/*! @license Firebase v3.7.5
    Build: 3.7.5-rc.1
    Terms: https://firebase.google.com/terms/ */
var firebase = null; (function() { var aa=function(a){var b=0;return function(){return b<a.length?{done:!1,value:a[b++]}:{done:!0}}},l=typeof Object.defineProperties=="function"?Object.defineProperty:function(a,b,c){if(a==Array.prototype||a==Object.prototype)return a;a[b]=c.value;return a},ba=function(a){a=["object"==typeof globalThis&&globalThis,a,"object"==typeof window&&window,"object"==typeof self&&self,"object"==typeof global&&global];for(var b=0;b<a.length;++b){var c=a[b];if(c&&c.Math==Math)return c}throw Error("Cannot find global object");
},n=ba(this),ca=function(a,b){if(b)a:{var c=n;a=a.split(".");for(var d=0;d<a.length-1;d++){var e=a[d];if(!(e in c))break a;c=c[e]}a=a[a.length-1];d=c[a];b=b(d);b!=d&&b!=null&&l(c,a,{configurable:!0,writable:!0,value:b})}};
ca("Symbol",function(a){if(a)return a;var b=function(g,k){this.V=g;l(this,"description",{configurable:!0,writable:!0,value:k})};b.prototype.toString=function(){return this.V};var c="jscomp_symbol_"+(Math.random()*1E9>>>0)+"_",d=0,e=function(g){if(this instanceof e)throw new TypeError("Symbol is not a constructor");return new b(c+(g||"")+"_"+d++,g)};return e});
var p=function(a){var b=typeof Symbol!="undefined"&&Symbol.iterator&&a[Symbol.iterator];if(b)return b.call(a);if(typeof a.length=="number")return{next:aa(a)};throw Error(String(a)+" is not an iterable or ArrayLike");},q=function(a){for(var b,c=[];!(b=a.next()).done;)c.push(b.value);return c},da=function(){for(var a=Number(this),b=[],c=a;c<arguments.length;c++)b[c-a]=arguments[c];return b};/*

 Copyright The Closure Library Authors.
 SPDX-License-Identifier: Apache-2.0
*/
var r=this||self,ea=function(a,b){var c=Array.prototype.slice.call(arguments,1);return function(){var d=c.slice();d.push.apply(d,arguments);return a.apply(this,d)}},u=function(a,b){function c(){}c.prototype=b.prototype;a.ha=b.prototype;a.prototype=new c;a.prototype.constructor=a;a.base=function(d,e,g){for(var k=Array(arguments.length-2),f=2;f<arguments.length;f++)k[f-2]=arguments[f];return b.prototype[e].apply(d,k)}};var v=typeof AsyncContext!=="undefined"&&typeof AsyncContext.Snapshot==="function"?function(a){return a&&AsyncContext.Snapshot.wrap(a)}:function(a){return a};function w(a,b){if(Error.captureStackTrace)Error.captureStackTrace(this,w);else{var c=Error().stack;c&&(this.stack=c)}a&&(this.message=String(a));b!==void 0&&(this.cause=b)}u(w,Error);w.prototype.name="CustomError";function x(a,b){a=a.split("%s");for(var c="",d=a.length-1,e=0;e<d;e++)c+=a[e]+(e<b.length?b[e]:"%s");w.call(this,c+a[d])}u(x,w);x.prototype.name="AssertionError";function z(a,b,c,d){var e="Assertion failed";if(c){e+=": "+c;var g=d}else a&&(e+=": "+a,g=b);throw new x(""+e,g||[]);}
var A=function(a,b,c){a||z("",null,b,Array.prototype.slice.call(arguments,2))},fa=function(a,b,c){a==null&&z("Expected to exist: %s.",[a],b,Array.prototype.slice.call(arguments,2));return a},B=function(a,b,c){if(typeof a!=="function"){var d=typeof a;d=d!="object"?d:a?Array.isArray(a)?"array":d:"null";z("Expected function but got %s: %s.",[d,a],b,Array.prototype.slice.call(arguments,2))}};var C=function(a,b){this.aa=100;this.W=a;this.ba=b;this.F=0;this.D=null};C.prototype.get=function(){if(this.F>0){this.F--;var a=this.D;this.D=a.next;a.next=null}else a=this.W();return a};C.prototype.put=function(a){this.ba(a);this.F<this.aa&&(this.F++,a.next=this.D,this.D=a)};function ha(a){r.setTimeout(function(){throw a;},0)};var D=function(){this.G=this.o=null};D.prototype.add=function(a,b){var c=ia.get();c.set(a,b);this.G?this.G.next=c:(A(!this.o),this.o=c);this.G=c};D.prototype.remove=function(){var a=null;this.o&&(a=this.o,this.o=this.o.next,this.o||(this.G=null),a.next=null);return a};var ia=new C(function(){return new E},function(a){return a.reset()}),E=function(){this.next=this.scope=this.fn=null};E.prototype.set=function(a,b){this.fn=a;this.scope=b;this.next=null};
E.prototype.reset=function(){this.next=this.scope=this.fn=null};var F=r.console&&r.console.createTask?r.console.createTask.bind(r.console):void 0,G=F?Symbol("consoleTask"):void 0;
function H(a,b){function c(){var f=da.apply(0,arguments),h=this;return k.run(function(){return a.call.apply(a,[h].concat(f instanceof Array?f:q(p(f))))})}b=b===void 0?"anonymous":b;if(G&&a[G])return a;var d=a,e,g=(e=ja)==null?void 0:e();a=function(){var f=da.apply(0,arguments),h,m=(h=ja)==null?void 0:h();if(g!==m)throw Error(b+" was scheduled in '"+g+"' but called in '"+m+"'.\nMake sure your test awaits all async calls.\n\nTIP: To help investigate, debug the test in Chrome and look at the async portion\nof the call stack to see what originally scheduled the callback.  Then, make the\ntest wait for the relevant asynchronous work to finish.");return d.call.apply(d,
[this].concat(f instanceof Array?f:q(p(f))))};if(!F)return a;var k=F(a.name||b);c[fa(G)]=k;return c}var ja;var I,J=!1,ka=new D,K=function(a,b){a=H(a,"goog.async.run");I||la();J||(I(),J=!0);ka.add(a,b)},la=function(){var a=Promise.resolve(void 0);I=function(){a.then(ma)}};function ma(){for(var a;a=ka.remove();){try{a.fn.call(a.scope)}catch(b){ha(b)}ia.put(a)}J=!1};var L=function(){};var O=function(a,b){this.g=0;this.T=void 0;this.s=this.i=this.m=null;this.B=this.H=!1;if(a!=L)try{var c=this;a.call(b,function(d){M(c,2,d)},function(d){if(!(d instanceof N))try{if(d instanceof Error)throw d;throw Error("Promise rejected.");}catch(e){}M(c,3,d)})}catch(d){M(this,3,d)}},na=function(){this.next=this.context=this.u=this.l=this.child=null;this.v=!1};na.prototype.reset=function(){this.context=this.u=this.l=this.child=null;this.v=!1};
var oa=new C(function(){return new na},function(a){a.reset()}),pa=function(a,b,c){var d=oa.get();d.l=a;d.u=b;d.context=c;return d},ra=function(a,b,c){qa(a,b,c,null)||K(ea(b,a))};O.prototype.then=function(a,b,c){a!=null&&B(a,"opt_onFulfilled should be a function.");b!=null&&B(b,"opt_onRejected should be a function. Did you pass opt_context as the second argument instead of the third?");return sa(this,v(typeof a==="function"?a:null),v(typeof b==="function"?b:null),c)};O.prototype.$goog_Thenable=!0;
var ua=function(a,b,c,d){b!=null&&B(b,"opt_onFulfilled should be a function.");c!=null&&B(c,"opt_onRejected should be a function. Did you pass opt_context as the second argument instead of the third?");ta(a,pa(b||L,c||null,d))};O.prototype.finally=function(a){var b=this;a=v(a);return new Promise(function(c,d){ua(b,function(e){a();c(e)},function(e){a();d(e)})})};O.prototype.U=function(a,b){return sa(this,null,v(a),b)};O.prototype.catch=O.prototype.U;
O.prototype.cancel=function(a){if(this.g==0){var b=new N(a);K(function(){va(this,b)},this)}};
var va=function(a,b){if(a.g==0)if(a.m){var c=a.m;if(c.i){for(var d=0,e=null,g=null,k=c.i;k&&(k.v||(d++,k.child==a&&(e=k),!(e&&d>1)));k=k.next)e||(g=k);e&&(c.g==0&&d==1?va(c,b):(g?(d=g,A(c.i),A(d!=null),d.next==c.s&&(c.s=d),d.next=d.next.next):wa(c),xa(c,e,3,b)))}a.m=null}else M(a,3,b)},ta=function(a,b){a.i||a.g!=2&&a.g!=3||ya(a);A(b.l!=null);a.s?a.s.next=b:a.i=b;a.s=b},sa=function(a,b,c,d){b&&(b=H(b,"goog.Promise.then"));c&&(c=H(c,"goog.Promise.then"));var e=pa(null,null,null);e.child=new O(function(g,
k){e.l=b?function(f){try{var h=b.call(d,f);g(h)}catch(m){k(m)}}:g;e.u=c?function(f){try{var h=c.call(d,f);h===void 0&&f instanceof N?k(f):g(h)}catch(m){k(m)}}:k});e.child.m=a;ta(a,e);return e.child};O.prototype.ea=function(a){A(this.g==1);this.g=0;M(this,2,a)};O.prototype.fa=function(a){A(this.g==1);this.g=0;M(this,3,a)};
var M=function(a,b,c){a.g==0&&(a===c&&(b=3,c=new TypeError("Promise cannot resolve to itself")),a.g=1,qa(c,a.ea,a.fa,a)||(a.T=c,a.g=b,a.m=null,ya(a),b!=3||c instanceof N||za(a,c)))},qa=function(a,b,c,d){if(a instanceof O)return ua(a,b,c,d),!0;if(a)try{var e=!!a.$goog_Thenable}catch(k){e=!1}else e=!1;if(e)return a.then(b,c,d),!0;e=typeof a;if(e=="object"&&a!=null||e=="function")try{var g=a.then;if(typeof g==="function")return Aa(a,g,b,c,d),!0}catch(k){return c.call(d,k),!0}return!1},Aa=function(a,
b,c,d,e){var g=!1,k=function(h){g||(g=!0,c.call(e,h))},f=function(h){g||(g=!0,d.call(e,h))};try{b.call(a,k,f)}catch(h){f(h)}},ya=function(a){a.H||(a.H=!0,K(a.X,a))},wa=function(a){var b=null;a.i&&(b=a.i,a.i=b.next,b.next=null);a.i||(a.s=null);b!=null&&A(b.l!=null);return b};O.prototype.X=function(){for(var a;a=wa(this);)xa(this,a,this.g,this.T);this.H=!1};
var xa=function(a,b,c,d){if(c==3&&b.u&&!b.v)for(;a&&a.B;a=a.m)a.B=!1;if(b.child)b.child.m=null,Ba(b,c,d);else try{b.v?b.l.call(b.context):Ba(b,c,d)}catch(e){Ca.call(null,e)}oa.put(b)},Ba=function(a,b,c){b==2?a.l.call(a.context,c):a.u&&a.u.call(a.context,c)},za=function(a,b){a.B=!0;K(function(){a.B&&Ca.call(null,b)})},Ca=ha,N=function(a){w.call(this,a)};u(N,w);N.prototype.name="cancel";O.all=function(a){return new O(function(b,c){var d=a.length,e=[];if(d)for(var g=function(m,t){d--;e[m]=t;d==0&&b(e)},k=function(m){c(m)},f,h=0;h<a.length;h++)f=a[h],ra(f,ea(g,h),k);else b(e)})};O.resolve=function(a){if(a instanceof O)return a;var b=new O(L);M(b,2,a);return b};O.reject=function(a){return new O(function(b,c){c(a)})};O.prototype["catch"]=O.prototype.U;var P=O;typeof Promise!=="undefined"&&(P=Promise);function Q(a,b){if(!(b instanceof Object))return b;switch(b.constructor){case Date:return new Date(b.getTime());case Object:a===void 0&&(a={});break;case Array:a=[];break;default:return b}for(var c in b)b.hasOwnProperty(c)&&(a[c]=Q(a[c],b[c]));return a};var Da=Error.captureStackTrace,S=function(a,b){this.code=a;this.message=b;if(Da)Da(this,R.prototype.create);else{var c=Error.apply(this,arguments);this.name="FirebaseError";Object.defineProperty(this,"stack",{get:function(){return c.stack}})}};S.prototype.constructor=S;S.prototype.name="FirebaseError";var R=function(a,b,c){this.service=a;this.da=b;this.errors=c;this.pattern=/\{\$([^}]+)}/g};
R.prototype.create=function(a,b){b===void 0&&(b={});var c=this.errors[a];a=this.service+"/"+a;c=c===void 0?"Error":c.replace(this.pattern,function(e,g){e=b[g];return e!==void 0?e.toString():"<"+g+"?>"});c=this.da+": "+c+" ("+a+").";c=new S(a,c);for(var d in b)b.hasOwnProperty(d)&&d.slice(-1)!=="_"&&(c[d]=b[d]);return c};var Ea=P;function Fa(a,b){a=new T(a,b);return a.subscribe.bind(a)}var T=function(a,b){var c=this;this.h=[];this.S=0;this.task=Ea.resolve();this.A=!1;this.J=b;this.task.then(function(){a(c)}).catch(function(d){c.error(d)})};T.prototype.next=function(a){U(this,function(b){b.next(a)})};T.prototype.error=function(a){U(this,function(b){b.error(a)});this.close(a)};T.prototype.complete=function(){U(this,function(a){a.complete()});this.close()};
T.prototype.subscribe=function(a,b,c){var d=this;if(a===void 0&&b===void 0&&c===void 0)throw Error("Missing Observer.");var e=Ga(a)?a:{next:a,error:b,complete:c};e.next===void 0&&(e.next=V);e.error===void 0&&(e.error=V);e.complete===void 0&&(e.complete=V);a=this.ga.bind(this,this.h.length);this.A&&this.task.then(function(){try{d.M?e.error(d.M):e.complete()}catch(g){}});this.h.push(e);return a};
T.prototype.ga=function(a){this.h!==void 0&&this.h[a]!==void 0&&(delete this.h[a],--this.S,this.S===0&&this.J!==void 0&&this.J(this))};var U=function(a,b){if(!a.A)for(var c=0;c<a.h.length;c++)Ha(a,c,b)},Ha=function(a,b,c){a.task.then(function(){if(a.h!==void 0&&a.h[b]!==void 0)try{c(a.h[b])}catch(d){typeof console!=="undefined"&&console.error&&console.error(d)}})};T.prototype.close=function(a){var b=this;this.A||(this.A=!0,a!==void 0&&(this.M=a),this.task.then(function(){b.h=void 0;b.J=void 0}))};
function Ga(a){if(typeof a!=="object"||a===null)return!1;for(var b=p(["next","error","complete"]),c=b.next();!c.done;c=b.next())if(c=c.value,c in a&&typeof a[c]==="function")return!0;return!1}function V(){};var W=P,X=function(a,b,c){var d=this;this.P=c;this.R=!1;this.j={};this.I=b;this.K=Q(void 0,a);a="serviceAccount"in this.K;("credential"in this.K||a)&&typeof console!=="undefined"&&console.log("The '"+(a?"serviceAccount":"credential")+"' property specified in the first argument to initializeApp() is deprecated and will be removed in the next major version. You should instead use the 'firebase-admin' package. See https://firebase.google.com/docs/admin/setup for details on how to get started.");Object.keys(c.INTERNAL.factories).forEach(function(e){var g=
c.INTERNAL.useAsService(d,e);g!==null&&(g=d.Z.bind(d,g),d[e]=g)})};X.prototype.delete=function(){var a=this;return(new W(function(b){Y(a);b()})).then(function(){a.P.INTERNAL.removeApp(a.I);var b=[];Object.keys(a.j).forEach(function(c){Object.keys(a.j[c]).forEach(function(d){b.push(a.j[c][d])})});return W.all(b.filter(function(c){return"INTERNAL"in c}).map(function(c){return c.INTERNAL.delete()}))}).then(function(){a.R=!0;a.j={}})};
X.prototype.Z=function(a,b){Y(this);typeof this.j[a]==="undefined"&&(this.j[a]={});var c=b||"[DEFAULT]";return typeof this.j[a][c]==="undefined"?(b=this.P.INTERNAL.factories[a](this,this.Y.bind(this),b),this.j[a][c]=b):this.j[a][c]};X.prototype.Y=function(a){Q(this,a)};var Y=function(a){a.R&&Z("app-deleted",{name:a.I})};n.Object.defineProperties(X.prototype,{name:{configurable:!0,enumerable:!0,get:function(){Y(this);return this.I}},options:{configurable:!0,enumerable:!0,get:function(){Y(this);return this.K}}});
X.prototype.name&&X.prototype.options||X.prototype.delete||console.log("dc");
function Ia(){function a(f){f=f||"[DEFAULT]";var h=d[f];h===void 0&&Z("no-app",{name:f});return h}function b(f,h){Object.keys(e).forEach(function(m){m=c(f,m);if(m!==null&&g[m])g[m](h,f)})}function c(f,h){if(h==="serverAuth")return null;var m=h;f=f.options;h==="auth"&&(f.serviceAccount||f.credential)&&(m="serverAuth","serverAuth"in e||Z("sa-not-supported"));return m}var d={},e={},g={},k={__esModule:!0,initializeApp:function(f,h){h===void 0?h="[DEFAULT]":(typeof h!=="string"||h==="")&&Z("bad-app-name",
{name:h+""});d[h]!==void 0&&Z("duplicate-app",{name:h});f=new X(f,h,k);d[h]=f;b(f,"create");f.INTERNAL!=void 0&&f.INTERNAL.getToken!=void 0||Q(f,{INTERNAL:{getUid:function(){return null},getToken:function(){return W.resolve(null)},addAuthTokenListener:function(){},removeAuthTokenListener:function(){}}});return f},app:a,apps:null,Promise:W,SDK_VERSION:"0.0.0",INTERNAL:{registerService:function(f,h,m,t,Ja){e[f]&&Z("duplicate-service",{name:f});e[f]=Ja?h:function(y,Ka){return h(y,Ka,"[DEFAULT]")};t&&
(g[f]=t);t=function(y){y===void 0&&(y=a());typeof y[f]!=="function"&&Z("invalid-app-argument",{name:f});return y[f]()};m!==void 0&&Q(t,m);return k[f]=t},createFirebaseNamespace:Ia,extendNamespace:function(f){Q(k,f)},createSubscribe:Fa,ErrorFactory:R,removeApp:function(f){b(d[f],"delete");delete d[f]},factories:e,useAsService:c,Promise:O,deepExtend:Q}};k["default"]=k;Object.defineProperty(k,"apps",{get:function(){return Object.keys(d).map(function(f){return d[f]})}});a.App=X;return k}
function Z(a,b){throw La.create(a,b);}
var La=new R("app","Firebase",{"no-app":"No Firebase App '{$name}' has been created - call Firebase App.initializeApp()","bad-app-name":"Illegal App name: '{$name}","duplicate-app":"Firebase App named '{$name}' already exists","app-deleted":"Firebase App named '{$name}' already deleted","duplicate-service":"Firebase service named '{$name}' already registered","sa-not-supported":"Initializing the Firebase SDK with a service account is only allowed in a Node.js environment. On client devices, you should instead initialize the SDK with an api key and auth domain","invalid-app-argument":"firebase.{$name}() takes either no argument or a Firebase App instance."});typeof firebase!=="undefined"&&(firebase=Ia()); }).call(this);
firebase.SDK_VERSION = "3.7.5";
(function(){var l,aa=function(a){var b=0;return function(){return b<a.length?{done:!1,value:a[b++]}:{done:!0}}},ca=typeof Object.defineProperties=="function"?Object.defineProperty:function(a,b,c){if(a==Array.prototype||a==Object.prototype)return a;a[b]=c.value;return a},da=function(a){a=["object"==typeof globalThis&&globalThis,a,"object"==typeof window&&window,"object"==typeof self&&self,"object"==typeof global&&global];for(var b=0;b<a.length;++b){var c=a[b];if(c&&c.Math==Math)return c}throw Error("Cannot find global object");
},ea=da(this),p=function(a,b){if(b)a:{var c=ea;a=a.split(".");for(var d=0;d<a.length-1;d++){var e=a[d];if(!(e in c))break a;c=c[e]}a=a[a.length-1];d=c[a];b=b(d);b!=d&&b!=null&&ca(c,a,{configurable:!0,writable:!0,value:b})}};
p("Symbol",function(a){if(a)return a;var b=function(f,g){this.Ai=f;ca(this,"description",{configurable:!0,writable:!0,value:g})};b.prototype.toString=function(){return this.Ai};var c="jscomp_symbol_"+(Math.random()*1E9>>>0)+"_",d=0,e=function(f){if(this instanceof e)throw new TypeError("Symbol is not a constructor");return new b(c+(f||"")+"_"+d++,f)};return e});
p("Symbol.iterator",function(a){if(a)return a;a=Symbol("Symbol.iterator");for(var b="Array Int8Array Uint8Array Uint8ClampedArray Int16Array Uint16Array Int32Array Uint32Array Float32Array Float64Array".split(" "),c=0;c<b.length;c++){var d=ea[b[c]];typeof d==="function"&&typeof d.prototype[a]!="function"&&ca(d.prototype,a,{configurable:!0,writable:!0,value:function(){return fa(aa(this))}})}return a});
var fa=function(a){a={next:a};a[Symbol.iterator]=function(){return this};return a},ha=typeof Object.create=="function"?Object.create:function(a){var b=function(){};b.prototype=a;return new b},ia;if(typeof Object.setPrototypeOf=="function")ia=Object.setPrototypeOf;else{var ja;a:{var ka={a:!0},la={};try{la.__proto__=ka;ja=la.a;break a}catch(a){}ja=!1}ia=ja?function(a,b){a.__proto__=b;if(a.__proto__!==b)throw new TypeError(a+" is not extensible");return a}:null}
var ma=ia,q=function(a,b){a.prototype=ha(b.prototype);a.prototype.constructor=a;if(ma)ma(a,b);else for(var c in b)if(c!="prototype")if(Object.defineProperties){var d=Object.getOwnPropertyDescriptor(b,c);d&&Object.defineProperty(a,c,d)}else a[c]=b[c];a.Dc=b.prototype},na=function(a){var b=typeof Symbol!="undefined"&&Symbol.iterator&&a[Symbol.iterator];if(b)return b.call(a);if(typeof a.length=="number")return{next:aa(a)};throw Error(String(a)+" is not an iterable or ArrayLike");},oa=function(a){if(!(a instanceof
Array)){a=na(a);for(var b,c=[];!(b=a.next()).done;)c.push(b.value);a=c}return a},ra=function(a){return pa(a,a)},pa=function(a,b){a.raw=b;Object.freeze&&(Object.freeze(a),Object.freeze(b));return a},sa=function(){for(var a=Number(this),b=[],c=a;c<arguments.length;c++)b[c-a]=arguments[c];return b};p("globalThis",function(a){return a||ea});
p("Promise",function(a){function b(){this.lb=null}function c(g){return g instanceof e?g:new e(function(h){h(g)})}if(a)return a;b.prototype.wg=function(g){if(this.lb==null){this.lb=[];var h=this;this.xg(function(){h.Si()})}this.lb.push(g)};var d=ea.setTimeout;b.prototype.xg=function(g){d(g,0)};b.prototype.Si=function(){for(;this.lb&&this.lb.length;){var g=this.lb;this.lb=[];for(var h=0;h<g.length;++h){var k=g[h];g[h]=null;try{k()}catch(m){this.Hi(m)}}}this.lb=null};b.prototype.Hi=function(g){this.xg(function(){throw g;
})};var e=function(g){this.R=0;this.ma=void 0;this.rc=[];this.oh=!1;var h=this.kf();try{g(h.resolve,h.reject)}catch(k){h.reject(k)}};e.prototype.kf=function(){function g(m){return function(n){k||(k=!0,m.call(h,n))}}var h=this,k=!1;return{resolve:g(this.Wj),reject:g(this.cg)}};e.prototype.Wj=function(g){if(g===this)this.cg(new TypeError("A Promise cannot resolve to itself"));else if(g instanceof e)this.kk(g);else{a:switch(typeof g){case "object":var h=g!=null;break a;case "function":h=!0;break a;default:h=
!1}h?this.Vj(g):this.Yg(g)}};e.prototype.Vj=function(g){var h=void 0;try{h=g.then}catch(k){this.cg(k);return}typeof h=="function"?this.lk(h,g):this.Yg(g)};e.prototype.cg=function(g){this.ai(2,g)};e.prototype.Yg=function(g){this.ai(1,g)};e.prototype.ai=function(g,h){if(this.R!=0)throw Error("Cannot settle("+g+", "+h+"): Promise already settled in state"+this.R);this.R=g;this.ma=h;this.R===2&&this.ck();this.Ui()};e.prototype.ck=function(){var g=this;d(function(){if(g.Fj()){var h=ea.console;typeof h!==
"undefined"&&h.error(g.ma)}},1)};e.prototype.Fj=function(){if(this.oh)return!1;var g=ea.CustomEvent,h=ea.Event,k=ea.dispatchEvent;if(typeof k==="undefined")return!0;typeof g==="function"?g=new g("unhandledrejection",{cancelable:!0}):typeof h==="function"?g=new h("unhandledrejection",{cancelable:!0}):(g=ea.document.createEvent("CustomEvent"),g.initCustomEvent("unhandledrejection",!1,!0,g));g.promise=this;g.reason=this.ma;return k(g)};e.prototype.Ui=function(){if(this.rc!=null){for(var g=0;g<this.rc.length;++g)f.wg(this.rc[g]);
this.rc=null}};var f=new b;e.prototype.kk=function(g){var h=this.kf();g.Nd(h.resolve,h.reject)};e.prototype.lk=function(g,h){var k=this.kf();try{g.call(h,k.resolve,k.reject)}catch(m){k.reject(m)}};e.prototype.then=function(g,h){function k(t,y){return typeof t=="function"?function(ba){try{m(t(ba))}catch(jb){n(jb)}}:y}var m,n,r=new e(function(t,y){m=t;n=y});this.Nd(k(g,m),k(h,n));return r};e.prototype.catch=function(g){return this.then(void 0,g)};e.prototype.Nd=function(g,h){function k(){switch(m.R){case 1:g(m.ma);
break;case 2:h(m.ma);break;default:throw Error("Unexpected state: "+m.R);}}var m=this;this.rc==null?f.wg(k):this.rc.push(k);this.oh=!0};e.resolve=c;e.reject=function(g){return new e(function(h,k){k(g)})};e.race=function(g){return new e(function(h,k){for(var m=na(g),n=m.next();!n.done;n=m.next())c(n.value).Nd(h,k)})};e.all=function(g){var h=na(g),k=h.next();return k.done?c([]):new e(function(m,n){function r(ba){return function(jb){t[ba]=jb;y--;y==0&&m(t)}}var t=[],y=0;do t.push(void 0),y++,c(k.value).Nd(r(t.length-
1),n),k=h.next();while(!k.done)})};return e});var ta=function(a,b){return Object.prototype.hasOwnProperty.call(a,b)};p("Symbol.dispose",function(a){return a?a:Symbol("Symbol.dispose")});p("Array.prototype.find",function(a){return a?a:function(b,c){a:{var d=this;d instanceof String&&(d=String(d));for(var e=d.length,f=0;f<e;f++){var g=d[f];if(b.call(c,g,f,d)){b=g;break a}}b=void 0}return b}});
p("WeakMap",function(a){function b(){}function c(k){var m=typeof k;return m==="object"&&k!==null||m==="function"}function d(k){if(!ta(k,f)){var m=new b;ca(k,f,{value:m})}}function e(k){var m=Object[k];m&&(Object[k]=function(n){if(n instanceof b)return n;Object.isExtensible(n)&&d(n);return m(n)})}if(function(){if(!a||!Object.seal)return!1;try{var k=Object.seal({}),m=Object.seal({}),n=new a([[k,2],[m,3]]);if(n.get(k)!=2||n.get(m)!=3)return!1;n.delete(k);n.set(m,4);return!n.has(k)&&n.get(m)==4}catch(r){return!1}}())return a;
var f="$jscomp_hidden_"+Math.random();e("freeze");e("preventExtensions");e("seal");var g=0,h=function(k){this.Ea=(g+=Math.random()+1).toString();if(k){k=na(k);for(var m;!(m=k.next()).done;)m=m.value,this.set(m[0],m[1])}};h.prototype.set=function(k,m){if(!c(k))throw Error("Invalid WeakMap key");d(k);if(!ta(k,f))throw Error("WeakMap key fail: "+k);k[f][this.Ea]=m;return this};h.prototype.get=function(k){return c(k)&&ta(k,f)?k[f][this.Ea]:void 0};h.prototype.has=function(k){return c(k)&&ta(k,f)&&ta(k[f],
this.Ea)};h.prototype.delete=function(k){return c(k)&&ta(k,f)&&ta(k[f],this.Ea)?delete k[f][this.Ea]:!1};return h});
p("Map",function(a){if(function(){if(!a||typeof a!="function"||!a.prototype.entries||typeof Object.seal!="function")return!1;try{var h=Object.seal({x:4}),k=new a(na([[h,"s"]]));if(k.get(h)!="s"||k.size!=1||k.get({x:4})||k.set({x:4},"t")!=k||k.size!=2)return!1;var m=k.entries(),n=m.next();if(n.done||n.value[0]!=h||n.value[1]!="s")return!1;n=m.next();return n.done||n.value[0].x!=4||n.value[1]!="t"||!m.next().done?!1:!0}catch(r){return!1}}())return a;var b=new WeakMap,c=function(h){this[0]={};this[1]=
f();this.size=0;if(h){h=na(h);for(var k;!(k=h.next()).done;)k=k.value,this.set(k[0],k[1])}};c.prototype.set=function(h,k){h=h===0?0:h;var m=d(this,h);m.list||(m.list=this[0][m.id]=[]);m.ha?m.ha.value=k:(m.ha={next:this[1],gb:this[1].gb,head:this[1],key:h,value:k},m.list.push(m.ha),this[1].gb.next=m.ha,this[1].gb=m.ha,this.size++);return this};c.prototype.delete=function(h){h=d(this,h);return h.ha&&h.list?(h.list.splice(h.index,1),h.list.length||delete this[0][h.id],h.ha.gb.next=h.ha.next,h.ha.next.gb=
h.ha.gb,h.ha.head=null,this.size--,!0):!1};c.prototype.clear=function(){this[0]={};this[1]=this[1].gb=f();this.size=0};c.prototype.has=function(h){return!!d(this,h).ha};c.prototype.get=function(h){return(h=d(this,h).ha)&&h.value};c.prototype.entries=function(){return e(this,function(h){return[h.key,h.value]})};c.prototype.keys=function(){return e(this,function(h){return h.key})};c.prototype.values=function(){return e(this,function(h){return h.value})};c.prototype.forEach=function(h,k){for(var m=this.entries(),
n;!(n=m.next()).done;)n=n.value,h.call(k,n[1],n[0],this)};c.prototype[Symbol.iterator]=c.prototype.entries;var d=function(h,k){var m=k&&typeof k;m=="object"||m=="function"?b.has(k)?m=b.get(k):(m=""+ ++g,b.set(k,m)):m="p_"+k;var n=h[0][m];if(n&&ta(h[0],m))for(h=0;h<n.length;h++){var r=n[h];if(k!==k&&r.key!==r.key||k===r.key)return{id:m,list:n,index:h,ha:r}}return{id:m,list:n,index:-1,ha:void 0}},e=function(h,k){var m=h[1];return fa(function(){if(m){for(;m.head!=h[1];)m=m.gb;for(;m.next!=m.head;)return m=
m.next,{done:!1,value:k(m)};m=null}return{done:!0,value:void 0}})},f=function(){var h={};return h.gb=h.next=h.head=h},g=0;return c});p("Math.log2",function(a){return a?a:function(b){return Math.log(b)/Math.LN2}});p("Object.values",function(a){return a?a:function(b){var c=[],d;for(d in b)ta(b,d)&&c.push(b[d]);return c}});p("Object.is",function(a){return a?a:function(b,c){return b===c?b!==0||1/b===1/c:b!==b&&c!==c}});
p("Array.prototype.includes",function(a){return a?a:function(b,c){var d=this;d instanceof String&&(d=String(d));var e=d.length;c=c||0;for(c<0&&(c=Math.max(c+e,0));c<e;c++){var f=d[c];if(f===b||Object.is(f,b))return!0}return!1}});
p("String.prototype.includes",function(a){return a?a:function(b,c){if(this==null)throw new TypeError("The 'this' value for String.prototype.includes must not be null or undefined");if(b instanceof RegExp)throw new TypeError("First argument to String.prototype.includes must not be a regular expression");return(this+"").indexOf(b,c||0)!==-1}});
p("Array.from",function(a){return a?a:function(b,c,d){c=c!=null?c:function(h){return h};var e=[],f=typeof Symbol!="undefined"&&Symbol.iterator&&b[Symbol.iterator];if(typeof f=="function"){b=f.call(b);for(var g=0;!(f=b.next()).done;)e.push(c.call(d,f.value,g++))}else for(f=b.length,g=0;g<f;g++)e.push(c.call(d,b[g],g));return e}});p("Object.entries",function(a){return a?a:function(b){var c=[],d;for(d in b)ta(b,d)&&c.push([d,b[d]]);return c}});
var ua=function(a,b){a instanceof String&&(a+="");var c=0,d=!1,e={next:function(){if(!d&&c<a.length){var f=c++;return{value:b(f,a[f]),done:!1}}d=!0;return{done:!0,value:void 0}}};e[Symbol.iterator]=function(){return e};return e};p("Array.prototype.entries",function(a){return a?a:function(){return ua(this,function(b,c){return[b,c]})}});p("Array.prototype.keys",function(a){return a?a:function(){return ua(this,function(b){return b})}});
p("Array.prototype.values",function(a){return a?a:function(){return ua(this,function(b,c){return c})}});/*

 Copyright The Closure Library Authors.
 SPDX-License-Identifier: Apache-2.0
*/
var va=va||{},u=this||self,wa=function(a){var b=typeof a;return b!="object"?b:a?Array.isArray(a)?"array":b:"null"},xa=function(a){var b=wa(a);return b=="array"||b=="object"&&typeof a.length=="number"},v=function(a){var b=typeof a;return b=="object"&&a!=null||b=="function"},ya=function(a,b,c){return a.call.apply(a.bind,arguments)},za=function(a,b,c){if(!a)throw Error();if(arguments.length>2){var d=Array.prototype.slice.call(arguments,2);return function(){var e=Array.prototype.slice.call(arguments);
Array.prototype.unshift.apply(e,d);return a.apply(b,e)}}return function(){return a.apply(b,arguments)}},w=function(a,b,c){w=Function.prototype.bind&&Function.prototype.bind.toString().indexOf("native code")!=-1?ya:za;return w.apply(null,arguments)},Aa=function(a,b){var c=Array.prototype.slice.call(arguments,1);return function(){var d=c.slice();d.push.apply(d,arguments);return a.apply(this,d)}},x=function(a,b){function c(){}c.prototype=b.prototype;a.Dc=b.prototype;a.prototype=new c;a.prototype.constructor=
a;a.gl=function(d,e,f){for(var g=Array(arguments.length-2),h=2;h<arguments.length;h++)g[h-2]=arguments[h];return b.prototype[e].apply(d,g)}};function Ba(a,b){if(Error.captureStackTrace)Error.captureStackTrace(this,Ba);else{var c=Error().stack;c&&(this.stack=c)}a&&(this.message=String(a));b!==void 0&&(this.cause=b)}x(Ba,Error);Ba.prototype.name="CustomError";var Ca;function Da(a,b){a=a.split("%s");for(var c="",d=a.length-1,e=0;e<d;e++)c+=a[e]+(e<b.length?b[e]:"%s");Ba.call(this,c+a[d])}x(Da,Ba);Da.prototype.name="AssertionError";function Ea(a,b,c,d){var e="Assertion failed";if(c){e+=": "+c;var f=d}else a&&(e+=": "+a,f=b);throw new Da(""+e,f||[]);}
var z=function(a,b,c){a||Ea("",null,b,Array.prototype.slice.call(arguments,2));return a},Fa=function(a,b,c){a==null&&Ea("Expected to exist: %s.",[a],b,Array.prototype.slice.call(arguments,2));return a},Ga=function(a,b){throw new Da("Failure"+(a?": "+a:""),Array.prototype.slice.call(arguments,1));},Ha=function(a,b,c){typeof a!=="number"&&Ea("Expected number but got %s: %s.",[wa(a),a],b,Array.prototype.slice.call(arguments,2));return a},Ia=function(a,b,c){typeof a!=="function"&&Ea("Expected function but got %s: %s.",
[wa(a),a],b,Array.prototype.slice.call(arguments,2))},Ja=function(a,b,c){Array.isArray(a)||Ea("Expected array but got %s: %s.",[wa(a),a],b,Array.prototype.slice.call(arguments,2))};function Ka(a){u.setTimeout(function(){throw a;},0)};var La=function(a){return Array.prototype.map.call(a,function(b){b=b.toString(16);return b.length>1?b:"0"+b}).join("")};var Ma=String.prototype.trim?function(a){return a.trim()}:function(a){return/^[\s\xa0]*([\s\S]*?)[\s\xa0]*$/.exec(a)[1]},Na=/&/g,Oa=/</g,Pa=/>/g,Qa=/"/g,Ra=/'/g,Sa=/\x00/g,Ta=/[\x00&<>"']/;function A(a,b){return a.indexOf(b)!=-1};var Ua,Va;a:{for(var Wa=["CLOSURE_FLAGS"],Xa=u,Ya=0;Ya<Wa.length;Ya++)if(Xa=Xa[Wa[Ya]],Xa==null){Va=null;break a}Va=Xa}var Za=Va&&Va[610401301];Ua=Za!=null?Za:!1;function $a(){var a=u.navigator;return a&&(a=a.userAgent)?a:""}var ab,bb=u.navigator;ab=bb?bb.userAgentData||null:null;function B(a){return A($a(),a)};var cb=Array.prototype.indexOf?function(a,b){z(a.length!=null);return Array.prototype.indexOf.call(a,b,void 0)}:function(a,b){if(typeof a==="string")return typeof b!=="string"||b.length!=1?-1:a.indexOf(b,0);for(var c=0;c<a.length;c++)if(c in a&&a[c]===b)return c;return-1},C=Array.prototype.forEach?function(a,b){z(a.length!=null);Array.prototype.forEach.call(a,b,void 0)}:function(a,b){for(var c=a.length,d=typeof a==="string"?a.split(""):a,e=0;e<c;e++)e in d&&b.call(void 0,d[e],e,a)};
function db(a,b){for(var c=typeof a==="string"?a.split(""):a,d=a.length-1;d>=0;--d)d in c&&b.call(void 0,c[d],d,a)}
var eb=Array.prototype.filter?function(a,b){z(a.length!=null);return Array.prototype.filter.call(a,b,void 0)}:function(a,b){for(var c=a.length,d=[],e=0,f=typeof a==="string"?a.split(""):a,g=0;g<c;g++)if(g in f){var h=f[g];b.call(void 0,h,g,a)&&(d[e++]=h)}return d},fb=Array.prototype.map?function(a,b){z(a.length!=null);return Array.prototype.map.call(a,b,void 0)}:function(a,b){for(var c=a.length,d=Array(c),e=typeof a==="string"?a.split(""):a,f=0;f<c;f++)f in e&&(d[f]=b.call(void 0,e[f],f,a));return d},
gb=Array.prototype.some?function(a,b){z(a.length!=null);return Array.prototype.some.call(a,b,void 0)}:function(a,b){for(var c=a.length,d=typeof a==="string"?a.split(""):a,e=0;e<c;e++)if(e in d&&b.call(void 0,d[e],e,a))return!0;return!1};function hb(a,b){return cb(a,b)>=0}function ib(a,b){b=cb(a,b);var c;(c=b>=0)&&kb(a,b);return c}function kb(a,b){z(a.length!=null);return Array.prototype.splice.call(a,b,1).length==1}function lb(a,b){var c=0;db(a,function(d,e){b.call(void 0,d,e,a)&&kb(a,e)&&c++})}
function mb(a){var b=a.length;if(b>0){for(var c=Array(b),d=0;d<b;d++)c[d]=a[d];return c}return[]};var nb=Ua&&ab&&ab.brands.length>0?!1:B("Opera"),ob=Ua&&ab&&ab.brands.length>0?!1:B("Trident")||B("MSIE"),pb=B("Edge"),qb=B("Gecko")&&!(A($a().toLowerCase(),"webkit")&&!B("Edge"))&&!(B("Trident")||B("MSIE"))&&!B("Edge"),rb=A($a().toLowerCase(),"webkit")&&!B("Edge"),sb=function(){var a=u.document;return a?a.documentMode:void 0},tb;
a:{var ub="",vb=function(){var a=$a();if(qb)return/rv:([^\);]+)(\)|;)/.exec(a);if(pb)return/Edge\/([\d\.]+)/.exec(a);if(ob)return/\b(?:MSIE|rv)[: ]([^\);]+)(\)|;)/.exec(a);if(rb)return/WebKit\/(\S+)/.exec(a);if(nb)return/(?:Version)[ \/]?(\S+)/.exec(a)}();vb&&(ub=vb?vb[1]:"");if(ob){var wb=sb();if(wb!=null&&wb>parseFloat(ub)){tb=String(wb);break a}}tb=ub}var xb=tb,yb;if(u.document&&ob){var zb=sb();yb=zb?zb:parseInt(xb,10)||void 0}else yb=void 0;var Ab=yb;var Bb=null,Db=function(a){var b=[];Cb(a,function(c){b.push(c)});return b},Cb=function(a,b){function c(k){for(;d<a.length;){var m=a.charAt(d++),n=Bb[m];if(n!=null)return n;if(!/^[\s\xa0]*$/.test(m))throw Error("Unknown base64 encoding at char: "+m);}return k}Eb();for(var d=0;;){var e=c(-1),f=c(0),g=c(64),h=c(64);if(h===64&&e===-1)break;b(e<<2|f>>4);g!=64&&(b(f<<4&240|g>>2),h!=64&&b(g<<6&192|h))}},Eb=function(){if(!Bb){Bb={};for(var a="ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789".split(""),
b=["+/=","+/","-_=","-_.","-_"],c=0;c<5;c++)for(var d=a.concat(b[c].split("")),e=0;e<d.length;e++){var f=d[e],g=Bb[f];g===void 0?Bb[f]=e:z(g===e)}}};var Fb=typeof Symbol==="function"&&typeof Symbol()==="symbol",Gb;Gb=typeof Symbol==="function"&&typeof Symbol()==="symbol"?Symbol.for?Symbol.for("jas"):Symbol("jas"):void 0;z(Math.round(Math.log2(Math.max.apply(Math,oa(Object.values({Vk:1,Uk:2,Tk:4,Yk:8,Xk:16,Wk:32,Gk:64,dl:128,Qk:256,Pk:512,Lk:1024,bl:2048,Mk:4096,Ik:8192,Rk:16384})))))===14);var Hb=Fb?Fa(Gb):"il";function Ib(a){Ja(a,"state is only maintained on arrays.");return a[Hb]|0}var Jb=Object.getOwnPropertyDescriptor(Array.prototype,"zj");Object.defineProperties(Array.prototype,{zj:{get:function(){var a=Kb(this);return Jb?Jb.get.call(this)+"|"+a:a},configurable:!0,enumerable:!1}});
function Kb(a){function b(e,f){e&c&&d.push(f)}var c=Ib(a),d=[];b(1,"IS_REPEATED_FIELD");b(2,"IS_IMMUTABLE_ARRAY");b(4,"IS_API_FORMATTED");b(2048,"STRING_FORMATTED");b(4096,"GBIGINT_FORMATTED");b(4096,"BINARY");b(8,"ONLY_MUTABLE_VALUES");b(32,"MUTABLE_REFERENCES_ARE_OWNED");b(64,"CONSTRUCTED");b(128,"TRANSFERRED");b(256,"HAS_SPARSE_OBJECT");b(512,"HAS_MESSAGE_ID");b(1024,"FROZEN_ARRAY");b(8192,"DESERIALIZED_FROM_BINARY");b(16384,"HAS_WRAPPER");a=c>>15&1023||536870912;a!==536870912&&d.push("pivot: "+
a);return d.join(",")};var Lb=typeof Symbol!="undefined"&&typeof Symbol.hasInstance!="undefined";Object.freeze({});var Mb=function(){throw Error("please construct maps as mutable then call toImmutable");};if(Lb){var Nb=function(){throw Error("Cannot perform instanceof checks on ImmutableMap: please use isImmutableMap or isMutableMap to assert on the mutability of a map. See go/jspb-api-gotchas#immutable-classes for more information");},Ob={};Object.defineProperties(Mb,(Ob[Symbol.hasInstance]={value:Nb,configurable:!1,writable:!1,enumerable:!1},Ob));z(Mb[Symbol.hasInstance]===Nb,"defineProperties did not work: was it monkey-patched?")};if(typeof Proxy!=="undefined"){var Qb=Pb;new Proxy({},{getPrototypeOf:Qb,setPrototypeOf:Qb,isExtensible:Qb,preventExtensions:Qb,getOwnPropertyDescriptor:Qb,defineProperty:Qb,has:Qb,get:Qb,set:Qb,deleteProperty:Qb,apply:Qb,construct:Qb})}function Pb(){throw Error("this array or object is owned by JSPB and should not be reused, did you mean to copy it with copyJspbArray? See go/jspb-api-gotchas#construct_from_array");};z(!0);/*
 SPDX-License-Identifier: Apache-2.0
*/
(function(){}).prototype=Object.create(null);/*

 Copyright Google LLC
 SPDX-License-Identifier: Apache-2.0
*/
var Rb={};function Sb(){if(Rb!==Rb)throw Error("Bad secret");};var Tb=globalThis.trustedTypes,Ub;function Vb(){var a=null;if(!Tb)return a;try{var b=function(c){return c};a=Tb.createPolicy("goog#html",{createHTML:b,createScript:b,createScriptURL:b})}catch(c){throw c;}return a}function Wb(){Ub===void 0&&(Ub=Vb());return Ub};var Xb=function(a){Sb();this.Kh=a};Xb.prototype.toString=function(){return this.Kh+""};function Yb(a){var b=Wb();return new Xb(b?b.createScriptURL(a):a)}function Zb(a){if(a instanceof Xb)return a.Kh;throw Error("Unexpected type when unwrapping TrustedResourceUrl");};var $b=ra([""]),ac=pa(["\x00"],["\\0"]),bc=pa(["\n"],["\\n"]),cc=pa(["\x00"],["\\u0000"]),dc=ra([""]),ec=pa(["\x00"],["\\0"]),fc=pa(["\n"],["\\n"]),gc=pa(["\x00"],["\\u0000"]);
function hc(a,b){if(!Array.isArray(a)||!Array.isArray(a.raw)||a.length!==a.raw.length||!ic&&a===a.raw||!(ic&&!jc||kc(a))||b+1!==a.length)throw new TypeError("\n    ############################## ERROR ##############################\n\n    It looks like you are trying to call a template tag function (fn`...`)\n    using the normal function syntax (fn(...)), which is not supported.\n\n    The functions in the safevalues library are not designed to be called\n    like normal functions, and doing so invalidates the security guarantees\n    that safevalues provides.\n\n    If you are stuck and not sure how to proceed, please reach out to us\n    instead through:\n     - go/ise-hardening-yaqs (preferred) // LINE-INTERNAL\n     - g/ise-hardening // LINE-INTERNAL\n     - https://github.com/google/safevalues/issues\n\n    ############################## ERROR ##############################");}
function kc(a){return Object.isFrozen(a)&&Object.isFrozen(a.raw)}function lc(a){return a.toString().indexOf("`")===-1}var ic=lc(function(a){return a($b)})||lc(function(a){return a(ac)})||lc(function(a){return a(bc)})||lc(function(a){return a(cc)}),jc=kc(dc)&&kc(ec)&&kc(fc)&&kc(gc);var mc=function(a){Sb();this.Mh=a};mc.prototype.toString=function(){return this.Mh};new mc("about:blank");var nc=new mc("about:invalid#zClosurez");function oc(a){if(a instanceof mc)return a.Mh;throw Error("Unexpected type when unwrapping SafeUrl, got '"+a+"' of type '"+typeof a+"'");};var pc=function(a){this.yj=a};function qc(a){return new pc(function(b){return b.substr(0,a.length+1).toLowerCase()===a+":"})}var rc=[qc("data"),qc("http"),qc("https"),qc("mailto"),qc("ftp"),new pc(function(a){return/^[^:]*([/?#]|$)/.test(a)})];function sc(a){var b=b===void 0?rc:b;a:if(b=b===void 0?rc:b,a instanceof mc)b=a;else{for(var c=0;c<b.length;++c){var d=b[c];if(d instanceof pc&&d.yj(a)){b=new mc(a);break a}}b=void 0}b===void 0&&tc(a.toString());return b||nc}var uc=/^\s*(?!javascript:)(?:[\w+.-]+:|[^:/?#]*(?:[/?#]|$))/i;
function vc(a){if(a instanceof mc)a=oc(a);else{var b=!uc.test(a);b&&tc(a);a=b?void 0:a}return a}var wc=[],tc=function(){};xc(function(a){console.warn("A URL with content '"+a+"' was sanitized away.")});function xc(a){wc.indexOf(a)===-1&&wc.push(a);tc=function(b){wc.forEach(function(c){c(b)})}};var yc=function(a){Sb();this.Jh=a};yc.prototype.toString=function(){return this.Jh+""};function zc(a){var b=Wb();return new yc(b?b.createHTML(a):a)}function Ac(a){if(a instanceof yc)return a.Jh;throw Error("Unexpected type when unwrapping SafeHtml");};function Bc(a,b,c,d){b=vc(b);return b!==void 0?a.open(b,c,d):null}function Cc(a,b){b=b===void 0?document:b;var c,d;b=(d=(c=b).querySelector)==null?void 0:d.call(c,a+"[nonce]");return b==null?"":b.nonce||b.getAttribute("nonce")||""};function Dc(a,b){a.src=Zb(b);(b=Cc("script",a.ownerDocument))&&a.setAttribute("nonce",b)};var Ec=function(a){Sb();this.Oj=a};Ec.prototype.toString=function(){return this.Oj};var Fc=function(a){Sb();this.Lh=a};Fc.prototype.toString=function(){return this.Lh};var Gc=function(a,b){this.name=a;this.value=b};Gc.prototype.toString=function(){return this.name};var Hc=new Gc("OFF",Infinity),Ic=new Gc("SEVERE",1E3),Jc=new Gc("WARNING",900),Kc=new Gc("CONFIG",700),Lc=new Gc("FINE",500),Mc=function(){this.Od=0;this.clear()},Nc;Mc.prototype.clear=function(){this.Ag=Array(this.Od);this.Mg=-1;this.nh=!1};var Oc=function(a,b,c){this.reset(a||Hc,b,c,void 0,void 0)};Oc.prototype.reset=function(){};
var Pc=function(a,b){this.level=null;this.mj=[];this.parent=(b===void 0?null:b)||null;this.children=[];this.vh={getName:function(){return a}}},Qc=function(a){if(a.level)return a.level;if(a.parent)return Qc(a.parent);Ga("Root logger has no level set.");return Hc},Rc=function(a,b){for(;a;)a.mj.forEach(function(c){c(b)}),a=a.parent},Sc=function(){this.entries={};var a=new Pc("");a.level=Kc;this.entries[""]=a},Tc,Uc=function(a,b){var c=a.entries[b];if(c)return c;c=Uc(a,b.slice(0,Math.max(b.lastIndexOf("."),
0)));var d=new Pc(b,c);a.entries[b]=d;c.children.push(d);return d},Vc=function(){Tc||(Tc=new Sc);return Tc},Wc=function(a,b,c){var d;if(d=a)if(d=a&&b){d=b.value;var e=a?Qc(Uc(Vc(),a.getName())):Hc;d=d>=e.value}if(d){b=b||Hc;d=Uc(Vc(),a.getName());typeof c==="function"&&(c=c());Nc||(Nc=new Mc);e=Nc;a=a.getName();if(e.Od>0){var f=(e.Mg+1)%e.Od;e.Mg=f;e.nh?(e=e.Ag[f],e.reset(b,c,a),a=e):(e.nh=f==e.Od-1,a=e.Ag[f]=new Oc(b,c,a))}else a=new Oc(b,c,a);Rc(d,a)}},Xc=function(a,b){a&&Wc(a,Lc,b)};function Yc(a){if(typeof a!=="string"||a.trim()==="")throw Error("Calls to uncheckedconversion functions must go through security review. A justification must be provided to capture what security assumptions are being made. See go/unchecked-conversions");};var Zc=function(a,b){for(var c=a.split("%s"),d="",e=Array.prototype.slice.call(arguments,1);e.length&&c.length>1;)d+=c.shift()+e.shift();return d+c.join("%s")};var $c="src srcdoc codebase data href rel action formaction sandbox icon".split(" ");function ad(a){if(a instanceof yc)return a;a=String(a).replace(/&/g,"&amp;").replace(/</g,"&lt;").replace(/>/g,"&gt;").replace(/"/g,"&quot;").replace(/'/g,"&apos;");return zc(a)};function bd(a){var b=sa.apply(1,arguments);hc(a,b.length);if(b.length===0)return Yb(a[0]);var c=a[0].toLowerCase();if(/^data:/.test(c))throw Error("Data URLs cannot have expressions in the template literal input.");if(/^https:\/\//.test(c)||/^\/\//.test(c)){var d=c.indexOf("//")+2;var e=c.indexOf("/",d);if(e<=d)throw Error("Can't interpolate data in a url's origin, Please make sure to fully specify the origin, terminated with '/'.");d=c.substring(d,e);if(!/^[0-9a-z.:-]+$/i.test(d))throw Error("The origin contains unsupported characters.");
if(!/^[^:]*(:[0-9]+)?$/i.test(d))throw Error("Invalid port number.");if(!/(^|\.)[a-z][^.]*$/i.test(d))throw Error("The top-level domain must start with a letter.");d=!0}else d=!1;if(!d)if(/^\//.test(c))if(c==="/"||c.length>1&&c[1]!=="/"&&c[1]!=="\\")d=!0;else throw Error("The path start in the url is invalid.");else d=!1;if(!(d=d||RegExp("^[^:\\s\\\\/]+/").test(c)))if(/^about:blank/.test(c)){if(c!=="about:blank"&&!/^about:blank#/.test(c))throw Error("The about url is invalid.");d=!0}else d=!1;if(!d)throw Error("Trying to interpolate expressions in an unsupported url format.");
c=a[0];for(d=0;d<b.length;d++)c+=encodeURIComponent(b[d])+a[d+1];return Yb(c)};function cd(a,b){for(var c in a)b.call(void 0,a[c],c,a)}function dd(a,b){for(var c in a)if(b.call(void 0,a[c],c,a))return!0;return!1}function ed(a){for(var b in a)return!1;return!0}function fd(a){var b={},c;for(c in a)b[c]=a[c];return b}var gd="constructor hasOwnProperty isPrototypeOf propertyIsEnumerable toLocaleString toString valueOf".split(" ");
function hd(a,b){for(var c,d,e=1;e<arguments.length;e++){d=arguments[e];for(c in d)a[c]=d[c];for(var f=0;f<gd.length;f++)c=gd[f],Object.prototype.hasOwnProperty.call(d,c)&&(a[c]=d[c])}};var id=function(a){if(a.ob&&typeof a.ob=="function")return a.ob();if(typeof Map!=="undefined"&&a instanceof Map||typeof Set!=="undefined"&&a instanceof Set)return Array.from(a.values());if(typeof a==="string")return a.split("");if(xa(a)){for(var b=[],c=a.length,d=0;d<c;d++)b.push(a[d]);return b}b=[];c=0;for(d in a)b[c++]=a[d];return b},jd=function(a){if(a.Yd&&typeof a.Yd=="function")return a.Yd();if(!a.ob||typeof a.ob!="function"){if(typeof Map!=="undefined"&&a instanceof Map)return Array.from(a.keys());
if(!(typeof Set!=="undefined"&&a instanceof Set)){if(xa(a)||typeof a==="string"){var b=[];a=a.length;for(var c=0;c<a;c++)b.push(c);return b}b=[];c=0;for(var d in a)b[c++]=d;return b}}},kd=function(a,b,c){if(a.forEach&&typeof a.forEach=="function")a.forEach(b,c);else if(xa(a)||typeof a==="string")Array.prototype.forEach.call(a,b,c);else for(var d=jd(a),e=id(a),f=e.length,g=0;g<f;g++)b.call(c,e[g],d&&d[g],a)};var ld=RegExp("^(?:([^:/?#.]+):)?(?://(?:([^\\\\/?#]*)@)?([^\\\\/?#]*?)(?::([0-9]+))?(?=[\\\\/?#]|$))?([^?#]+)?(?:\\?([^#]*))?(?:#([\\s\\S]*))?$"),md=function(a,b){if(a){a=a.split("&");for(var c=0;c<a.length;c++){var d=a[c].indexOf("="),e=null;if(d>=0){var f=a[c].substring(0,d);e=a[c].substring(d+1)}else f=a[c];b(f,e?decodeURIComponent(e.replace(/\+/g," ")):"")}}};var nd=function(a){this.ga=this.Wb=this.ua="";this.Sa=null;this.ic=this.eb="";this.Ba=this.wj=!1;if(a instanceof nd){this.Ba=a.Ba;od(this,a.ua);var b=a.Wb;pd(this);this.Wb=b;qd(this,a.ga);rd(this,a.Sa);sd(this,a.eb);td(this,a.ya.clone());ud(this,a.ic)}else a&&(b=String(a).match(ld))?(this.Ba=!1,od(this,b[1]||"",!0),a=b[2]||"",pd(this),this.Wb=vd(a),qd(this,b[3]||"",!0),rd(this,b[4]),sd(this,b[5]||"",!0),td(this,b[6]||"",!0),ud(this,b[7]||"",!0)):(this.Ba=!1,this.ya=new wd(null,this.Ba))};
nd.prototype.toString=function(){var a=[],b=this.ua;b&&a.push(xd(b,yd,!0),":");var c=this.ga;if(c||b=="file")a.push("//"),(b=this.Wb)&&a.push(xd(b,yd,!0),"@"),a.push(encodeURIComponent(String(c)).replace(/%25([0-9a-fA-F]{2})/g,"%$1")),c=this.Sa,c!=null&&a.push(":",String(c));if(c=this.eb)this.ga&&c.charAt(0)!="/"&&a.push("/"),a.push(xd(c,c.charAt(0)=="/"?zd:Ad,!0));(c=this.ya.toString())&&a.push("?",c);(c=this.ic)&&a.push("#",xd(c,Bd));return a.join("")};
nd.prototype.resolve=function(a){var b=this.clone(),c=!!a.ua;c?od(b,a.ua):c=!!a.Wb;if(c){var d=a.Wb;pd(b);b.Wb=d}else c=!!a.ga;c?qd(b,a.ga):c=a.Sa!=null;d=a.eb;if(c)rd(b,a.Sa);else if(c=!!a.eb){if(d.charAt(0)!="/")if(this.ga&&!this.eb)d="/"+d;else{var e=b.eb.lastIndexOf("/");e!=-1&&(d=b.eb.slice(0,e+1)+d)}e=d;if(e==".."||e==".")d="";else if(A(e,"./")||A(e,"/.")){d=e.lastIndexOf("/",0)==0;e=e.split("/");for(var f=[],g=0;g<e.length;){var h=e[g++];h=="."?d&&g==e.length&&f.push(""):h==".."?((f.length>
1||f.length==1&&f[0]!="")&&f.pop(),d&&g==e.length&&f.push("")):(f.push(h),d=!0)}d=f.join("/")}else d=e}c?sd(b,d):c=a.ya.toString()!=="";c?td(b,a.ya.clone()):c=!!a.ic;c&&ud(b,a.ic);return b};nd.prototype.clone=function(){return new nd(this)};
var od=function(a,b,c){pd(a);a.ua=c?vd(b,!0):b;a.ua&&(a.ua=a.ua.replace(/:$/,""))},qd=function(a,b,c){pd(a);a.ga=c?vd(b,!0):b},rd=function(a,b){pd(a);if(b){b=Number(b);if(isNaN(b)||b<0)throw Error("Bad port number "+b);a.Sa=b}else a.Sa=null},sd=function(a,b,c){pd(a);a.eb=c?vd(b,!0):b;return a},td=function(a,b,c){pd(a);b instanceof wd?(a.ya=b,a.ya.jg(a.Ba)):(c||(b=xd(b,Cd)),a.ya=new wd(b,a.Ba));return a};nd.prototype.getQuery=function(){return this.ya.toString()};
var D=function(a,b,c){pd(a);a.ya.set(b,c)},E=function(a,b){return a.ya.get(b)},ud=function(a,b,c){pd(a);a.ic=c?vd(b):b;return a};nd.prototype.removeParameter=function(a){pd(this);this.ya.remove(a);return this};var pd=function(a){if(a.wj)throw Error("Tried to modify a read-only Uri");};nd.prototype.jg=function(a){this.Ba=a;this.ya&&this.ya.jg(a)};
var F=function(a){return a instanceof nd?a.clone():new nd(a)},Dd=function(a,b,c,d,e,f){var g=new nd(null);a&&od(g,a);b&&qd(g,b);c&&rd(g,c);d&&sd(g,d);e&&td(g,e);f&&ud(g,f);return g},vd=function(a,b){return a?b?decodeURI(a.replace(/%25/g,"%2525")):decodeURIComponent(a):""},xd=function(a,b,c){return typeof a==="string"?(a=encodeURI(a).replace(b,Ed),c&&(a=a.replace(/%25([0-9a-fA-F]{2})/g,"%$1")),a):null},Ed=function(a){a=a.charCodeAt(0);return"%"+(a>>4&15).toString(16)+(a&15).toString(16)},yd=/[#\/\?@]/g,
Ad=/[#\?:]/g,zd=/[#\?]/g,Cd=/[#\?@]/g,Bd=/#/g,wd=function(a,b){this.ea=this.M=null;this.va=a||null;this.Ba=!!b},Fd=function(a){a.M||(a.M=new Map,a.ea=0,a.va&&md(a.va,function(b,c){a.add(decodeURIComponent(b.replace(/\+/g," ")),c)}))},Hd=function(a){var b=jd(a);if(typeof b=="undefined")throw Error("Keys are undefined");var c=new wd(null);a=id(a);for(var d=0;d<b.length;d++){var e=b[d],f=a[d];Array.isArray(f)?Gd(c,e,f):c.add(e,f)}return c};l=wd.prototype;
l.add=function(a,b){Fd(this);this.va=null;a=this.wa(a);var c=this.M.get(a);c||this.M.set(a,c=[]);c.push(b);this.ea=Ha(this.ea)+1;return this};l.remove=function(a){Fd(this);a=this.wa(a);return this.M.has(a)?(this.va=null,this.ea=Ha(this.ea)-this.M.get(a).length,this.M.delete(a)):!1};l.clear=function(){this.M=this.va=null;this.ea=0};l.mh=function(){Fd(this);return this.ea==0};l.Nc=function(a){Fd(this);a=this.wa(a);return this.M.has(a)};
l.forEach=function(a,b){Fd(this);this.M.forEach(function(c,d){c.forEach(function(e){a.call(b,e,d,this)},this)},this)};l.Yd=function(){Fd(this);for(var a=Array.from(this.M.values()),b=Array.from(this.M.keys()),c=[],d=0;d<b.length;d++)for(var e=a[d],f=0;f<e.length;f++)c.push(b[d]);return c};l.ob=function(a){Fd(this);var b=[];if(typeof a==="string")this.Nc(a)&&(b=b.concat(this.M.get(this.wa(a))));else{a=Array.from(this.M.values());for(var c=0;c<a.length;c++)b=b.concat(a[c])}return b};
l.set=function(a,b){Fd(this);this.va=null;a=this.wa(a);this.Nc(a)&&(this.ea=Ha(this.ea)-this.M.get(a).length);this.M.set(a,[b]);this.ea=Ha(this.ea)+1;return this};l.get=function(a,b){if(!a)return b;a=this.ob(a);return a.length>0?String(a[0]):b};var Gd=function(a,b,c){a.remove(b);c.length>0&&(a.va=null,a.M.set(a.wa(b),mb(c)),a.ea=Ha(a.ea)+c.length)};l=wd.prototype;
l.toString=function(){if(this.va)return this.va;if(!this.M)return"";for(var a=[],b=Array.from(this.M.keys()),c=0;c<b.length;c++){var d=b[c],e=encodeURIComponent(String(d));d=this.ob(d);for(var f=0;f<d.length;f++){var g=e;d[f]!==""&&(g+="="+encodeURIComponent(String(d[f])));a.push(g)}}return this.va=a.join("&")};l.clone=function(){var a=new wd;a.va=this.va;this.M&&(a.M=new Map(this.M),a.ea=this.ea);return a};l.wa=function(a){a=String(a);this.Ba&&(a=a.toLowerCase());return a};
l.jg=function(a){a&&!this.Ba&&(Fd(this),this.va=null,this.M.forEach(function(b,c){var d=c.toLowerCase();c!=d&&(this.remove(c),Gd(this,d,b))},this));this.Ba=a};l.extend=function(a){for(var b=0;b<arguments.length;b++)kd(arguments[b],function(c,d){this.add(d,c)},this)};var Id={kl:!0},Jd=function(){throw Error("Do not instantiate directly");};Jd.prototype.Hg=null;Jd.prototype.toString=function(){return this.content};Jd.prototype.ki=function(){if(this.Ig!==Id)throw Error("Sanitized content was not of kind HTML.");var a=this.toString();Yc("Soy SanitizedContent of kind HTML produces SafeHtml-contract-compliant value.");return zc(a)};var Kd=function(){Jd.call(this)};x(Kd,Jd);Kd.prototype.Ig=Id;var Ld=function(a){if(a!=null)switch(a.Hg){case 1:return 1;case -1:return-1;case 0:return 0}return null},Qd=function(a){return Md(a)?a:a instanceof yc?Nd(Ac(a).toString()):Nd(String(String(a)).replace(Od,Pd),Ld(a))},Nd=function(a){function b(c){this.content=c}b.prototype=a.prototype;return function(c,d){c=new b(String(c));d!==void 0&&(c.Hg=d);return c}}(Kd),Rd={},Ud=function(a){return Sd(String(a),function(){return""}).replace(Td,"&lt;")},Vd=RegExp.prototype.hasOwnProperty("sticky"),Wd=new RegExp((Vd?
"":"^")+"(?:!|/?([a-zA-Z][a-zA-Z0-9:-]*))",Vd?"gy":"g");
function Sd(a,b){for(var c=[],d=a.length,e=0,f=[],g,h,k=0;k<d;){switch(e){case 0:var m=a.indexOf("<",k);if(m<0){if(c.length===0)return a;c.push(a.substring(k));k=d}else c.push(a.substring(k,m)),h=m,k=m+1,Vd?(Wd.lastIndex=k,m=Wd.exec(a)):(Wd.lastIndex=0,m=Wd.exec(a.substring(k))),m?(f=["<",m[0]],g=m[1],e=1,k+=m[0].length):c.push("<");break;case 1:m=a.charAt(k++);switch(m){case "'":case '"':var n=a.indexOf(m,k);n<0?k=d:(f.push(m,a.substring(k,n+1)),k=n+1);break;case ">":f.push(m);c.push(b(f.join(""),
g));e=0;f=[];h=g=null;break;default:f.push(m)}break;default:throw Error();}e===1&&k>=d&&(k=h+1,c.push("<"),e=0,f=[],h=g=null)}return c.join("")}
var G=function(a){return Md(a)?String(Ud(a.content)).replace(Xd,Pd):String(a).replace(Od,Pd)},Yd=function(a,b,c,d){a||(a=c instanceof Function?c.displayName||c.name||"unknown type name":c instanceof Object?c.constructor.displayName||c.constructor.name||Object.prototype.toString.call(c):c===null?"null":typeof c,Ga("expected @param "+b+" of type "+d+", but got "+a+"."),Ga("parameter type error. Enable DEBUG to see details."));return c},Zd={},$d=function(){z(Zd===Zd,"found an incorrect call marker, was an internal function called from the top level?")},
Md=function(a){var b=a!=null&&a.Ig===Id;b&&Kd&&z(a.constructor===Kd);return b},ae={"\x00":"&#0;","\t":"&#9;","\n":"&#10;","\v":"&#11;","\f":"&#12;","\r":"&#13;"," ":"&#32;",'"':"&quot;","&":"&amp;","'":"&#39;","-":"&#45;","/":"&#47;","<":"&lt;","=":"&#61;",">":"&gt;","`":"&#96;","\u0085":"&#133;","\u00a0":"&#160;","\u2028":"&#8232;","\u2029":"&#8233;"},Pd=function(a){return ae[a]},Od=/[\x00\x22\x26\x27\x3c\x3e]/g,Xd=/[\x00\x22\x27\x3c\x3e]/g,Td=/</g;function be(){};(function(){var a=u.jspbGetTypeName;u.jspbGetTypeName=a?function(b){return a(b)||void 0}:be})();var ce=ra(["data-soyloggingfunction-"]);
(function(a){hc(a,0);var b=a[0].toLowerCase();if(b.indexOf("on")===0||"on".indexOf(b)===0)throw Error("Prefix '"+a[0]+"' does not guarantee the attribute to be safe as it is also a prefix for event handler attributesPlease use 'addEventListener' to set event handlers.");$c.forEach(function(c){if(c.indexOf(b)===0)throw Error("Prefix '"+a[0]+"' does not guarantee the attribute to be safe as it is also a prefix for the security sensitive attribute '"+(c+"'. Please use native or safe DOM APIs to set the attribute."));});
return new Ec(b)})(ce);var fe=function(a,b){this.ii=a===de&&b||"";this.Di=ee};fe.prototype.toString=function(){return this.ii};var ee={},de={};var ge=function(a){var b=document;return typeof a==="string"?b.getElementById(a):a},ie=function(a,b){cd(b,function(c,d){d=="style"?a.style.cssText=c:d=="class"?a.className=c:d=="for"?a.htmlFor=c:he.hasOwnProperty(d)?a.setAttribute(he[d],c):d.lastIndexOf("aria-",0)==0||d.lastIndexOf("data-",0)==0?a.setAttribute(d,c):a[d]=c})},he={cellpadding:"cellPadding",cellspacing:"cellSpacing",colspan:"colSpan",frameborder:"frameBorder",height:"height",maxlength:"maxLength",nonce:"nonce",role:"role",rowspan:"rowSpan",
type:"type",usemap:"useMap",valign:"vAlign",width:"width"},ke=function(a,b,c){return je(document,arguments)},je=function(a,b){var c=b[1],d=le(a,String(b[0]));c&&(typeof c==="string"?d.className=c:Array.isArray(c)?d.className=c.join(" "):ie(d,c));b.length>2&&me(a,d,b,2);return d},me=function(a,b,c,d){function e(h){h&&b.appendChild(typeof h==="string"?a.createTextNode(h):h)}for(;d<c.length;d++){var f=c[d];if(!xa(f)||v(f)&&f.nodeType>0)e(f);else{a:{if(f&&typeof f.length=="number"){if(v(f)){var g=typeof f.item==
"function"||typeof f.item=="string";break a}if(typeof f==="function"){g=typeof f.item=="function";break a}}g=!1}C(g?mb(f):f,e)}}},le=function(a,b){b=String(b);a.contentType==="application/xhtml+xml"&&(b=b.toLowerCase());return a.createElement(b)},ne=function(a,b){z(a!=null&&b!=null,"goog.dom.appendChild expects non-null arguments");a.appendChild(b)},oe=function(a){for(var b;b=a.firstChild;)a.removeChild(b)},pe=function(a){return a&&a.parentNode?a.parentNode.removeChild(a):null},qe=function(){var a=
document.body;if(a.lastElementChild!==void 0)a=a.lastElementChild;else for(a=a.lastChild;a&&a.nodeType!=1;)a=a.previousSibling;return a},re=function(a){z(a,"Node cannot be null or undefined.");return a.nodeType==9?a:a.ownerDocument||a.document},te=function(a,b){z(a!=null,"goog.dom.setTextContent expects a non-null value for node");if("textContent"in a)a.textContent=b;else if(a.nodeType==3)a.data=String(b);else if(a.firstChild&&a.firstChild.nodeType==3){for(;a.lastChild!=a.firstChild;)a.removeChild(z(a.lastChild));
a.firstChild.data=String(b)}else{oe(a);var c=re(a);a.appendChild(c.createTextNode(String(b)))}},ue={SCRIPT:1,STYLE:1,HEAD:1,IFRAME:1,OBJECT:1},ve={IMG:" ",BR:"\n"},xe=function(a){var b=[];we(a,b,!0);a=b.join("");a=a.replace(/ \xAD /g," ").replace(/\xAD/g,"");a=a.replace(/\u200B/g,"");a=a.replace(/ +/g," ");a!=" "&&(a=a.replace(/^\s*/,""));return a},we=function(a,b,c){if(!(a.nodeName in ue))if(a.nodeType==3)c?b.push(String(a.nodeValue).replace(/(\r\n|\r|\n)/g,"")):b.push(a.nodeValue);else if(a.nodeName in
ve)b.push(ve[a.nodeName]);else for(a=a.firstChild;a;)we(a,b,c),a=a.nextSibling},ye=function(a){this.ab=a||u.document||document};ye.prototype.getElementsByTagName=function(a,b){return(b||this.ab).getElementsByTagName(String(a))};var ze=function(a,b){a=a.ab;return(b=b&&b!="*"?String(b).toUpperCase():"")?a.querySelectorAll(b+""):a.getElementsByTagName("*")};l=ye.prototype;l.Kg=function(a,b,c){return je(this.ab,arguments)};l.createElement=function(a){return le(this.ab,a)};l.createTextNode=function(a){return this.ab.createTextNode(String(a))};
l.getWindow=function(){return this.ab.defaultView};l.appendChild=ne;l.append=function(a,b){me(re(a),a,arguments,1)};l.canHaveChildren=function(a){if(a.nodeType!=1)return!1;switch(a.tagName){case "APPLET":case "AREA":case "BASE":case "BR":case "COL":case "COMMAND":case "EMBED":case "FRAME":case "HR":case "IMG":case "INPUT":case "IFRAME":case "ISINDEX":case "KEYGEN":case "LINK":case "NOFRAMES":case "NOSCRIPT":case "META":case "OBJECT":case "PARAM":case "SCRIPT":case "SOURCE":case "STYLE":case "TRACK":case "WBR":return!1}return!0};
l.removeNode=pe;l.contains=function(a,b){if(!a||!b)return!1;if(a.contains&&b.nodeType==1)return a==b||a.contains(b);if(typeof a.compareDocumentPosition!="undefined")return a==b||!!(a.compareDocumentPosition(b)&16);for(;b&&a!=b;)b=b.parentNode;return b==a};/*
 Copyright The Closure Library Authors.
 SPDX-License-Identifier: Apache-2.0
*/
var Ae=/^<(body|caption|col|colgroup|head|html|tr|td|th|tbody|thead|tfoot)>/i,Be={};Uc(Vc(),"api_idom");var Ce=function(a,b){return Rd["fireauth.oauthhelper.ui.soy.pendingScreen"]?Rd["fireauth.oauthhelper.ui.soy.pendingScreen"](a,b):Nd('<div id="pending-screen"><div id="progressBar" class="'+G("mdl-progress")+" "+G("mdl-js-progress")+" "+G("mdl-progress__indeterminate")+" "+G("firebase-progress-bar")+'"></div></div>')},De=function(a,b){a=a||{};a=a.appName;$d();Rd["fireauth.oauthhelper.ui.soy.continueScreen"]?b=Rd["fireauth.oauthhelper.ui.soy.continueScreen"]({appName:a},b):(a=Yd(a==null||typeof a===
"string","appName",a,"null|string|undefined"),b='<div id="continue-screen" class="'+G("mdl-card")+" "+G("mdl-shadow--2dp")+" "+G("firebase-container")+'"><button id="continue" class="'+G("mdl-button")+" "+G("mdl-button--raised")+" "+G("mdl-button--colored")+'">',a?(a="Continue to "+Qd(a),b+=a):b+="Continue to the app",b=Nd(b+"</button></div>"));return b},Ee=function(a,b){a=a.errorMessage;$d();Rd["fireauth.oauthhelper.ui.soy.errorScreen"]?b=Rd["fireauth.oauthhelper.ui.soy.errorScreen"]({errorMessage:a},
b):(b=Yd(typeof a==="string","errorMessage",a,"string"),b=Nd('<div id="error-screen" class="'+G("mdl-card")+" "+G("mdl-shadow--2dp")+" "+G("firebase-container")+'">'+Qd(b)+"</div>"));return b},Fe=function(a,b){if(Rd["fireauth.oauthhelper.ui.soy.appVerificationScreen"])return Rd["fireauth.oauthhelper.ui.soy.appVerificationScreen"](a,b);a='<div id="app-verification-screen" class="'+G("mdl-card")+" "+G("mdl-shadow--2dp")+" "+G("firebase-container")+'"><button id="verify" class="'+G("mdl-button")+" "+
G("firebase-hidden-button")+'">';return Nd(a+'Verify</button><div id="status-container"><h1 class="firebase-title" id="status-container-label">Verifying you\'re not a robot...</h1><div id="app-verification-progress-bar" class="mdl-progress mdl-js-progress mdl-progress__indeterminate firebase-middle-progress-bar"></div></div></div>')};function Ge(){this.blockSize=-1};function He(a,b){this.blockSize=-1;this.blockSize=64;this.Qd=u.Uint8Array?new Uint8Array(this.blockSize):Array(this.blockSize);this.Qe=this.nc=0;this.F=[];this.Gj=a;this.kh=b;this.Ak=u.Int32Array?new Int32Array(64):Array(64);Ie===void 0&&(Ie=u.Int32Array?new Int32Array(Je):Je);this.reset()}x(He,Ge);for(var Ke=[],Le=0;Le<63;Le++)Ke[Le]=0;var Me=[].concat(128,Ke);He.prototype.reset=function(){this.Qe=this.nc=0;this.F=u.Int32Array?new Int32Array(this.kh):mb(this.kh)};
var Ne=function(a){var b=a.Qd;z(b.length==a.blockSize);for(var c=a.Ak,d=0,e=0;e<b.length;)c[d++]=b[e]<<24|b[e+1]<<16|b[e+2]<<8|b[e+3],e=d*4;for(b=16;b<64;b++)d=c[b-15]|0,e=c[b-2]|0,c[b]=((c[b-16]|0)+((d>>>7|d<<25)^(d>>>18|d<<14)^d>>>3)|0)+((c[b-7]|0)+((e>>>17|e<<15)^(e>>>19|e<<13)^e>>>10)|0)|0;b=a.F[0]|0;d=a.F[1]|0;e=a.F[2]|0;for(var f=a.F[3]|0,g=a.F[4]|0,h=a.F[5]|0,k=a.F[6]|0,m=a.F[7]|0,n=0;n<64;n++){var r=((b>>>2|b<<30)^(b>>>13|b<<19)^(b>>>22|b<<10))+(b&d^b&e^d&e)|0,t=(m+((g>>>6|g<<26)^(g>>>11|
g<<21)^(g>>>25|g<<7))|0)+(((g&h^~g&k)+(Ie[n]|0)|0)+(c[n]|0)|0)|0;m=k;k=h;h=g;g=f+t|0;f=e;e=d;d=b;b=t+r|0}a.F[0]=a.F[0]+b|0;a.F[1]=a.F[1]+d|0;a.F[2]=a.F[2]+e|0;a.F[3]=a.F[3]+f|0;a.F[4]=a.F[4]+g|0;a.F[5]=a.F[5]+h|0;a.F[6]=a.F[6]+k|0;a.F[7]=a.F[7]+m|0};
He.prototype.update=function(a,b){b===void 0&&(b=a.length);var c=0,d=this.nc;if(typeof a==="string")for(;c<b;)this.Qd[d++]=a.charCodeAt(c++),d==this.blockSize&&(Ne(this),d=0);else if(xa(a))for(;c<b;){var e=a[c++];if(!("number"==typeof e&&0<=e&&255>=e&&e==(e|0)))throw Error("message must be a byte array");this.Qd[d++]=e;d==this.blockSize&&(Ne(this),d=0)}else throw Error("message must be string or array");this.nc=d;this.Qe+=b};
He.prototype.digest=function(){var a=[],b=this.Qe*8;this.nc<56?this.update(Me,56-this.nc):this.update(Me,this.blockSize-(this.nc-56));for(var c=63;c>=56;c--)this.Qd[c]=b&255,b/=256;Ne(this);for(c=b=0;c<this.Gj;c++)for(var d=24;d>=0;d-=8)a[b++]=this.F[c]>>d&255;return a};
var Je=[1116352408,1899447441,3049323471,3921009573,961987163,1508970993,2453635748,2870763221,3624381080,310598401,607225278,1426881987,1925078388,2162078206,2614888103,3248222580,3835390401,4022224774,264347078,604807628,770255983,1249150122,1555081692,1996064986,2554220882,2821834349,2952996808,3210313671,3336571891,3584528711,113926993,338241895,666307205,773529912,1294757372,1396182291,1695183700,1986661051,2177026350,2456956037,2730485921,2820302411,3259730800,3345764771,3516065817,3600352804,
4094571909,275423344,430227734,506948616,659060556,883997877,958139571,1322822218,1537002063,1747873779,1955562222,2024104815,2227730452,2361852424,2428436474,2756734187,3204031479,3329325298],Ie;function Oe(){He.call(this,8,Pe)}x(Oe,He);var Pe=[1779033703,3144134277,1013904242,2773480762,1359893119,2600822924,528734635,1541459225];var Qe=function(){this.Tc=this.Tc;this.ue=this.ue};Qe.prototype.Tc=!1;Qe.prototype.isDisposed=function(){return this.Tc};Qe.prototype.dispose=function(){this.Tc||(this.Tc=!0,this.Sc())};Qe.prototype[Symbol.dispose]=function(){this.dispose()};Qe.prototype.Sc=function(){if(this.ue)for(;this.ue.length;)this.ue.shift()()};var H=function(a,b){this.type=a;this.currentTarget=this.target=b;this.defaultPrevented=this.nd=!1};H.prototype.stopPropagation=function(){this.nd=!0};H.prototype.preventDefault=function(){this.defaultPrevented=!0};var Re=function(){if(!u.addEventListener||!Object.defineProperty)return!1;var a=!1,b=Object.defineProperty({},"passive",{get:function(){a=!0}});try{var c=function(){};u.addEventListener("test",c,b);u.removeEventListener("test",c,b)}catch(d){}return a}();var Se=function(a,b){H.call(this,a?a.type:"");this.relatedTarget=this.currentTarget=this.target=null;this.button=this.screenY=this.screenX=this.clientY=this.clientX=this.offsetY=this.offsetX=0;this.key="";this.charCode=this.keyCode=0;this.metaKey=this.shiftKey=this.altKey=this.ctrlKey=!1;this.state=null;this.pointerId=0;this.pointerType="";this.timeStamp=0;this.qa=null;a&&this.init(a,b)};x(Se,H);
Se.prototype.init=function(a,b){var c=this.type=a.type,d=a.changedTouches&&a.changedTouches.length?a.changedTouches[0]:null;this.target=a.target||a.srcElement;this.currentTarget=b;b=a.relatedTarget;b||(c=="mouseover"?b=a.fromElement:c=="mouseout"&&(b=a.toElement));this.relatedTarget=b;d?(this.clientX=d.clientX!==void 0?d.clientX:d.pageX,this.clientY=d.clientY!==void 0?d.clientY:d.pageY,this.screenX=d.screenX||0,this.screenY=d.screenY||0):(this.offsetX=rb||a.offsetX!==void 0?a.offsetX:a.layerX,this.offsetY=
rb||a.offsetY!==void 0?a.offsetY:a.layerY,this.clientX=a.clientX!==void 0?a.clientX:a.pageX,this.clientY=a.clientY!==void 0?a.clientY:a.pageY,this.screenX=a.screenX||0,this.screenY=a.screenY||0);this.button=a.button;this.keyCode=a.keyCode||0;this.key=a.key||"";this.charCode=a.charCode||(c=="keypress"?a.keyCode:0);this.ctrlKey=a.ctrlKey;this.altKey=a.altKey;this.shiftKey=a.shiftKey;this.metaKey=a.metaKey;this.pointerId=a.pointerId||0;this.pointerType=a.pointerType;this.state=a.state;this.timeStamp=
a.timeStamp;this.qa=a;a.defaultPrevented&&Se.Dc.preventDefault.call(this)};Se.prototype.stopPropagation=function(){Se.Dc.stopPropagation.call(this);this.qa.stopPropagation?this.qa.stopPropagation():this.qa.cancelBubble=!0};Se.prototype.preventDefault=function(){Se.Dc.preventDefault.call(this);var a=this.qa;a.preventDefault?a.preventDefault():a.returnValue=!1};Se.prototype.Xi=function(){return this.qa};var Te="closure_listenable_"+(Math.random()*1E6|0);var Ue=0;var Ve=function(a,b,c,d,e){this.listener=a;this.proxy=null;this.src=b;this.type=c;this.capture=!!d;this.be=e;this.key=++Ue;this.sd=this.Md=!1},We=function(a){a.sd=!0;a.listener=null;a.proxy=null;a.src=null;a.be=null};function Xe(a){this.src=a;this.ia={};this.Ad=0}Xe.prototype.add=function(a,b,c,d,e){var f=a.toString();a=this.ia[f];a||(a=this.ia[f]=[],this.Ad++);var g=Ye(a,b,d,e);g>-1?(b=a[g],c||(b.Md=!1)):(b=new Ve(b,this.src,f,!!d,e),b.Md=c,a.push(b));return b};Xe.prototype.remove=function(a,b,c,d){a=a.toString();if(!(a in this.ia))return!1;var e=this.ia[a];b=Ye(e,b,c,d);return b>-1?(We(e[b]),kb(e,b),e.length==0&&(delete this.ia[a],this.Ad--),!0):!1};
var Ze=function(a,b){var c=b.type;c in a.ia&&ib(a.ia[c],b)&&(We(b),a.ia[c].length==0&&(delete a.ia[c],a.Ad--))};Xe.prototype.yf=function(a,b,c,d){a=this.ia[a.toString()];var e=-1;a&&(e=Ye(a,b,c,d));return e>-1?a[e]:null};Xe.prototype.hasListener=function(a,b){var c=a!==void 0,d=c?a.toString():"",e=b!==void 0;return dd(this.ia,function(f){for(var g=0;g<f.length;++g)if(!(c&&f[g].type!=d||e&&f[g].capture!=b))return!0;return!1})};
var Ye=function(a,b,c,d){for(var e=0;e<a.length;++e){var f=a[e];if(!f.sd&&f.listener==b&&f.capture==!!c&&f.be==d)return e}return-1};var $e="closure_lm_"+(Math.random()*1E6|0),af={},bf=0,df=function(a,b,c,d,e){if(d&&d.once)return cf(a,b,c,d,e);if(Array.isArray(b)){for(var f=0;f<b.length;f++)df(a,b[f],c,d,e);return null}c=ef(c);return a&&a[Te]?a.listen(b,c,v(d)?!!d.capture:!!d,e):ff(a,b,c,!1,d,e)},ff=function(a,b,c,d,e,f){if(!b)throw Error("Invalid event type");var g=v(e)?!!e.capture:!!e,h=gf(a);h||(a[$e]=h=new Xe(a));c=h.add(b,c,d,g,f);if(c.proxy)return c;d=hf();c.proxy=d;d.src=a;d.listener=c;if(a.addEventListener)Re||(e=g),e===
void 0&&(e=!1),a.addEventListener(b.toString(),d,e);else if(a.attachEvent)a.attachEvent(jf(b.toString()),d);else if(a.addListener&&a.removeListener)z(b==="change","MediaQueryList only has a change event"),a.addListener(d);else throw Error("addEventListener and attachEvent are unavailable.");bf++;return c},hf=function(){var a=kf,b=function(c){return a.call(b.src,b.listener,c)};return b},cf=function(a,b,c,d,e){if(Array.isArray(b)){for(var f=0;f<b.length;f++)cf(a,b[f],c,d,e);return null}c=ef(c);return a&&
a[Te]?lf(a,b,c,v(d)?!!d.capture:!!d,e):ff(a,b,c,!0,d,e)},mf=function(a,b,c,d,e){if(Array.isArray(b))for(var f=0;f<b.length;f++)mf(a,b[f],c,d,e);else d=v(d)?!!d.capture:!!d,c=ef(c),a&&a[Te]?a.Da.remove(String(b),c,d,e):a&&(a=gf(a))&&(b=a.yf(b,c,d,e))&&nf(b)},nf=function(a){if(typeof a!=="number"&&a&&!a.sd){var b=a.src;if(b&&b[Te])Ze(b.Da,a);else{var c=a.type,d=a.proxy;b.removeEventListener?b.removeEventListener(c,d,a.capture):b.detachEvent?b.detachEvent(jf(c),d):b.addListener&&b.removeListener&&b.removeListener(d);
bf--;(c=gf(b))?(Ze(c,a),c.Ad==0&&(c.src=null,b[$e]=null)):We(a)}}},jf=function(a){return a in af?af[a]:af[a]="on"+a},kf=function(a,b){if(a.sd)a=!0;else{b=new Se(b,this);var c=a.listener,d=a.be||a.src;a.Md&&nf(a);a=c.call(d,b)}return a},gf=function(a){a=a[$e];return a instanceof Xe?a:null},of="__closure_events_fn_"+(Math.random()*1E9>>>0),ef=function(a){z(a,"Listener can not be null.");if(typeof a==="function")return a;z(a.handleEvent,"An object listener must have handleEvent method.");a[of]||(a[of]=
function(b){return a.handleEvent(b)});return a[of]};var pf=function(){Qe.call(this);this.Da=new Xe(this);this.Ei=this;this.Sf=null};x(pf,Qe);pf.prototype[Te]=!0;l=pf.prototype;l.addEventListener=function(a,b,c,d){df(this,a,b,c,d)};l.removeEventListener=function(a,b,c,d){mf(this,a,b,c,d)};
l.dispatchEvent=function(a){qf(this);var b=this.Sf;if(b){var c=[];for(var d=1;b;b=b.Sf)c.push(b),z(++d<1E3,"infinite loop")}b=this.Ei;d=a.type||a;if(typeof a==="string")a=new H(a,b);else if(a instanceof H)a.target=a.target||b;else{var e=a;a=new H(d,b);hd(a,e)}e=!0;var f;if(c)for(f=c.length-1;!a.nd&&f>=0;f--){var g=a.currentTarget=c[f];e=rf(g,d,!0,a)&&e}a.nd||(g=a.currentTarget=b,e=rf(g,d,!0,a)&&e,a.nd||(e=rf(g,d,!1,a)&&e));if(c)for(f=0;!a.nd&&f<c.length;f++)g=a.currentTarget=c[f],e=rf(g,d,!1,a)&&
e;return e};l.Sc=function(){pf.Dc.Sc.call(this);if(this.Da){var a=this.Da,b=0,c;for(c in a.ia){for(var d=a.ia[c],e=0;e<d.length;e++)++b,We(d[e]);delete a.ia[c];a.Ad--}}this.Sf=null};l.listen=function(a,b,c,d){qf(this);return this.Da.add(String(a),b,!1,c,d)};
var lf=function(a,b,c,d,e){return a.Da.add(String(b),c,!0,d,e)},rf=function(a,b,c,d){b=a.Da.ia[String(b)];if(!b)return!0;b=b.concat();for(var e=!0,f=0;f<b.length;++f){var g=b[f];if(g&&!g.sd&&g.capture==c){var h=g.listener,k=g.be||g.src;g.Md&&Ze(a.Da,g);e=h.call(k,d)!==!1&&e}}return e&&!d.defaultPrevented};pf.prototype.yf=function(a,b,c,d){return this.Da.yf(String(a),b,c,d)};pf.prototype.hasListener=function(a,b){return this.Da.hasListener(a!==void 0?String(a):void 0,b)};
var qf=function(a){z(a.Da,"Event target is not initialized. Did you call the superclass (goog.events.EventTarget) constructor?")};function sf(){};var tf,uf=function(){};x(uf,sf);uf.prototype.Oc=function(){return new XMLHttpRequest};tf=new uf;function vf(){}x(vf,sf);vf.prototype.Oc=function(){var a=new XMLHttpRequest;if("withCredentials"in a)return a;if(typeof XDomainRequest!="undefined")return new wf;throw Error("Unsupported browser");};
var wf=function(){this.Na=new XDomainRequest;this.readyState=0;this.onreadystatechange=null;this.responseType=this.responseText=this.response="";this.status=-1;this.responseXML=null;this.statusText="";this.Na.onload=w(this.dj,this);this.Na.onerror=w(this.eh,this);this.Na.onprogress=w(this.ej,this);this.Na.ontimeout=w(this.ij,this)};l=wf.prototype;l.open=function(a,b,c){if(c!=null&&!c)throw Error("Only async requests are supported.");this.Na.open(a,b)};
l.send=function(a){if(a)if(typeof a=="string")this.Na.send(a);else throw Error("Only string data is supported");else this.Na.send()};l.abort=function(){this.Na.abort()};l.setRequestHeader=function(){};l.getResponseHeader=function(a){return a.toLowerCase()=="content-type"?this.Na.contentType:""};l.dj=function(){this.status=200;this.response=this.responseText=this.Na.responseText;xf(this,4)};l.eh=function(){this.status=500;this.response=this.responseText="";xf(this,4)};l.ij=function(){this.eh()};
l.ej=function(){this.status=200;xf(this,1)};var xf=function(a,b){a.readyState=b;if(a.onreadystatechange)a.onreadystatechange()};wf.prototype.getAllResponseHeaders=function(){return"content-type: "+this.Na.contentType};var yf=function(){},zf=function(a){return typeof a==="function"};var Af=function(a){this.Dd=a.Ck||null;this.xd=a.ll||!1;this.bc=this.Db=void 0};x(Af,sf);Af.prototype.Oc=function(){var a=new Bf(this.Dd,this.xd);this.Db&&a.hg(this.Db);this.bc&&a.Yh(this.bc);return a};Af.prototype.hg=function(a){this.Db=a};Af.prototype.Yh=function(a){this.bc=a};
var Bf=function(a,b){pf.call(this);this.Dd=a;this.xd=b;this.bc=this.Db=void 0;this.status=this.readyState=0;this.responseType=this.responseText=this.response=this.statusText="";this.onreadystatechange=this.responseXML=null;this.dg=new Headers;this.Bc=null;this.xh="GET";this.Vb="";this.Qa=!1;this.P=Uc(Vc(),"goog.net.FetchXmlHttp").vh;this.pg=this.Pc=this.Vd=null};x(Bf,pf);
Bf.prototype.open=function(a,b,c){z(!!c,"Only async requests are supported.");if(this.readyState!=0)throw this.abort(),Error("Error reopening a connection");this.xh=a;this.Vb=b;this.readyState=1;Cf(this)};Bf.prototype.send=function(a){if(this.readyState!=1)throw this.abort(),Error("need to call open() first. ");this.Qa=!0;var b={headers:this.dg,method:this.xh,credentials:this.Db,cache:this.bc};a&&(b.body=a);(this.Dd||u).fetch(new Request(this.Vb,b)).then(this.hj.bind(this),this.ae.bind(this))};
Bf.prototype.abort=function(){var a=this;this.response=this.responseText="";this.dg=new Headers;this.status=0;this.Pc&&this.Pc.cancel("Request was aborted.").catch(function(){var b=a.P;b&&Wc(b,Jc,"Fetch reader cancellation error.")});this.readyState>=1&&this.Qa&&this.readyState!=4&&(this.Qa=!1,Df(this));this.readyState=0};
Bf.prototype.hj=function(a){if(this.Qa&&(this.Vd=a,this.Bc||(this.status=this.Vd.status,this.statusText=this.Vd.statusText,this.Bc=a.headers,this.readyState=2,Cf(this)),this.Qa&&(this.readyState=3,Cf(this),this.Qa)))if(this.responseType==="arraybuffer")a.arrayBuffer().then(this.fj.bind(this),this.ae.bind(this));else if(typeof u.ReadableStream!=="undefined"&&"body"in a){this.Pc=a.body.getReader();if(this.xd){if(this.responseType)throw Error('responseType must be empty for "streamBinaryChunks" mode responses.');
this.response=[]}else this.response=this.responseText="",this.pg=new TextDecoder;Ef(this)}else a.text().then(this.gj.bind(this),this.ae.bind(this))};var Ef=function(a){a.Pc.read().then(a.bj.bind(a)).catch(a.ae.bind(a))};Bf.prototype.bj=function(a){if(this.Qa){if(this.xd&&a.value)this.response.push(a.value);else if(!this.xd){var b=a.value?a.value:new Uint8Array(0);if(b=this.pg.decode(b,{stream:!a.done}))this.response=this.responseText+=b}a.done?Df(this):Cf(this);this.readyState==3&&Ef(this)}};
Bf.prototype.gj=function(a){this.Qa&&(this.response=this.responseText=a,Df(this))};Bf.prototype.fj=function(a){this.Qa&&(this.response=a,Df(this))};Bf.prototype.ae=function(){var a=this.P;a&&Wc(a,Jc,"Failed to fetch url "+this.Vb);this.Qa&&Df(this)};var Df=function(a){a.readyState=4;a.Vd=null;a.Pc=null;a.pg=null;Cf(a)};l=Bf.prototype;l.setRequestHeader=function(a,b){this.dg.append(a,b)};
l.getResponseHeader=function(a){return this.Bc?this.Bc.get(a.toLowerCase())||"":((a=this.P)&&Wc(a,Jc,"Attempting to get response header but no headers have been received for url: "+this.Vb),"")};l.getAllResponseHeaders=function(){if(!this.Bc){var a=this.P;a&&Wc(a,Jc,"Attempting to get all response headers but no headers have been received for url: "+this.Vb);return""}a=[];for(var b=this.Bc.entries(),c=b.next();!c.done;)c=c.value,a.push(c[0]+": "+c[1]),c=b.next();return a.join("\r\n")};
l.hg=function(a){this.Db=a};l.Yh=function(a){this.bc=a};var Cf=function(a){a.onreadystatechange&&a.onreadystatechange.call(a)};Object.defineProperty(Bf.prototype,"withCredentials",{get:function(){return this.Db==="include"},set:function(a){this.hg(a?"include":"same-origin")}});var Ff=typeof AsyncContext!=="undefined"&&typeof AsyncContext.Snapshot==="function"?function(a){return a&&AsyncContext.Snapshot.wrap(a)}:function(a){return a};var Gf=function(a,b){this.Bj=100;this.Ni=a;this.Uj=b;this.se=0;this.ce=null};Gf.prototype.get=function(){if(this.se>0){this.se--;var a=this.ce;this.ce=a.next;a.next=null}else a=this.Ni();return a};Gf.prototype.put=function(a){this.Uj(a);this.se<this.Bj&&(this.se++,a.next=this.ce,this.ce=a)};var Hf=function(){this.Ue=this.Yb=null};Hf.prototype.add=function(a,b){var c=If.get();c.set(a,b);this.Ue?this.Ue.next=c:(z(!this.Yb),this.Yb=c);this.Ue=c};Hf.prototype.remove=function(){var a=null;this.Yb&&(a=this.Yb,this.Yb=this.Yb.next,this.Yb||(this.Ue=null),a.next=null);return a};var If=new Gf(function(){return new Jf},function(a){return a.reset()}),Jf=function(){this.next=this.scope=this.wf=null};Jf.prototype.set=function(a,b){this.wf=a;this.scope=b;this.next=null};
Jf.prototype.reset=function(){this.next=this.scope=this.wf=null};var Kf=u.console&&u.console.createTask?u.console.createTask.bind(u.console):void 0,Lf=Kf?Symbol("consoleTask"):void 0;
function Mf(a,b){function c(){var h=sa.apply(0,arguments),k=this;return g.run(function(){return a.call.apply(a,[k].concat(oa(h)))})}b=b===void 0?"anonymous":b;if(Lf&&a[Lf])return a;var d=a,e,f=(e=Nf)==null?void 0:e();a=function(){var h=sa.apply(0,arguments),k,m=(k=Nf)==null?void 0:k();if(f!==m)throw Error(b+" was scheduled in '"+f+"' but called in '"+m+"'.\nMake sure your test awaits all async calls.\n\nTIP: To help investigate, debug the test in Chrome and look at the async portion\nof the call stack to see what originally scheduled the callback.  Then, make the\ntest wait for the relevant asynchronous work to finish.");return d.call.apply(d,
[this].concat(oa(h)))};if(!Kf)return a;var g=Kf(a.name||b);c[Fa(Lf)]=g;return c}var Nf;var Of,Pf=!1,Qf=new Hf,Sf=function(a,b){a=Mf(a,"goog.async.run");Of||Rf();Pf||(Of(),Pf=!0);Qf.add(a,b)},Rf=function(){var a=Promise.resolve(void 0);Of=function(){a.then(Tf)}};function Tf(){for(var a;a=Qf.remove();){try{a.wf.call(a.scope)}catch(b){Ka(b)}If.put(a)}Pf=!1};var Uf=function(a){if(!a)return!1;try{return!!a.$goog_Thenable}catch(b){return!1}};var I=function(a,b){this.R=0;this.ma=void 0;this.cc=this.Ya=this.sa=null;this.Zd=this.tf=!1;if(a!=yf)try{var c=this;a.call(b,function(d){Vf(c,2,d)},function(d){if(!(d instanceof Wf))try{if(d instanceof Error)throw d;throw Error("Promise rejected.");}catch(e){}Vf(c,3,d)})}catch(d){Vf(this,3,d)}},Xf=function(){this.next=this.context=this.qc=this.Ob=this.child=null;this.Kc=!1};Xf.prototype.reset=function(){this.context=this.qc=this.Ob=this.child=null;this.Kc=!1};
var Yf=new Gf(function(){return new Xf},function(a){a.reset()}),Zf=function(a,b,c){var d=Yf.get();d.Ob=a;d.qc=b;d.context=c;return d},J=function(a){if(a instanceof I)return a;var b=new I(yf);Vf(b,2,a);return b},K=function(a){return new I(function(b,c){c(a)})},ag=function(a,b,c){$f(a,b,c,null)||Sf(Aa(b,a))},bg=function(a){return new I(function(b,c){var d=a.length,e=[];if(d)for(var f=function(m,n){d--;e[m]=n;d==0&&b(e)},g=function(m){c(m)},h,k=0;k<a.length;k++)h=a[k],ag(h,Aa(f,k),g);else b(e)})},cg=
function(a){return new I(function(b){var c=a.length,d=[];if(c)for(var e=function(h,k,m){c--;d[h]=k?{Zg:!0,value:m}:{Zg:!1,reason:m};c==0&&b(d)},f,g=0;g<a.length;g++)f=a[g],ag(f,Aa(e,g,!0),Aa(e,g,!1));else b(d)})},dg=function(a){return new I(function(b,c){var d=a.length,e=[];if(d)for(var f=function(m){b(m)},g=function(m,n){d--;e[m]=n;d==0&&c(e)},h,k=0;k<a.length;k++)h=a[k],ag(h,f,Aa(g,k));else b(void 0)})};
I.prototype.then=function(a,b,c){a!=null&&Ia(a,"opt_onFulfilled should be a function.");b!=null&&Ia(b,"opt_onRejected should be a function. Did you pass opt_context as the second argument instead of the third?");return eg(this,Ff(typeof a==="function"?a:null),Ff(typeof b==="function"?b:null),c)};I.prototype.$goog_Thenable=!0;
var gg=function(a,b,c,d){b!=null&&Ia(b,"opt_onFulfilled should be a function.");c!=null&&Ia(c,"opt_onRejected should be a function. Did you pass opt_context as the second argument instead of the third?");fg(a,Zf(b||yf,c||null,d))};l=I.prototype;l.yb=function(a,b){a=Ff(a);b=Zf(a,a,b);b.Kc=!0;fg(this,b);return this};l.finally=function(a){var b=this;a=Ff(a);return new Promise(function(c,d){gg(b,function(e){a();c(e)},function(e){a();d(e)})})};l.h=function(a,b){return eg(this,null,Ff(a),b)};l.catch=I.prototype.h;
l.cancel=function(a){if(this.R==0){var b=new Wf(a);Sf(function(){hg(this,b)},this)}};
var hg=function(a,b){if(a.R==0)if(a.sa){var c=a.sa;if(c.Ya){for(var d=0,e=null,f=null,g=c.Ya;g&&(g.Kc||(d++,g.child==a&&(e=g),!(e&&d>1)));g=g.next)e||(f=g);e&&(c.R==0&&d==1?hg(c,b):(f?(d=f,z(c.Ya),z(d!=null),d.next==c.cc&&(c.cc=d),d.next=d.next.next):ig(c),jg(c,e,3,b)))}a.sa=null}else Vf(a,3,b)},fg=function(a,b){a.Ya||a.R!=2&&a.R!=3||kg(a);z(b.Ob!=null);a.cc?a.cc.next=b:a.Ya=b;a.cc=b},eg=function(a,b,c,d){b&&(b=Mf(b,"goog.Promise.then"));c&&(c=Mf(c,"goog.Promise.then"));var e=Zf(null,null,null);e.child=
new I(function(f,g){e.Ob=b?function(h){try{var k=b.call(d,h);f(k)}catch(m){g(m)}}:f;e.qc=c?function(h){try{var k=c.call(d,h);k===void 0&&h instanceof Wf?g(h):f(k)}catch(m){g(m)}}:g});e.child.sa=a;fg(a,e);return e.child};I.prototype.vk=function(a){z(this.R==1);this.R=0;Vf(this,2,a)};I.prototype.wk=function(a){z(this.R==1);this.R=0;Vf(this,3,a)};
var Vf=function(a,b,c){a.R==0&&(a===c&&(b=3,c=new TypeError("Promise cannot resolve to itself")),a.R=1,$f(c,a.vk,a.wk,a)||(a.ma=c,a.R=b,a.sa=null,kg(a),b!=3||c instanceof Wf||lg(a,c)))},$f=function(a,b,c,d){if(a instanceof I)return gg(a,b,c,d),!0;if(Uf(a))return a.then(b,c,d),!0;if(v(a))try{var e=a.then;if(typeof e==="function")return mg(a,e,b,c,d),!0}catch(f){return c.call(d,f),!0}return!1},mg=function(a,b,c,d,e){var f=!1,g=function(k){f||(f=!0,c.call(e,k))},h=function(k){f||(f=!0,d.call(e,k))};
try{b.call(a,g,h)}catch(k){h(k)}},kg=function(a){a.tf||(a.tf=!0,Sf(a.Ti,a))},ig=function(a){var b=null;a.Ya&&(b=a.Ya,a.Ya=b.next,b.next=null);a.Ya||(a.cc=null);b!=null&&z(b.Ob!=null);return b};I.prototype.Ti=function(){for(var a;a=ig(this);)jg(this,a,this.R,this.ma);this.tf=!1};
var jg=function(a,b,c,d){if(c==3&&b.qc&&!b.Kc)for(;a&&a.Zd;a=a.sa)a.Zd=!1;if(b.child)b.child.sa=null,ng(b,c,d);else try{b.Kc?b.Ob.call(b.context):ng(b,c,d)}catch(e){og.call(null,e)}Yf.put(b)},ng=function(a,b,c){b==2?a.Ob.call(a.context,c):a.qc&&a.qc.call(a.context,c)},lg=function(a,b){a.Zd=!0;Sf(function(){a.Zd&&og.call(null,b)})},og=Ka,Wf=function(a){Ba.call(this,a)};x(Wf,Ba);Wf.prototype.name="cancel";/*

 Copyright 2005, 2007 Bob Ippolito. All Rights Reserved.
 Copyright The Closure Library Authors.
 SPDX-License-Identifier: MIT
*/
var qg=function(a){var b=pg;this.Je=[];this.Ah=b;this.Qg=a||null;this.Zc=this.hc=!1;this.ma=void 0;this.mg=this.zg=this.cf=!1;this.Re=0;this.sa=null;this.df=0};qg.prototype.cancel=function(a){if(this.hc)this.ma instanceof qg&&this.ma.cancel();else{if(this.sa){var b=this.sa;delete this.sa;a?b.cancel(a):(b.df--,b.df<=0&&b.cancel())}this.Ah?this.Ah.call(this.Qg,this):this.mg=!0;this.hc||rg(this,new sg(this))}};qg.prototype.Jg=function(a,b){this.cf=!1;tg(this,a,b)};
var tg=function(a,b,c){a.hc=!0;a.ma=c;a.Zc=!b;ug(a)},wg=function(a){if(a.hc){if(!a.mg)throw new vg(a);a.mg=!1}};qg.prototype.callback=function(a){wg(this);xg(a);tg(this,!0,a)};var rg=function(a,b){wg(a);xg(b);tg(a,!1,b)},xg=function(a){z(!(a instanceof qg),"An execution sequence may not be initiated with a blocking Deferred.")};qg.prototype.addCallback=function(a,b){return yg(this,a,null,b)};var zg=function(a,b){yg(a,null,b)};
qg.prototype.finally=function(a){var b=this;return new Promise(function(c,d){yg(b,function(e){a();c(e)},function(e){a();d(e)})})};var yg=function(a,b,c,d){z(!a.zg,"Blocking Deferreds can not be re-used");var e=a.hc;e||(b===c?b=c=Ff(b):(b=Ff(b),c=Ff(c)));a.Je.push([b,c,d]);e&&ug(a);return a};qg.prototype.then=function(a,b,c){var d,e,f=new I(function(g,h){e=g;d=h});yg(this,e,function(g){g instanceof sg?f.cancel():d(g);return Ag},this);return f.then(a,b,c)};qg.prototype.$goog_Thenable=!0;
var Bg=function(a){return gb(a.Je,function(b){return typeof b[1]==="function"})},Ag={},ug=function(a){if(a.Re&&a.hc&&Bg(a)){var b=a.Re,c=Cg[b];c&&(u.clearTimeout(c.Ea),delete Cg[b]);a.Re=0}a.sa&&(a.sa.df--,delete a.sa);b=a.ma;for(var d=c=!1;a.Je.length&&!a.cf;){var e=a.Je.shift(),f=e[0],g=e[1];e=e[2];if(f=a.Zc?g:f)try{var h=f.call(e||a.Qg,b);h===Ag&&(h=void 0);h!==void 0&&(a.Zc=a.Zc&&(h==b||h instanceof Error),a.ma=b=h);if(Uf(b)||typeof u.Promise==="function"&&b instanceof u.Promise)d=!0,a.cf=!0}catch(k){b=
k,a.Zc=!0,Bg(a)||(c=!0)}}a.ma=b;d&&(h=w(a.Jg,a,!0),d=w(a.Jg,a,!1),b instanceof qg?(yg(b,h,d),b.zg=!0):b.then(h,d));c&&(b=new Dg(b),Cg[b.Ea]=b,a.Re=b.Ea)},vg=function(){Ba.call(this)};x(vg,Ba);vg.prototype.message="Deferred has already fired";vg.prototype.name="AlreadyCalledError";var sg=function(){Ba.call(this)};x(sg,Ba);sg.prototype.message="Deferred was canceled";sg.prototype.name="CanceledError";var Dg=function(a){this.Ea=u.setTimeout(w(this.tk,this),0);this.Y=a};
Dg.prototype.tk=function(){z(Cg[this.Ea],"Cannot throw an error that is not scheduled.");delete Cg[this.Ea];throw this.Y;};var Cg={};var Hg=function(a){var b={},c=b.document||document,d=Zb(a).toString(),e=(new ye(c)).createElement("SCRIPT"),f={Th:e,Oe:void 0},g=new qg(f),h=null,k=b.timeout!=null?b.timeout:5E3;k>0&&(h=window.setTimeout(function(){Eg(e,!0);rg(g,new Fg(1,"Timeout reached for loading script "+d))},k),f.Oe=h);e.onload=e.onreadystatechange=function(){e.readyState&&e.readyState!="loaded"&&e.readyState!="complete"||(Eg(e,b.hl||!1,h),g.callback(null))};e.onerror=function(){Eg(e,!0,h);rg(g,new Fg(0,"Error while loading script "+
d))};f=b.attributes||{};hd(f,{type:"text/javascript",charset:"UTF-8"});ie(e,f);Dc(e,a);Gg(c).appendChild(e);return g},Gg=function(a){var b=(a||document).getElementsByTagName("HEAD");return b&&b.length!==0?b[0]:a.documentElement},pg=function(){if(this&&this.Th){var a=this.Th;a&&a.tagName=="SCRIPT"&&Eg(a,!0,this.Oe)}},Eg=function(a,b,c){c!=null&&u.clearTimeout(c);a.onload=function(){};a.onerror=function(){};a.onreadystatechange=function(){};b&&window.setTimeout(function(){pe(a)},0)},Fg=function(a,b){var c=
"Jsloader error (code #"+a+")";b&&(c+=": "+b);Ba.call(this,c);this.code=a};x(Fg,Ba);var L=function(a){pf.call(this);this.headers=new Map;this.zi=a||null;this.jb=!1;this.l=null;this.ed=this.sh=this.me="";this.Kb=this.Ef=this.ie=this.rf=!1;this.Ec=0;this.Ub=null;this.De="";this.Pj=this.yi=!1;this.Ze=this.qg=null};x(L,pf);L.prototype.P=Uc(Vc(),"goog.net.XhrIo").vh;var Ig=/^https?$/i,Jg=["POST","PUT"];l=L.prototype;l.setTrustToken=function(a){this.qg=a};l.setAttributionReporting=function(a){this.Ze=a};
l.send=function(a,b,c,d){if(this.l)throw Error("[goog.net.XhrIo] Object is active with another request="+this.me+"; newUri="+a);b=b?b.toUpperCase():"GET";this.me=a;this.ed="";this.sh=b;this.rf=!1;this.jb=!0;this.l=this.zi?this.zi.Oc():tf.Oc();this.l.onreadystatechange=Ff(w(this.Hh,this));this.Pj&&"onprogress"in this.l&&(this.l.onprogress=Ff(w(function(g){this.Gh(g,!0)},this)),this.l.upload&&(this.l.upload.onprogress=Ff(w(this.Gh,this))));try{Xc(this.P,Kg(this,"Opening Xhr")),this.Ef=!0,this.l.open(b,
String(a),!0),this.Ef=!1}catch(g){Xc(this.P,Kg(this,"Error opening Xhr: "+g.message));this.Y(5,g);return}a=c||"";c=new Map(this.headers);if(d)if(Object.getPrototypeOf(d)===Object.prototype)for(var e in d)c.set(e,d[e]);else if(typeof d.keys==="function"&&typeof d.get==="function"){e=na(d.keys());for(var f=e.next();!f.done;f=e.next())f=f.value,c.set(f,d.get(f))}else throw Error("Unknown input type for opt_headers: "+String(d));d=Array.from(c.keys()).find(function(g){return"content-type"==g.toLowerCase()});
e=u.FormData&&a instanceof u.FormData;!hb(Jg,b)||d||e||c.set("Content-Type","application/x-www-form-urlencoded;charset=utf-8");b=na(c);for(d=b.next();!d.done;d=b.next())c=na(d.value),d=c.next().value,c=c.next().value,this.l.setRequestHeader(d,c);this.De&&(this.l.responseType=this.De);"withCredentials"in this.l&&this.l.withCredentials!==this.yi&&(this.l.withCredentials=this.yi);if("setTrustToken"in this.l&&this.qg)try{this.l.setTrustToken(this.qg)}catch(g){Xc(this.P,Kg(this,"Error SetTrustToken: "+
g.message))}if("setAttributionReporting"in this.l&&this.Ze)try{this.l.setAttributionReporting(this.Ze)}catch(g){Xc(this.P,Kg(this,"Error SetAttributionReporting: "+g.message))}try{this.Ub&&(clearTimeout(this.Ub),this.Ub=null),this.Ec>0&&(Xc(this.P,Kg(this,"Will abort after "+this.Ec+"ms if incomplete")),this.Ub=setTimeout(this.Oe.bind(this),this.Ec)),Xc(this.P,Kg(this,"Sending request")),this.ie=!0,this.l.send(a),this.ie=!1}catch(g){Xc(this.P,Kg(this,"Send error: "+g.message)),this.Y(5,g)}};
l.Oe=function(){typeof va!="undefined"&&this.l&&(this.ed="Timed out after "+this.Ec+"ms, aborting",Xc(this.P,Kg(this,this.ed)),this.dispatchEvent("timeout"),this.abort(8))};l.Y=function(a,b){this.jb=!1;this.l&&(this.Kb=!0,this.l.abort(),this.Kb=!1);this.ed=b;Lg(this);Mg(this)};var Lg=function(a){a.rf||(a.rf=!0,a.dispatchEvent("complete"),a.dispatchEvent("error"))};
L.prototype.abort=function(){this.l&&this.jb&&(Xc(this.P,Kg(this,"Aborting")),this.jb=!1,this.Kb=!0,this.l.abort(),this.Kb=!1,this.dispatchEvent("complete"),this.dispatchEvent("abort"),Mg(this))};L.prototype.Sc=function(){this.l&&(this.jb&&(this.jb=!1,this.Kb=!0,this.l.abort(),this.Kb=!1),Mg(this,!0));L.Dc.Sc.call(this)};L.prototype.Hh=function(){this.isDisposed()||(this.Ef||this.ie||this.Kb?Ng(this):this.Jj())};L.prototype.Jj=function(){Ng(this)};
var Ng=function(a){if(a.jb&&typeof va!="undefined")if(a.ie&&Og(a)==4)setTimeout(a.Hh.bind(a),0);else if(a.dispatchEvent("readystatechange"),Og(a)==4){Xc(a.P,Kg(a,"Request complete"));a.jb=!1;try{var b=Pg(a);a:switch(b){case 200:case 201:case 202:case 204:case 206:case 304:case 1223:var c=!0;break a;default:c=!1}var d;if(!(d=c)){var e;if(e=b===0){var f=String(a.me).match(ld)[1]||null;!f&&u.self&&u.self.location&&(f=u.self.location.protocol.slice(0,-1));e=!Ig.test(f?f.toLowerCase():"")}d=e}if(d)a.dispatchEvent("complete"),
a.dispatchEvent("success");else{try{var g=Og(a)>2?a.l.statusText:""}catch(h){Xc(a.P,"Can not get status: "+h.message),g=""}a.ed=g+" ["+Pg(a)+"]";Lg(a)}}finally{Mg(a)}}};L.prototype.Gh=function(a,b){z(a.type==="progress","goog.net.EventType.PROGRESS is of the same type as raw XHR progress.");this.dispatchEvent(Qg(a,"progress"));this.dispatchEvent(Qg(a,b?"downloadprogress":"uploadprogress"))};
var Qg=function(a,b){return{type:b,lengthComputable:a.lengthComputable,loaded:a.loaded,total:a.total}},Mg=function(a,b){if(a.l){a.Ub&&(clearTimeout(a.Ub),a.Ub=null);var c=a.l;a.l=null;b||a.dispatchEvent("ready");try{c.onreadystatechange=null}catch(d){(a=a.P)&&Wc(a,Ic,"Problem encountered resetting onreadystatechange: "+d.message)}}};L.prototype.isActive=function(){return!!this.l};
var Og=function(a){return a.l?a.l.readyState:0},Pg=function(a){try{return Og(a)>2?a.l.status:-1}catch(b){return-1}},Rg=function(a){try{return a.l?a.l.responseText:""}catch(b){return Xc(a.P,"Can not get responseText: "+b.message),""}};
L.prototype.getResponse=function(){try{if(!this.l)return null;if("response"in this.l)return this.l.response;switch(this.De){case "":case "text":return this.l.responseText;case "arraybuffer":if("mozResponseArrayBuffer"in this.l)return this.l.mozResponseArrayBuffer}var a=this.P;a&&Wc(a,Ic,"Response type "+this.De+" is not supported on this browser");return null}catch(b){return Xc(this.P,"Can not get response: "+b.message),null}};
L.prototype.getResponseHeader=function(a){if(this.l&&Og(this)==4)return a=this.l.getResponseHeader(a),a===null?void 0:a};L.prototype.getAllResponseHeaders=function(){return this.l&&Og(this)>=2?this.l.getAllResponseHeaders()||"":""};var Kg=function(a,b){return b+" ["+a.sh+" "+a.me+" "+Pg(a)+"]"};var Sg=function(a,b){if(typeof a!=="function")if(a&&typeof a.handleEvent=="function")a=w(a.handleEvent,a);else throw Error("Invalid listener argument");return Number(b)>2147483647?-1:u.setTimeout(a,b||0)},Tg=function(a){var b=null;return(new I(function(c,d){b=Sg(function(){c(void 0)},a);b==-1&&d(Error("Failed to schedule timer."))})).h(function(c){u.clearTimeout(b);throw c;})};var Ug=function(a){var b=Error();b.name="SecurityError";a="Failed to read a named property '"+a+"' from 'Window': ";if("location"in window)try{a+='Blocked a frame with origin "'+window.location.href+'" from accessing a cross-origin frame.'}catch(c){a+="An attempt was made to break through the security policy of the user agent."}b.message=a;throw b;},Vg=function(){return{get closed(){return!0},get location(){Ug("location")},get document(){Ug("document")},postMessage:function(){},close:function(){},
focus:function(){}}};var Wg=function(){this.Ki="/__/firebase/init.json";this.Mi=new vf};
Wg.prototype.He=function(a,b,c,d,e,f){return new I(function(g,h){try{if(f){a.Ec=Math.max(0,f);var k=setTimeout(function(){a.dispatchEvent("timeout")},f)}a.listen("complete",function(){k&&clearTimeout(k);var m=null,n=Rg(a);if(Pg(a)===200)try{m=JSON.parse(n)||null,g(m||null)}catch(r){h(Error(n))}else Pg(a)===404?h(Error("resource-not-found")):h(Error(n))});lf(a,"ready",function(){k&&clearTimeout(k);a.dispose()});lf(a,"timeout",function(){k&&clearTimeout(k);a.dispose();h(Error("Request timed out"))});
a.send(b,c,d,e)}catch(m){h(m)}})};var Xg={Fk:{Wd:"https://staging-identitytoolkit.sandbox.googleapis.com/identitytoolkit/v3/relyingparty/",Fe:"https://staging-securetoken.sandbox.googleapis.com/v1/token",fe:"https://staging-identitytoolkit.sandbox.googleapis.com/v2/",id:"b"},Zk:{Wd:"https://www.googleapis.com/identitytoolkit/v3/relyingparty/",Fe:"https://securetoken.googleapis.com/v1/token",fe:"https://identitytoolkit.googleapis.com/v2/",id:"p"},al:{Wd:"https://staging-www.sandbox.googleapis.com/identitytoolkit/v3/relyingparty/",
Fe:"https://staging-securetoken.sandbox.googleapis.com/v1/token",fe:"https://staging-identitytoolkit.sandbox.googleapis.com/v2/",id:"s"},cl:{Wd:"https://www-googleapis-test.sandbox.google.com/identitytoolkit/v3/relyingparty/",Fe:"https://test-securetoken.sandbox.googleapis.com/v1/token",fe:"https://test-identitytoolkit.sandbox.googleapis.com/v2/",id:"t"}};
function Yg(a){for(var b in Xg)if(Xg[b].id===a)return a=Xg[b],{firebaseEndpoint:a.Wd,secureTokenEndpoint:a.Fe,identityPlatformEndpoint:a.fe};return null}var Zg;Zg=Yg("__EID__")?"__EID__":void 0;var $g=function(){var a=M();return ob&&!!Ab&&Ab==11||/Edge\/\d+/.test(a)},ah=function(){return u.window&&u.window.location.href||self&&self.location&&self.location.href||""},bh=function(a,b){b=b||u.window;var c="about:blank";a&&(c=oc(sc(a)));b.location.href=c},ch=function(a,b,c){b=b||u.window;c?b.location.replace(a):b.location.replace(oc(sc(a)))},dh=function(a,b){var c=[],d;for(d in a)d in b?typeof a[d]!=typeof b[d]?c.push(d):typeof a[d]=="object"&&a[d]!=null&&b[d]!=null?dh(a[d],b[d]).length>0&&c.push(d):
a[d]!==b[d]&&c.push(d):c.push(d);for(var e in b)e in a||c.push(e);return c},fh=function(){var a=M();a=eh(a)!="Chrome"?null:(a=a.match(/\sChrome\/(\d+)/i))&&a.length==2?parseInt(a[1],10):null;return a&&a<30?!1:!ob||!Ab||Ab>9},gh=function(a){a=(a||M()).toLowerCase();return a.match(/android/)||a.match(/webos/)||a.match(/iphone|ipad|ipod/)||a.match(/blackberry/)||a.match(/windows phone/)||a.match(/iemobile/)?!0:!1},hh=function(a){a=a||u.window;try{a.close()}catch(b){}},ih=function(a,b,c){var d=Math.floor(Math.random()*
1E9).toString();b=b||500;c=c||600;var e=(window.screen.availHeight-c)/2,f=(window.screen.availWidth-b)/2;b={width:b,height:c,top:e>0?e:0,left:f>0?f:0,location:!0,resizable:!0,statusbar:!0,toolbar:!1};c=M().toLowerCase();d&&(b.target=d,A(c,"crios/")&&(b.target="_blank"));eh(M())=="Firefox"&&(a=a||"http://localhost",b.scrollbars=!0);e=a||"";(d=b)||(d={});a=window;b=e instanceof mc?e:sc(typeof e.href!="undefined"?e.href:String(e));c=self.crossOriginIsolated!==void 0;f="strict-origin-when-cross-origin";
window.Request&&(f=(new Request("/")).referrerPolicy);var g=d.noreferrer;if(c&&g&&f==="unsafe-url")throw Error("Cannot use the noreferrer option on a page that sets a referrer-policy of `unsafe-url` in modern browsers!");c=g&&!c;e=d.target||e.target;f=[];g=[];for(k in d){var h=d[k];switch(k){case "width":case "height":case "top":case "left":f.push(k+"="+h);break;case "target":break;case "noopener":case "noreferrer":h?g.push(k):g.push(k+"=false");break;case "attributionsrc":f.push(k+(h?"="+h:""));
break;default:f.push(k+"="+(h?1:0))}}["_blank","_self","_top","_parent",""].includes(e);var k=f.join(",");(B("iPhone")&&!B("iPod")&&!B("iPad")||B("iPad")||B("iPod"))&&a.navigator&&a.navigator.standalone&&e&&e!="_self"?(k=le(document,"A"),b=vc(b),b!==void 0&&(k.href=b),k.target=e,c&&(k.rel="noreferrer"),((d=d.attributionsrc)||d==="")&&k.setAttribute("attributionsrc",d),d=document.createEvent("MouseEvent"),d.initMouseEvent("click",!0,!0,a,1),k.dispatchEvent(d),k=Vg()):c?(k=Bc(a,"",e,k),a=oc(b),k&&(k.opener=
null,a===""&&(a="javascript:''"),Ta.test(a)&&(a.indexOf("&")!=-1&&(a=a.replace(Na,"&amp;")),a.indexOf("<")!=-1&&(a=a.replace(Oa,"&lt;")),a.indexOf(">")!=-1&&(a=a.replace(Pa,"&gt;")),a.indexOf('"')!=-1&&(a=a.replace(Qa,"&quot;")),a.indexOf("'")!=-1&&(a=a.replace(Ra,"&#39;")),a.indexOf("\x00")!=-1&&(a=a.replace(Sa,"&#0;"))),a='<meta name="referrer" content="no-referrer"><meta http-equiv="refresh" content="0; url='+a+'">',Yc("b/12014412, meta tag with sanitized URL"),a=zc(a),(d=k.document)&&d.write&&
(d.write(Ac(a)),d.close()))):((k=Bc(a,b,e,k))&&d.noopener&&(k.opener=null),k&&d.noreferrer&&(k.opener=null));if(k)try{k.focus()}catch(m){}return k},jh=function(){var a=M().match(/OS (\d+)_.*CriOS\/(\d+)\./i);return a&&a.length>2?parseInt(a[1],10)>=10&&parseInt(a[2],10)>=55:!1},kh=function(a){return new I(function(b){var c=function(){Tg(2E3).then(function(){if(!a||a.closed)b();else return c()})};return c()})},mh=function(a,b){var c=F(b);b=c.ua;c=c.ga;for(var d=0;d<a.length;d++){var e=a[d];e.indexOf("chrome-extension://")==
0?e=F(e).ga==c&&b=="chrome-extension":b!="http"&&b!="https"?e=!1:lh.test(e)?e=c==e:(e=e.split(".").join("\\."),e=(new RegExp("^(.+\\."+e+"|"+e+")$","i")).test(c));if(e)return!0}return!1},lh=/^\d{1,3}\.\d{1,3}\.\d{1,3}\.\d{1,3}$/,nh=/^[^@]+@[^@]+$/,oh=function(){var a=null;return(new I(function(b){u.document.readyState=="complete"?b():(a=function(){b()},cf(window,"load",a))})).h(function(b){mf(window,"load",a);throw b;})},qh=function(){return ph()?oh().then(function(){return new I(function(a,b){var c=
u.document,d=setTimeout(function(){b(Error("Cordova framework is not ready."))},1E3);c.addEventListener("deviceready",function(){clearTimeout(d);a()},!1)})}):K(Error("Cordova must run in an Android or iOS file scheme."))},ph=function(){var a=M();return!(rh()!=="file:"&&rh()!=="ionic:"||!a.toLowerCase().match(/iphone|ipad|ipod|android/))},sh=function(a){a=a||u.window;try{return!(!a||a==a.top)}catch(b){return!1}},th=function(){var a=u.window;try{var b=a&&a.opener;return!(!b||!sh(b))}catch(c){return!1}},
uh=function(){return typeof u.WorkerGlobalScope!=="undefined"&&typeof u.importScripts==="function"},vh=function(){return firebase.INTERNAL.hasOwnProperty("reactNative")?"ReactNative":firebase.INTERNAL.hasOwnProperty("node")?"Node":uh()?"Worker":"Browser"},wh=function(){var a=vh();return a==="ReactNative"||a==="Node"},zh=function(){for(var a=50,b=[];a>0;)b.push("1234567890abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ".charAt(Math.floor(Math.random()*62))),a--;return b.join("")},eh=function(a){var b=
a.toLowerCase();if(A(b,"opera/")||A(b,"opr/")||A(b,"opios/"))return"Opera";if(A(b,"iemobile"))return"IEMobile";if(A(b,"msie")||A(b,"trident/"))return"IE";if(A(b,"edge/"))return"Edge";if(A(b,"firefox/"))return"Firefox";if(A(b,"silk/"))return"Silk";if(A(b,"blackberry"))return"Blackberry";if(A(b,"webos"))return"Webos";if(!A(b,"safari/")||A(b,"chrome/")||A(b,"crios/")||A(b,"android"))if(!A(b,"chrome/")&&!A(b,"crios/")||A(b,"edge/")){if(A(b,"android"))return"Android";if((a=a.match(RegExp("([a-zA-Z\\d\\.]+)/[a-zA-Z\\d\\.]*$")))&&
a.length==2)return a[1]}else return"Chrome";else return"Safari";return"Other"},Ah={Hk:"FirebaseCore-web",Kk:"FirebaseUI-web",Sk:"gcip-iap"},Bh=function(a,b,c){c=c||[];var d=[],e={},f;for(f in Ah)e[Ah[f]]=!0;for(f=0;f<c.length;f++)typeof e[c[f]]!=="undefined"&&(delete e[c[f]],d.push(c[f]));d.sort();c=d;c.length||(c=["FirebaseCore-web"]);d=vh();return(d==="Browser"?eh(M()):d==="Worker"?eh(M())+"-"+d:d)+"/"+a+"/"+b+"/"+c.join(",")},M=function(){return u.navigator&&u.navigator.userAgent||""},N=function(a,
b){a=a.split(".");b=b||u;var c;for(c=0;c<a.length&&typeof b=="object"&&b!=null;c++)b=b[a[c]];c!=a.length&&(b=void 0);return b},Dh=function(){try{var a=u.localStorage,b=Ch();if(a)return a.setItem(b,"1"),a.removeItem(b),$g()?!!u.indexedDB:!0}catch(c){return uh()&&!!u.indexedDB}return!1},Fh=function(){return(Eh()||rh()==="chrome-extension:"||ph())&&!wh()&&Dh()&&!uh()},Eh=function(){return rh()==="http:"||rh()==="https:"},rh=function(){return u.location&&u.location.protocol||null},Gh=function(a){a=a||
M();return gh(a)||eh(a)=="Firefox"?!1:!0},Hh=function(a){return typeof a==="undefined"?null:JSON.stringify(a)},Ih=function(a){var b={},c;for(c in a)a.hasOwnProperty(c)&&a[c]!==null&&a[c]!==void 0&&(b[c]=a[c]);return b},Jh=function(a,b){a=fd(a);for(var c=0;c<b.length;c++){var d=b[c];d in a&&delete a[d]}return a},Kh=function(a){if(a!==null)return JSON.parse(a)},Ch=function(a){return a?a:""+Math.floor(Math.random()*1E9).toString()},Lh=function(a){a=a||M();return eh(a)=="Safari"||a.toLowerCase().match(/iphone|ipad|ipod/)?
!1:!0},Mh=function(){var a=u.___jsl;if(a&&a.H)for(var b in a.H)if(a.H[b].r=a.H[b].r||[],a.H[b].L=a.H[b].L||[],a.H[b].r=a.H[b].L.concat(),a.CP)for(var c=0;c<a.CP.length;c++)a.CP[c]=null},Nh=function(a,b){if(a>b)throw Error("Short delay should be less than long delay!");this.ci=a;this.Ej=b;a=M();b=vh();this.uj=gh(a)||b==="ReactNative"};
Nh.prototype.get=function(){var a=u.navigator;return(a&&typeof a.onLine==="boolean"&&(Eh()||rh()==="chrome-extension:"||typeof a.connection!=="undefined")?a.onLine:1)?this.uj?this.Ej:this.ci:Math.min(5E3,this.ci)};
var Oh=function(){var a=u.document;return a&&typeof a.visibilityState!=="undefined"?a.visibilityState=="visible":!0},Ph=function(){var a=u.document,b=null;return Oh()||!a?J():(new I(function(c){b=function(){Oh()&&(a.removeEventListener("visibilitychange",b,!1),c())};a.addEventListener("visibilitychange",b,!1)})).h(function(c){a.removeEventListener("visibilitychange",b,!1);throw c;})},Qh=function(a){typeof console!=="undefined"&&typeof console.error==="function"&&console.error(a)},Rh=function(a){try{var b=
new Date(parseInt(a,10));if(!isNaN(b.getTime())&&!/[^0-9]/.test(a))return b.toUTCString()}catch(c){}return null},Sh=function(){return!(!N("fireauth.oauthhelper",u)&&!N("fireauth.iframe",u))},Th=function(){if(u.document)try{var a=ke("META",{name:"referrer",content:"no-referrer"}),b=document.getElementsByTagName("HEAD");b.length&&b[0].appendChild(a)}catch(c){}},Uh=function(){var a=u.navigator;return a&&a.serviceWorker&&a.serviceWorker.controller||null},Vh=function(){var a=u.navigator;return a&&a.serviceWorker?
J().then(function(){return a.serviceWorker.ready}).then(function(b){return b.active||null}).h(function(){return null}):J(null)},Wh=function(a){var b={};a.split("&").forEach(function(c){c=c.split("=");c.length>1&&(b[decodeURIComponent(c[0])]=decodeURIComponent(c[1]))});return b};var Xh={};function Yh(a){Xh[a]||(Xh[a]=!0,typeof console!=="undefined"&&typeof console.warn==="function"&&console.warn(a))};var Zh;try{var $h={};Object.defineProperty($h,"abcd",{configurable:!0,enumerable:!0,value:1});Object.defineProperty($h,"abcd",{configurable:!0,enumerable:!0,value:2});Zh=$h.abcd==2}catch(a){Zh=!1}
var O=function(a,b,c){Zh?Object.defineProperty(a,b,{configurable:!0,enumerable:!0,value:c}):a[b]=c},ai=function(a,b){if(b)for(var c in b)b.hasOwnProperty(c)&&O(a,c,b[c])},bi=function(a){var b={};ai(b,a);return b},ci=function(a,b){if(!b||!b.length)return!0;if(!a)return!1;for(var c=0;c<b.length;c++){var d=a[b[c]];if(d===void 0||d===null||d==="")return!1}return!0},di=function(a){var b=a;if(typeof a=="object"&&a!=null){b="length"in a?[]:{};for(var c in a)O(b,c,di(a[c]))}return b};var ei="oauth_consumer_key oauth_nonce oauth_signature oauth_signature_method oauth_timestamp oauth_token oauth_version".split(" "),fi=["client_id","response_type","scope","redirect_uri","state"],gi={Jk:{dd:"locale",uc:700,tc:600,providerId:"facebook.com",td:fi},Nk:{dd:null,uc:500,tc:750,providerId:"github.com",td:fi},Ok:{dd:"hl",uc:515,tc:680,providerId:"google.com",td:fi},fl:{dd:"lang",uc:485,tc:705,providerId:"twitter.com",td:ei},Ek:{dd:"locale",uc:640,tc:600,providerId:"apple.com",td:[]}};
function hi(a){for(var b in gi)if(gi[b].providerId==a)return gi[b];return null}function ii(a){return(a=hi(a))&&a.td||[]}function ji(a){return typeof a==="string"&&a.indexOf("saml.")==0};var P=function(a,b,c){this.code="auth/"+a;this.message=b||ki[a]||"";this.Vh=c||null};x(P,Error);P.prototype.m=function(){var a={code:this.code,message:this.message};this.Vh&&(a.serverResponse=this.Vh);return a};P.prototype.toJSON=function(){return this.m()};
var li=function(a){var b=a&&a.code;return b?new P(b.substring(5),a.message,a.serverResponse):null},ki={"api-key-service-blocked":"The request is denied because it violates [API key HTTP restrictions](https://cloud.google.com/docs/authentication/api-keys#adding_http_restrictions).","admin-restricted-operation":"This operation is restricted to administrators only.","argument-error":"","app-not-authorized":"This app, identified by the domain where it's hosted, is not authorized to use Firebase Authentication with the provided API key. Review your key configuration in the Google API console.",
"app-not-installed":"The requested mobile application corresponding to the identifier (Android package name or iOS bundle ID) provided is not installed on this device.","bad-request":"The requested action is invalid.","captcha-check-failed":"The reCAPTCHA response token provided is either invalid, expired, already used or the domain associated with it does not match the list of whitelisted domains.","code-expired":"The SMS code has expired. Please re-send the verification code to try again.","cordova-not-ready":"Cordova framework is not ready.",
"cors-unsupported":"This browser is not supported.","credential-already-in-use":"This credential is already associated with a different user account.","custom-token-mismatch":"The custom token corresponds to a different audience.","requires-recent-login":"This operation is sensitive and requires recent authentication. Log in again before retrying this request.","dynamic-link-not-activated":"Please activate Dynamic Links in the Firebase Console and agree to the terms and conditions.","email-change-needs-verification":"Multi-factor users must always have a verified email.",
"email-already-in-use":"The email address is already in use by another account.","expired-action-code":"The action code has expired. ","cancelled-popup-request":"This operation has been cancelled due to another conflicting popup being opened.","internal-error":"An internal error has occurred.","invalid-app-credential":"The phone verification request contains an invalid application verifier. The reCAPTCHA token response is either invalid or expired.","invalid-app-id":"The mobile app identifier is not registed for the current project.",
"invalid-user-token":"This user's credential isn't valid for this project. This can happen if the user's token has been tampered with, or if the user isn't for the project associated with this API key.","invalid-auth-event":"An internal error has occurred.","invalid-verification-code":"The SMS verification code used to create the phone auth credential is invalid. Please resend the verification code sms and be sure to use the verification code provided by the user.","invalid-continue-uri":"The continue URL provided in the request is invalid.",
"invalid-cordova-configuration":"The following Cordova plugins must be installed to enable OAuth sign-in: cordova-plugin-buildinfo, cordova-universal-links-plugin, cordova-plugin-browsertab, cordova-plugin-inappbrowser and cordova-plugin-customurlscheme.","invalid-custom-token":"The custom token format is incorrect. Please check the documentation.","invalid-dynamic-link-domain":"The provided dynamic link domain is not configured or authorized for the current project.","invalid-email":"The email address is badly formatted.",
"invalid-api-key":"Your API key is invalid, please check you have copied it correctly.","invalid-cert-hash":"The SHA-1 certificate hash provided is invalid.","invalid-credential":"The supplied auth credential is malformed or has expired.","invalid-message-payload":"The email template corresponding to this action contains invalid characters in its message. Please fix by going to the Auth email templates section in the Firebase Console.","invalid-multi-factor-session":"The request does not contain a valid proof of first factor successful sign-in.",
"invalid-oauth-provider":"EmailAuthProvider is not supported for this operation. This operation only supports OAuth providers.","invalid-oauth-client-id":"The OAuth client ID provided is either invalid or does not match the specified API key.","unauthorized-domain":"This domain is not authorized for OAuth operations for your Firebase project. Edit the list of authorized domains from the Firebase console.","invalid-action-code":"The action code is invalid. This can happen if the code is malformed, expired, or has already been used.",
"wrong-password":"The password is invalid or the user does not have a password.","invalid-persistence-type":"The specified persistence type is invalid. It can only be local, session or none.","invalid-phone-number":"The format of the phone number provided is incorrect. Please enter the phone number in a format that can be parsed into E.164 format. E.164 phone numbers are written in the format [+][country code][subscriber number including area code].","invalid-provider-id":"The specified provider ID is invalid.",
"invalid-recipient-email":"The email corresponding to this action failed to send as the provided recipient email address is invalid.","invalid-sender":"The email template corresponding to this action contains an invalid sender email or name. Please fix by going to the Auth email templates section in the Firebase Console.","invalid-verification-id":"The verification ID used to create the phone auth credential is invalid.","invalid-tenant-id":"The Auth instance's tenant ID is invalid.","multi-factor-info-not-found":"The user does not have a second factor matching the identifier provided.",
"multi-factor-auth-required":"Proof of ownership of a second factor is required to complete sign-in.","missing-android-pkg-name":"An Android Package Name must be provided if the Android App is required to be installed.","auth-domain-config-required":"Be sure to include authDomain when calling firebase.initializeApp(), by following the instructions in the Firebase console.","missing-app-credential":"The phone verification request is missing an application verifier assertion. A reCAPTCHA response token needs to be provided.",
"missing-verification-code":"The phone auth credential was created with an empty SMS verification code.","missing-continue-uri":"A continue URL must be provided in the request.","missing-iframe-start":"An internal error has occurred.","missing-ios-bundle-id":"An iOS Bundle ID must be provided if an App Store ID is provided.","missing-multi-factor-info":"No second factor identifier is provided.","missing-multi-factor-session":"The request is missing proof of first factor successful sign-in.","missing-or-invalid-nonce":"The request does not contain a valid nonce. This can occur if the SHA-256 hash of the provided raw nonce does not match the hashed nonce in the ID token payload.",
"missing-phone-number":"To send verification codes, provide a phone number for the recipient.","missing-verification-id":"The phone auth credential was created with an empty verification ID.","app-deleted":"This instance of FirebaseApp has been deleted.","account-exists-with-different-credential":"An account already exists with the same email address but different sign-in credentials. Sign in using a provider associated with this email address.","network-request-failed":"A network error (such as timeout, interrupted connection or unreachable host) has occurred.",
"no-auth-event":"An internal error has occurred.","no-such-provider":"User was not linked to an account with the given provider.","null-user":"A null user object was provided as the argument for an operation which requires a non-null user object.","operation-not-allowed":"The given sign-in provider is disabled for this Firebase project. Enable it in the Firebase console, under the sign-in method tab of the Auth section.","operation-not-supported-in-this-environment":'This operation is not supported in the environment this application is running on. "location.protocol" must be http, https or chrome-extension and web storage must be enabled.',
"password-does-not-meet-requirements":"The provided password does not meet the configured requirements.","popup-blocked":"Unable to establish a connection with the popup. It may have been blocked by the browser.","popup-closed-by-user":"The popup has been closed by the user before finalizing the operation.","provider-already-linked":"User can only be linked to one identity for the given provider.","quota-exceeded":"The project's quota for this operation has been exceeded.","redirect-cancelled-by-user":"The redirect operation has been cancelled by the user before finalizing.",
"redirect-operation-pending":"A redirect sign-in operation is already pending.","rejected-credential":"The request contains malformed or mismatching credentials.","second-factor-already-in-use":"The second factor is already enrolled on this account.","maximum-second-factor-count-exceeded":"The maximum allowed number of second factors on a user has been exceeded.","tenant-id-mismatch":"The provided tenant ID does not match the Auth instance's tenant ID",timeout:"The operation has timed out.","user-token-expired":"The user's credential is no longer valid. The user must sign in again.",
"too-many-requests":"We have blocked all requests from this device due to unusual activity. Try again later.","unauthorized-continue-uri":"The domain of the continue URL is not whitelisted.  Please whitelist the domain in the Firebase console.","unsupported-first-factor":"Enrolling a second factor or signing in with a multi-factor account requires sign-in with a supported first factor.","unsupported-persistence-type":"The current environment does not support the specified persistence type.","unsupported-tenant-operation":"This operation is not supported in a multi-tenant context.",
"unverified-email":"The operation requires a verified email.","user-cancelled":"The user did not grant your application the permissions it requested.","user-not-found":"There is no user record corresponding to this identifier. The user may have been deleted.","user-disabled":"The user account has been disabled by an administrator.","user-mismatch":"The supplied credentials do not correspond to the previously signed in user.","user-signed-out":"","weak-password":"The password must be 6 characters long or more.",
"web-storage-unsupported":"This browser is not supported or 3rd party cookies and data may be disabled."};var mi=function(a,b,c,d,e,f,g){this.Gc=a;this.T=b||null;this.Wa=c||null;this.vd=d||null;this.Wf=f||null;this.C=g||null;this.Y=e||null;if(this.Wa||this.Y){if(this.Wa&&this.Y)throw new P("invalid-auth-event");if(this.Wa&&!this.vd)throw new P("invalid-auth-event");}else throw new P("invalid-auth-event");};l=mi.prototype;l.getType=function(){return this.Gc};l.getUid=function(){var a=[];a.push(this.Gc);this.T&&a.push(this.T);this.vd&&a.push(this.vd);this.C&&a.push(this.C);return a.join("-")};l.jc=function(){return this.vd};
l.getError=function(){return this.Y};l.m=function(){return{type:this.Gc,eventId:this.T,urlResponse:this.Wa,sessionId:this.vd,postBody:this.Wf,tenantId:this.C,error:this.Y&&this.Y.m()}};var ni=function(a){a=a||{};return a.type?new mi(a.type,a.eventId,a.urlResponse,a.sessionId,a.error&&li(a.error),a.postBody,a.tenantId):null};var oi=function(a,b,c,d,e,f,g,h,k,m,n,r,t,y,ba,jb,qa){this.A=a;this.B=b;this.Gc=c;this.T=d||null;this.zc=e||null;this.Pa=f||null;this.nf=g||null;this.ac=h||null;this.ad=k||null;this.Sg=m||null;this.U=n||[];this.Cb=r||null;this.bi=t||null;this.C=y||null;this.wc=ba||null;this.Gb=jb||null;this.Ph=qa||null};oi.prototype.getType=function(){return this.Gc};
oi.prototype.m=function(){return{apiKey:this.A,appName:this.B,type:this.Gc,eventId:this.T,redirectUrl:this.zc,clientVersion:this.Pa,displayName:this.nf,apn:this.ac,ibi:this.ad,eid:this.Sg,fw:this.U,clientId:this.Cb,sha1Cert:this.bi,tenantId:this.C,providerId:this.wc,appId:this.Gb,publicKey:this.Ph}};var pi=function(a,b){if(!b||!a||!a.mfaEnrollmentId)throw new P("internal-error","Internal assert: invalid MultiFactorInfo object");O(this,"uid",a.mfaEnrollmentId);O(this,"displayName",a.displayName||null);O(this,"enrollmentTime",a.enrolledAt?(new Date(a.enrolledAt)).toUTCString():null);O(this,"factorId",b)};pi.prototype.m=function(){return{uid:this.uid,displayName:this.displayName,factorId:this.factorId,enrollmentTime:this.enrollmentTime}};
var si=function(a){try{if(a.phoneInfo)return new qi(a);if(a.totpInfo)return new ri(a)}catch(b){}return null},qi=function(a){var b=a.phoneInfo;if(!b)throw new P("internal-error","Internal assert: invalid Phone MultiFactorInfo object");pi.call(this,a,"phone");O(this,"phoneNumber",b)};q(qi,pi);qi.prototype.m=function(){var a=pi.prototype.m.call(this);a.phoneNumber=this.phoneNumber;return a};
var ri=function(a){var b=a.totpInfo;if(!b)throw new P("internal-error","Internal assert: invalid TOTP MultiFactorInfo object");pi.call(this,a,"totp");O(this,"totpInfo",b)};q(ri,pi);ri.prototype.m=function(){var a=pi.prototype.m.call(this);a.totpInfo=this.totpInfo;return a};var ti=function(a){var b={},c=a.email,d=a.newEmail,e=a.requestType;a=si(a.mfaInfo);if(!e||e!="EMAIL_SIGNIN"&&e!="VERIFY_AND_CHANGE_EMAIL"&&!c||e=="VERIFY_AND_CHANGE_EMAIL"&&!d||e=="REVERT_SECOND_FACTOR_ADDITION"&&!a)throw Error("Invalid checkActionCode response!");e=="VERIFY_AND_CHANGE_EMAIL"?(b.fromEmail=c||null,b.previousEmail=c||null,b.email=d):(b.fromEmail=d||null,b.previousEmail=d||null,b.email=c||null);b.multiFactorInfo=a||null;O(this,"operation",e);O(this,"data",di(b))};var vi=function(a){a=F(a);var b=E(a,"apiKey")||null,c=E(a,"oobCode")||null,d=E(a,"mode")||null;d=d?ui[d]||null:null;if(!b||!c||!d)throw new P("argument-error","apiKey, oobCodeand mode are required in a valid action code URL.");ai(this,{apiKey:b,operation:d,code:c,continueUrl:E(a,"continueUrl")||null,languageCode:E(a,"languageCode")||null,tenantId:E(a,"tenantId")||null})},wi=function(a){try{return new vi(a)}catch(b){return null}},ui={recoverEmail:"RECOVER_EMAIL",resetPassword:"PASSWORD_RESET",revertSecondFactorAddition:"REVERT_SECOND_FACTOR_ADDITION",
signIn:"EMAIL_SIGNIN",verifyAndChangeEmail:"VERIFY_AND_CHANGE_EMAIL",verifyEmail:"VERIFY_EMAIL"};var xi=function(a,b,c,d,e,f,g){this.Ug="https://"+d+"/__/auth/handler?firebaseError="+encodeURIComponent(Hh((new P("app-not-installed")).m()));O(this,"fallbackUrl",this.Ug);this.vf=a;O(this,"fdlDomain",a);this.xe=b;O(this,"platform",b);this.Gd=c;O(this,"appIdentifier",c);this.J=d;O(this,"authDomain",d);this.ne=e;O(this,"payload",e);this.B=null;O(this,"appName",null);this.Cb=f||null;O(this,"clientId",this.Cb);this.Gb=g||null;O(this,"firebaseAppId",this.Gb)},yi=function(a,b){a.B=b||null;O(a,"appName",
b)},zi=function(a){var b=F(a);a=E(b,"fdlDomain");var c=E(b,"platform"),d=E(b,"appIdentifier"),e=E(b,"authDomain"),f=E(b,"link");b=E(b,"appName");return a&&c&&d&&e&&f&&b?(a=new xi(a,c,d,e,f),yi(a,b),a):null},Ai=function(a){var b=F(a),c=E(b,"link"),d=E(F(c),"link");b=E(b,"deep_link_id");return E(F(b),"link")||b||d||c||a},Bi=function(a,b){var c=Dd("https",a.vf,null,"/");a.xe=="android"?(D(c,"apn",a.Gd),D(c,"afl",b)):a.xe=="ios"&&(D(c,"ibi",a.Gd),D(c,"ifl",b));return c};
xi.prototype.toString=function(a){if(this.xe=="android_non_gmscore")a=this.ne;else if(this.vf)if(a){a=Dd("https",this.J,null,"/__/auth/callback");D(a,"fdlDomain",this.vf);D(a,"platform",this.xe);D(a,"appIdentifier",this.Gd);D(a,"authDomain",this.J);D(a,"link",this.ne);D(a,"appName",this.B||"");var b=Bi(this,a.toString());D(b,"link",a.toString());a=b.toString()}else a=Bi(this,this.Ug),D(a,"link",this.ne),a=a.toString();else a=this.Cb?this.Cb.split(".").reverse().join("."):this.Gb?"app-"+this.Gb.replace(/:/g,
"-"):this.Gd,a=Dd(a,this.Cb||this.Gb?"firebaseauth":"google",null,"/link"),D(a,"deep_link_id",this.ne),a=a.toString();return a};var Ci=function(a){var b="unauthorized-domain",c=void 0,d=F(a);a=d.ga;d=d.ua;d=="chrome-extension"?c=Zc("This chrome extension ID (chrome-extension://%s) is not authorized to run this operation. If you are the app developer, add it to the OAuth redirect domains list in the Firebase console -> Auth section -> Sign in method tab.",a):d=="http"||d=="https"?c=Zc("This domain (%s) is not authorized to run this operation. If you are the app developer, add it to the OAuth redirect domains list in the Firebase console -> Auth section -> Sign in method tab.",
a):b="operation-not-supported-in-this-environment";P.call(this,b,c)};q(Ci,P);var Ei=function(a){var b=Di(a);if(!(b&&b.sub&&b.iss&&b.aud&&b.exp))throw Error("Invalid JWT");this.Aj=a;this.uf=b.exp;this.Cj=b.sub;a=Date.now()/1E3;this.nj=b.iat||(a>this.uf?this.uf:a);this.Eb=b.email||null;this.wc=b.provider_id||b.firebase&&b.firebase.sign_in_provider||null;this.C=b.firebase&&b.firebase.tenant||null;this.Gi=!!b.is_anonymous||this.wc=="anonymous";this.nf=b.display_name||null};Ei.prototype.getEmail=function(){return this.Eb};Ei.prototype.isAnonymous=function(){return this.Gi};
Ei.prototype.toString=function(){return this.Aj};
var Fi=function(a){try{return new Ei(a)}catch(b){return null}},Di=function(a){if(!a)return null;a=a.split(".");if(a.length!=3)return null;a=a[1];for(var b=(4-a.length%4)%4,c=0;c<b;c++)a+=".";try{var d=Db(a);a=[];for(c=b=0;b<d.length;){var e=d[b++];if(e<128)a[c++]=String.fromCharCode(e);else if(e>191&&e<224){var f=d[b++];a[c++]=String.fromCharCode((e&31)<<6|f&63)}else if(e>239&&e<365){var g=d[b++],h=d[b++],k=d[b++],m=((e&7)<<18|(g&63)<<12|(h&63)<<6|k&63)-65536;a[c++]=String.fromCharCode(55296+(m>>
10));a[c++]=String.fromCharCode(56320+(m&1023))}else{var n=d[b++],r=d[b++];a[c++]=String.fromCharCode((e&15)<<12|(n&63)<<6|r&63)}}return JSON.parse(a.join(""))}catch(t){}return null};var Gi=function(a){var b=Di(a);if(!(b&&b.exp&&b.auth_time&&b.iat))throw new P("internal-error","An internal error occurred. The token obtained by Firebase appears to be malformed. Please retry the operation.");ai(this,{token:a,expirationTime:Rh(b.exp*1E3),authTime:Rh(b.auth_time*1E3),issuedAtTime:Rh(b.iat*1E3),signInProvider:b.firebase&&b.firebase.sign_in_provider?b.firebase.sign_in_provider:null,signInSecondFactor:b.firebase&&b.firebase.sign_in_second_factor?b.firebase.sign_in_second_factor:null,
claims:b})};var Hi=function(a,b){if(!a&&!b)throw new P("internal-error","Internal assert: no raw session string available");if(a&&b)throw new P("internal-error","Internal assert: unable to determine the session type");this.ee=a||null;this.yh=b||null;this.type=this.ee?"enroll":"signin"};Hi.prototype.Xc=function(){return this.ee?J(this.ee):J(this.yh)};Hi.prototype.m=function(){return this.type=="enroll"?{multiFactorSession:{idToken:this.ee}}:{multiFactorSession:{pendingCredential:this.yh}}};var Ii=function(){};Ii.prototype.Jb=function(){};Ii.prototype.pc=function(){};Ii.prototype.fd=function(){};Ii.prototype.m=function(){};
var Ji=function(a,b){return a.then(function(c){if(c.idToken){var d=Fi(c.idToken);if(!d||b!=d.Cj)throw new P("user-mismatch");return c}throw new P("user-mismatch");}).h(function(c){throw c&&c.code&&c.code=="auth/user-not-found"?new P("user-mismatch"):c;})},Ki=function(a,b){if(b)this.fb=b;else throw new P("internal-error","failed to construct a credential");O(this,"providerId",a);O(this,"signInMethod",a)};l=Ki.prototype;l.Jb=function(a){return Li(a,this.Mb())};
l.pc=function(a,b){var c=this.Mb();c.idToken=b;return Mi(a,c)};l.fd=function(a,b){var c=this.Mb();return Ji(Ni(a,c),b)};l.Mb=function(){return{pendingToken:this.fb,requestUri:"http://localhost"}};l.m=function(){return{providerId:this.providerId,signInMethod:this.signInMethod,pendingToken:this.fb}};
var Oi=function(a){if(a&&a.providerId&&a.signInMethod&&a.providerId.indexOf("saml.")==0&&a.pendingToken)try{return new Ki(a.providerId,a.pendingToken)}catch(b){}return null},Pi=function(a,b,c){this.fb=null;if(b.idToken||b.accessToken)b.idToken&&O(this,"idToken",b.idToken),b.accessToken&&O(this,"accessToken",b.accessToken),b.nonce&&!b.pendingToken&&O(this,"nonce",b.nonce),b.pendingToken&&(this.fb=b.pendingToken);else if(b.oauthToken&&b.oauthTokenSecret)O(this,"accessToken",b.oauthToken),O(this,"secret",
b.oauthTokenSecret);else throw new P("internal-error","failed to construct a credential");O(this,"providerId",a);O(this,"signInMethod",c)};l=Pi.prototype;l.Jb=function(a){return Li(a,this.Mb())};l.pc=function(a,b){var c=this.Mb();c.idToken=b;return Mi(a,c)};l.fd=function(a,b){var c=this.Mb();return Ji(Ni(a,c),b)};
l.Mb=function(){var a={};this.idToken&&(a.id_token=this.idToken);this.accessToken&&(a.access_token=this.accessToken);this.secret&&(a.oauth_token_secret=this.secret);a.providerId=this.providerId;this.nonce&&!this.fb&&(a.nonce=this.nonce);a={postBody:Hd(a).toString(),requestUri:"http://localhost"};this.fb&&(delete a.postBody,a.pendingToken=this.fb);return a};
l.m=function(){var a={providerId:this.providerId,signInMethod:this.signInMethod};this.idToken&&(a.oauthIdToken=this.idToken);this.accessToken&&(a.oauthAccessToken=this.accessToken);this.secret&&(a.oauthTokenSecret=this.secret);this.nonce&&(a.nonce=this.nonce);this.fb&&(a.pendingToken=this.fb);return a};
var Qi=function(a){if(a&&a.providerId&&a.signInMethod){var b={idToken:a.oauthIdToken,accessToken:a.oauthTokenSecret?null:a.oauthAccessToken,oauthTokenSecret:a.oauthTokenSecret,oauthToken:a.oauthTokenSecret&&a.oauthAccessToken,nonce:a.nonce,pendingToken:a.pendingToken};try{return new Pi(a.providerId,b,a.signInMethod)}catch(c){}}return null},Ri=function(a,b){this.Tj=b||[];ai(this,{providerId:a,isOAuthProvider:!0});this.Og={};this.If=(hi(a)||{}).dd||null;this.mf=null};
Ri.prototype.setCustomParameters=function(a){this.Og=fd(a);return this};var Si=function(a){if(!ji(a))throw new P("argument-error",'SAML provider IDs must be prefixed with "saml."');Ri.call(this,a,[])};x(Si,Ri);var Ti=function(a){Ri.call(this,a,fi);this.eg=[]};x(Ti,Ri);Ti.prototype.addScope=function(a){hb(this.eg,a)||this.eg.push(a);return this};Ti.prototype.dh=function(){return mb(this.eg)};
Ti.prototype.credential=function(a,b){a=v(a)?{idToken:a.idToken||null,accessToken:a.accessToken||null,nonce:a.rawNonce||null}:{idToken:a||null,accessToken:b||null};if(!a.idToken&&!a.accessToken)throw new P("argument-error","credential failed: must provide the ID token and/or the access token.");return new Pi(this.providerId,a,this.providerId)};var Ui=function(){Ti.call(this,"facebook.com")};x(Ui,Ti);O(Ui,"PROVIDER_ID","facebook.com");O(Ui,"FACEBOOK_SIGN_IN_METHOD","facebook.com");
var Vi=function(a){if(!a)throw new P("argument-error","credential failed: expected 1 argument (the OAuth access token).");var b=a;v(a)&&(b=a.accessToken);return(new Ui).credential({accessToken:b})},Wi=function(){Ti.call(this,"github.com")};x(Wi,Ti);O(Wi,"PROVIDER_ID","github.com");O(Wi,"GITHUB_SIGN_IN_METHOD","github.com");
var Xi=function(a){if(!a)throw new P("argument-error","credential failed: expected 1 argument (the OAuth access token).");var b=a;v(a)&&(b=a.accessToken);return(new Wi).credential({accessToken:b})},Yi=function(){Ti.call(this,"google.com");this.addScope("profile")};x(Yi,Ti);O(Yi,"PROVIDER_ID","google.com");O(Yi,"GOOGLE_SIGN_IN_METHOD","google.com");
var Zi=function(a,b){var c=a;v(a)&&(c=a.idToken,b=a.accessToken);return(new Yi).credential({idToken:c,accessToken:b})},$i=function(){Ri.call(this,"twitter.com",ei)};x($i,Ri);O($i,"PROVIDER_ID","twitter.com");O($i,"TWITTER_SIGN_IN_METHOD","twitter.com");
var aj=function(a,b){var c=a;v(c)||(c={oauthToken:a,oauthTokenSecret:b});if(!c.oauthToken||!c.oauthTokenSecret)throw new P("argument-error","credential failed: expected 2 arguments (the OAuth access token and secret).");return new Pi("twitter.com",c,"twitter.com")},cj=function(a,b,c){this.Eb=a;this.gd=b;O(this,"providerId","password");O(this,"signInMethod",c===bj.EMAIL_LINK_SIGN_IN_METHOD?bj.EMAIL_LINK_SIGN_IN_METHOD:bj.EMAIL_PASSWORD_SIGN_IN_METHOD)};
cj.prototype.Jb=function(a){return this.signInMethod==bj.EMAIL_LINK_SIGN_IN_METHOD?Q(a,dj,{email:this.Eb,oobCode:this.gd}):Q(a,ej,{email:this.Eb,password:this.gd})};cj.prototype.pc=function(a,b){return this.signInMethod==bj.EMAIL_LINK_SIGN_IN_METHOD?Q(a,fj,{idToken:b,email:this.Eb,oobCode:this.gd}):Q(a,gj,{idToken:b,email:this.Eb,password:this.gd})};cj.prototype.fd=function(a,b){return Ji(this.Jb(a),b)};cj.prototype.m=function(){return{email:this.Eb,password:this.gd,signInMethod:this.signInMethod}};
var hj=function(a){return a&&a.email&&a.password?new cj(a.email,a.password,a.signInMethod):null},bj=function(){ai(this,{providerId:"password",isOAuthProvider:!1})},jj=function(a,b){b=ij(b);if(!b)throw new P("argument-error","Invalid email link!");return new cj(a,b.code,bj.EMAIL_LINK_SIGN_IN_METHOD)},ij=function(a){a=Ai(a);return(a=wi(a))&&a.operation==="EMAIL_SIGNIN"?a:null};ai(bj,{PROVIDER_ID:"password"});ai(bj,{EMAIL_LINK_SIGN_IN_METHOD:"emailLink"});ai(bj,{EMAIL_PASSWORD_SIGN_IN_METHOD:"password"});
var kj=function(a){if(!(a.verificationId&&a.Se||a.zd&&a.phoneNumber))throw new P("internal-error");this.V=a;O(this,"providerId","phone");this.providerId="phone";O(this,"signInMethod","phone")};kj.prototype.Jb=function(a){return a.verifyPhoneNumber(lj(this))};kj.prototype.pc=function(a,b){var c=lj(this);c.idToken=b;return Q(a,mj,c)};kj.prototype.fd=function(a,b){var c=lj(this);c.operation="REAUTH";a=Q(a,nj,c);return Ji(a,b)};
kj.prototype.m=function(){var a={providerId:"phone"};this.V.verificationId&&(a.verificationId=this.V.verificationId);this.V.Se&&(a.verificationCode=this.V.Se);this.V.zd&&(a.temporaryProof=this.V.zd);this.V.phoneNumber&&(a.phoneNumber=this.V.phoneNumber);return a};
var oj=function(a){if(a&&a.providerId==="phone"&&(a.verificationId&&a.verificationCode||a.temporaryProof&&a.phoneNumber)){var b={};C(["verificationId","verificationCode","temporaryProof","phoneNumber"],function(c){a[c]&&(b[c]=a[c])});return new kj(b)}return null},lj=function(a){return a.V.zd&&a.V.phoneNumber?{temporaryProof:a.V.zd,phoneNumber:a.V.phoneNumber}:{sessionInfo:a.V.verificationId,code:a.V.Se}},pj=function(a){try{this.Jd=a||firebase.auth()}catch(b){throw new P("argument-error","Either an instance of firebase.auth.Auth must be passed as an argument to the firebase.auth.PhoneAuthProvider constructor, or the default firebase App instance must be initialized via firebase.initializeApp().");
}ai(this,{providerId:"phone",isOAuthProvider:!1})};
pj.prototype.verifyPhoneNumber=function(a,b){var c=this.Jd.i;return J(b.verify()).then(function(d){if(typeof d!=="string")throw new P("argument-error","An implementation of firebase.auth.ApplicationVerifier.prototype.verify() must return a firebase.Promise that resolves with a string.");switch(b.type){case "recaptcha":var e=v(a)?a.session:null,f=v(a)?a.phoneNumber:a;return(e&&e.type=="enroll"?e.Xc().then(function(g){return qj(c,{idToken:g,phoneEnrollmentInfo:{phoneNumber:f,recaptchaToken:d}})}):e&&
e.type=="signin"?e.Xc().then(function(g){return rj(c,{mfaPendingCredential:g,mfaEnrollmentId:a.multiFactorHint&&a.multiFactorHint.uid||a.multiFactorUid,phoneSignInInfo:{recaptchaToken:d}})}):sj(c,{phoneNumber:f,recaptchaToken:d})).then(function(g){typeof b.reset==="function"&&b.reset();return g},function(g){typeof b.reset==="function"&&b.reset();throw g;});default:throw new P("argument-error",'Only firebase.auth.ApplicationVerifiers with type="recaptcha" are currently supported.');}})};
var tj=function(a,b){if(!a)throw new P("missing-verification-id");if(!b)throw new P("missing-verification-code");return new kj({verificationId:a,Se:b})};ai(pj,{PROVIDER_ID:"phone"});ai(pj,{PHONE_SIGN_IN_METHOD:"phone"});
var uj=function(a){if(a.temporaryProof&&a.phoneNumber)return new kj({zd:a.temporaryProof,phoneNumber:a.phoneNumber});var b=a&&a.providerId;if(!b||b==="password")return null;var c=a&&a.oauthAccessToken,d=a&&a.oauthTokenSecret,e=a&&a.nonce,f=a&&a.oauthIdToken,g=a&&a.pendingToken;try{switch(b){case "google.com":return Zi(f,c);case "facebook.com":return Vi(c);case "github.com":return Xi(c);case "twitter.com":return aj(c,d);default:return c||d||f||g?g?b.indexOf("saml.")==0?new Ki(b,g):new Pi(b,{pendingToken:g,
idToken:a.oauthIdToken,accessToken:a.oauthAccessToken},b):(new Ti(b)).credential({idToken:f,accessToken:c,rawNonce:e}):null}}catch(h){return null}},vj=function(a){if(!a.isOAuthProvider)throw new P("invalid-oauth-provider");};var wj=function(a,b,c){P.call(this,a,c);a=b||{};a.email&&O(this,"email",a.email);a.phoneNumber&&O(this,"phoneNumber",a.phoneNumber);a.credential&&O(this,"credential",a.credential);a.tenantId&&O(this,"tenantId",a.tenantId)};q(wj,P);wj.prototype.m=function(){var a={code:this.code,message:this.message};this.email&&(a.email=this.email);this.phoneNumber&&(a.phoneNumber=this.phoneNumber);this.tenantId&&(a.tenantId=this.tenantId);var b=this.credential&&this.credential.m();b&&hd(a,b);return a};
wj.prototype.toJSON=function(){return this.m()};var xj=function(a){if(a.code){var b=a.code||"";b.indexOf("auth/")==0&&(b=b.substring(5));var c={credential:uj(a),tenantId:a.tenantId};if(a.email)c.email=a.email;else if(a.phoneNumber)c.phoneNumber=a.phoneNumber;else if(!c.credential)return new P(b,a.message||void 0);return new wj(b,c,a.message)}return null};var yj=ra(["https://apis.google.com/js/client.js?onload=",""]),zj=function(a){this.Dk=a};q(zj,sf);zj.prototype.Oc=function(){return new this.Dk};
var Ej=function(a,b,c,d){this.A=a;b=b||{};this.Uh=b.secureTokenEndpoint||"https://securetoken.googleapis.com/v1/token";this.fk=b.secureTokenTimeout||Aj;this.Ge=fd(b.secureTokenHeaders||Bj);this.Xg=b.firebaseEndpoint||"https://www.googleapis.com/identitytoolkit/v3/relyingparty/";this.ih=b.identityPlatformEndpoint||"https://identitytoolkit.googleapis.com/v2/";this.Wi=b.firebaseTimeout||Cj;this.Hb=fd(b.firebaseHeaders||Dj);c&&(this.Hb["X-Client-Version"]=c,this.Ge["X-Client-Version"]=c);d&&(this.Hb["X-Firebase-AppCheck"]=
d);a=vh()=="Node";a=u.XMLHttpRequest||a&&firebase.INTERNAL.node&&firebase.INTERNAL.node.XMLHttpRequest;if(!a&&!uh())throw new P("internal-error","The XMLHttpRequest compatibility library was not found.");this.Ee=void 0;uh()?this.Ee=new Af({Ck:self}):wh()?this.Ee=new zj(a):this.Ee=new vf;this.C=null},Fj,Gj=function(a,b){b?a.Hb["X-Firebase-Locale"]=b:delete a.Hb["X-Firebase-Locale"]},Ij=function(a,b){b&&(a.Uh=Hj("https://securetoken.googleapis.com/v1/token",b),a.Xg=Hj("https://www.googleapis.com/identitytoolkit/v3/relyingparty/",
b),a.ih=Hj("https://identitytoolkit.googleapis.com/v2/",b))},Hj=function(a,b){a=F(a);b=F(b.url);sd(a,a.ga+a.eb);od(a,b.ua);qd(a,b.ga);rd(a,b.Sa);return a.toString()},Jj=function(a,b){b?(a.Hb["X-Client-Version"]=b,a.Ge["X-Client-Version"]=b):(delete a.Hb["X-Client-Version"],delete a.Ge["X-Client-Version"])};Ej.prototype.He=function(a,b,c,d,e,f){if(fh()||uh())var g=w(this.hk,this);else Fj||(Fj=new I(function(h,k){Kj(h,k)})),g=w(this.gk,this);g(a,b,c,d,e,f)};
Ej.prototype.hk=function(a,b,c,d,e,f){if(uh()&&(typeof u.fetch==="undefined"||typeof u.Headers==="undefined"||typeof u.Request==="undefined"))throw new P("operation-not-supported-in-this-environment","fetch, Headers and Request native APIs or equivalent Polyfills must be available to support HTTP requests from a Worker environment.");var g=new L(this.Ee);if(f){g.Ec=Math.max(0,f);var h=setTimeout(function(){g.dispatchEvent("timeout")},f)}g.listen("complete",function(){h&&clearTimeout(h);var k=null;
try{k=JSON.parse(Rg(this))||null}catch(m){k=null}b&&b(k)});lf(g,"ready",function(){h&&clearTimeout(h);this.dispose()});lf(g,"timeout",function(){h&&clearTimeout(h);this.dispose();b&&b(null)});g.send(a,c,d,e)};var Kj=function(a,b){if(((window.gapi||{}).client||{}).request)a();else{u[Lj]=function(){((window.gapi||{}).client||{}).request?a():b(Error("CORS_UNSUPPORTED"))};var c=bd(yj,Lj);zg(Hg(c),function(){b(Error("CORS_UNSUPPORTED"))})}};
Ej.prototype.gk=function(a,b,c,d,e){var f=this;Fj.then(function(){window.gapi.client.setApiKey(f.A);var g=window.gapi.auth.getToken();window.gapi.auth.setToken(null);window.gapi.client.request({path:a,method:c,body:d,headers:e,authType:"none",callback:function(h){window.gapi.auth.setToken(g);b&&b(h)}})}).h(function(g){b&&b({error:{message:g&&g.message||"CORS_UNSUPPORTED"}})})};
var Nj=function(a,b){return new I(function(c,d){b.grant_type=="refresh_token"&&b.refresh_token||b.grant_type=="authorization_code"&&b.code?a.He(a.Uh+"?key="+encodeURIComponent(a.A),function(e){e?e.error?d(Mj(e)):e.access_token&&e.refresh_token?c(e):d(new P("internal-error")):d(new P("network-request-failed"))},"POST",Hd(b).toString(),a.Ge,a.fk.get()):d(new P("internal-error"))})},Oj=function(a,b,c,d,e,f,g){var h=F(b+c);D(h,"key",a.A);g&&D(h,"cb",Date.now().toString());var k=d=="GET";if(k)for(var m in e)e.hasOwnProperty(m)&&
D(h,m,e[m]);return new I(function(n,r){a.He(h.toString(),function(t){t?t.error?r(Mj(t,f||{})):n(t):r(new P("network-request-failed"))},d,k?void 0:JSON.stringify(Ih(e)),a.Hb,a.Wi.get())})},Pj=function(a){a=a.email;if(typeof a!=="string"||!nh.test(a))throw new P("invalid-email");},Qj=function(a){"email"in a&&Pj(a)},Sj=function(a,b,c,d,e,f){var g=ji(b);var h={};e&&e.length?(h[b]=e.join(","),e=JSON.stringify(h)):e=null;c={identifier:null,providerId:b,continueUri:c,customParameter:d||{},oauthScope:e,sessionId:f};
g&&(delete c.customParameter,delete c.oauthScope);f&&b=="google.com"&&(c.authFlowType="CODE_FLOW");return Q(a,Rj,c)},Uj=function(a,b){return Q(a,Tj,{identifier:b,continueUri:Eh()?ah():"http://localhost"}).then(function(c){return c.signinMethods||[]})},Wj=function(a){return Q(a,Vj,{}).then(function(b){return b.authorizedDomains||[]})},Xj=function(a){return Q(a,Vj,{}).then(function(b){return b.projectId||""})},Yj=function(a,b){return Q(a,Vj,{iosBundleId:b}).then(function(){})},Zj=function(a,b,c){b=
{androidPackageName:b};c&&(b.sha1Cert=c);return Q(a,Vj,b).then(function(){})},ak=function(a,b){return Q(a,Vj,{clientId:b}).then(function(){})},bk=function(a,b){return Q(a,Vj,{firebaseAppId:b}).then(function(){})},ck=function(a){if(!a.idToken){if(a.mfaPendingCredential)throw new P("multi-factor-auth-required",null,fd(a));throw new P("internal-error");}},dk=function(a){if(a.phoneNumber||a.temporaryProof){if(!a.phoneNumber||!a.temporaryProof)throw new P("internal-error");}else{if(!a.sessionInfo)throw new P("missing-verification-id");
if(!a.code)throw new P("missing-verification-code");}};l=Ej.prototype;l.signInAnonymously=function(){return Q(this,ek,{})};l.updateEmail=function(a,b){return Q(this,fk,{idToken:a,email:b})};l.updatePassword=function(a,b){return Q(this,gj,{idToken:a,password:b})};l.updateProfile=function(a,b){var c={idToken:a},d=[];cd(gk,function(e,f){var g=b[f];g===null?d.push(e):f in b&&(c[f]=g)});d.length&&(c.deleteAttribute=d);return Q(this,fk,c)};
l.sendPasswordResetEmail=function(a,b){a={requestType:"PASSWORD_RESET",email:a};hd(a,b);return Q(this,hk,a)};l.sendSignInLinkToEmail=function(a,b){a={requestType:"EMAIL_SIGNIN",email:a};hd(a,b);return Q(this,ik,a)};l.sendEmailVerification=function(a,b){a={requestType:"VERIFY_EMAIL",idToken:a};hd(a,b);return Q(this,jk,a)};l.verifyBeforeUpdateEmail=function(a,b,c){a={requestType:"VERIFY_AND_CHANGE_EMAIL",idToken:a,newEmail:b};hd(a,c);return Q(this,kk,a)};var sj=function(a,b){return Q(a,lk,b)};
Ej.prototype.verifyPhoneNumber=function(a){return Q(this,mk,a)};
var qj=function(a,b){return Q(a,nk,b).then(function(c){return c.phoneSessionInfo.sessionInfo})},ok=function(a){if(!a.phoneVerificationInfo)throw new P("internal-error");if(!a.phoneVerificationInfo.sessionInfo)throw new P("missing-verification-id");if(!a.phoneVerificationInfo.code)throw new P("missing-verification-code");},rj=function(a,b){return Q(a,pk,b).then(function(c){return c.phoneResponseInfo.sessionInfo})},rk=function(a,b,c){return Q(a,qk,{idToken:b,deleteProvider:c})},sk=function(a){if(!a.requestUri||
!a.sessionId&&!a.postBody&&!a.pendingToken)throw new P("internal-error");},tk=function(a,b){b.oauthIdToken&&b.providerId&&b.providerId.indexOf("oidc.")==0&&!b.pendingToken&&(a.sessionId?b.nonce=a.sessionId:a.postBody&&(a=new wd(a.postBody),a.Nc("nonce")&&(b.nonce=a.get("nonce"))));return b},vk=function(a){var b=null;a.needConfirmation?(a.code="account-exists-with-different-credential",b=xj(a)):a.errorMessage=="FEDERATED_USER_ID_ALREADY_LINKED"?(a.code="credential-already-in-use",b=xj(a)):a.errorMessage==
"EMAIL_EXISTS"?(a.code="email-already-in-use",b=xj(a)):a.errorMessage&&(b=uk(a.errorMessage));if(b)throw b;ck(a)},Li=function(a,b){b.returnIdpCredential=!0;return Q(a,wk,b)},Mi=function(a,b){b.returnIdpCredential=!0;return Q(a,xk,b)},Ni=function(a,b){b.returnIdpCredential=!0;b.autoCreate=!1;return Q(a,yk,b)},zk=function(a){if(!a.oobCode)throw new P("invalid-action-code");};Ej.prototype.confirmPasswordReset=function(a,b){return Q(this,Ak,{oobCode:a,newPassword:b})};
Ej.prototype.checkActionCode=function(a){return Q(this,Bk,{oobCode:a})};Ej.prototype.applyActionCode=function(a){return Q(this,Ck,{oobCode:a})};
var Q=function(a,b,c){if(!ci(c,b.ba))return K(new P("internal-error"));var d=!!b.Bd,e=b.httpMethod||"POST",f;return J(c).then(b.G).then(function(){b.Ja&&(c.returnSecureToken=!0);b.I&&a.C&&typeof c.tenantId==="undefined"&&(c.tenantId=a.C);return d?Oj(a,a.ih,b.endpoint,e,c,b.Ng,b.Ld||!1):Oj(a,a.Xg,b.endpoint,e,c,b.Ng,b.Ld||!1)}).then(function(g){f=g;return b.Be?b.Be(c,f):f}).then(b.O).then(function(){if(!b.Ta)return f;if(!(b.Ta in f))throw new P("internal-error");return f[b.Ta]})},uk=function(a){return Mj({error:{errors:[{message:a}],
code:400,reason:a}})},Mj=function(a,b){var c=(a.error&&a.error.errors&&a.error.errors[0]||{}).reason||"";var d={keyInvalid:"invalid-api-key",ipRefererBlocked:"app-not-authorized"};if(c=d[c]?new P(d[c]):null)return c;c=a.error&&(a.error.reason||a.error.message)||"";d={INVALID_CUSTOM_TOKEN:"invalid-custom-token",CREDENTIAL_MISMATCH:"custom-token-mismatch",MISSING_CUSTOM_TOKEN:"internal-error",INVALID_IDENTIFIER:"invalid-email",MISSING_CONTINUE_URI:"internal-error",INVALID_EMAIL:"invalid-email",INVALID_PASSWORD:"wrong-password",
USER_DISABLED:"user-disabled",MISSING_PASSWORD:"internal-error",EMAIL_EXISTS:"email-already-in-use",PASSWORD_LOGIN_DISABLED:"operation-not-allowed",INVALID_IDP_RESPONSE:"invalid-credential",INVALID_PENDING_TOKEN:"invalid-credential",FEDERATED_USER_ID_ALREADY_LINKED:"credential-already-in-use",MISSING_OR_INVALID_NONCE:"missing-or-invalid-nonce",INVALID_MESSAGE_PAYLOAD:"invalid-message-payload",INVALID_RECIPIENT_EMAIL:"invalid-recipient-email",INVALID_SENDER:"invalid-sender",EMAIL_NOT_FOUND:"user-not-found",
RESET_PASSWORD_EXCEED_LIMIT:"too-many-requests",EXPIRED_OOB_CODE:"expired-action-code",INVALID_OOB_CODE:"invalid-action-code",MISSING_OOB_CODE:"internal-error",INVALID_PROVIDER_ID:"invalid-provider-id",CREDENTIAL_TOO_OLD_LOGIN_AGAIN:"requires-recent-login",INVALID_ID_TOKEN:"invalid-user-token",TOKEN_EXPIRED:"user-token-expired",USER_NOT_FOUND:"user-token-expired",CORS_UNSUPPORTED:"cors-unsupported",DYNAMIC_LINK_NOT_ACTIVATED:"dynamic-link-not-activated",INVALID_APP_ID:"invalid-app-id",TOO_MANY_ATTEMPTS_TRY_LATER:"too-many-requests",
WEAK_PASSWORD:"weak-password",PASSWORD_DOES_NOT_MEET_REQUIREMENTS:"password-does-not-meet-requirements",OPERATION_NOT_ALLOWED:"operation-not-allowed",USER_CANCELLED:"user-cancelled",CAPTCHA_CHECK_FAILED:"captcha-check-failed",INVALID_APP_CREDENTIAL:"invalid-app-credential",INVALID_CODE:"invalid-verification-code",INVALID_PHONE_NUMBER:"invalid-phone-number",INVALID_SESSION_INFO:"invalid-verification-id",INVALID_TEMPORARY_PROOF:"invalid-credential",INVALID_TENANT_ID:"invalid-tenant-id",MISSING_APP_CREDENTIAL:"missing-app-credential",
MISSING_CODE:"missing-verification-code",MISSING_PHONE_NUMBER:"missing-phone-number",MISSING_SESSION_INFO:"missing-verification-id",QUOTA_EXCEEDED:"quota-exceeded",SESSION_EXPIRED:"code-expired",REJECTED_CREDENTIAL:"rejected-credential",INVALID_CONTINUE_URI:"invalid-continue-uri",MISSING_ANDROID_PACKAGE_NAME:"missing-android-pkg-name",MISSING_IOS_BUNDLE_ID:"missing-ios-bundle-id",UNAUTHORIZED_DOMAIN:"unauthorized-continue-uri",INVALID_DYNAMIC_LINK_DOMAIN:"invalid-dynamic-link-domain",INVALID_OAUTH_CLIENT_ID:"invalid-oauth-client-id",
INVALID_CERT_HASH:"invalid-cert-hash",UNSUPPORTED_TENANT_OPERATION:"unsupported-tenant-operation",TENANT_ID_MISMATCH:"tenant-id-mismatch",ADMIN_ONLY_OPERATION:"admin-restricted-operation",INVALID_MFA_PENDING_CREDENTIAL:"invalid-multi-factor-session",MFA_ENROLLMENT_NOT_FOUND:"multi-factor-info-not-found",MISSING_MFA_PENDING_CREDENTIAL:"missing-multi-factor-session",MISSING_MFA_ENROLLMENT_ID:"missing-multi-factor-info",EMAIL_CHANGE_NEEDS_VERIFICATION:"email-change-needs-verification",SECOND_FACTOR_EXISTS:"second-factor-already-in-use",
SECOND_FACTOR_LIMIT_EXCEEDED:"maximum-second-factor-count-exceeded",UNSUPPORTED_FIRST_FACTOR:"unsupported-first-factor",UNVERIFIED_EMAIL:"unverified-email",API_KEY_SERVICE_BLOCKED:"api-key-service-blocked"};b=b||{};hd(d,b);b=(b=c.match(/^[^\s]+\s*:\s*([\s\S]*)$/))&&b.length>1?b[1]:void 0;for(var e in d)if(c.indexOf(e)===0)return new P(d[e],b);!b&&a&&(b=Hh(a));return new P("internal-error",b)},Aj=new Nh(3E4,6E4),Bj={"Content-Type":"application/x-www-form-urlencoded"},Cj=new Nh(3E4,6E4),Dj={"Content-Type":"application/json"},
Lj="__fcb"+Math.floor(Math.random()*1E6).toString(),gk={displayName:"DISPLAY_NAME",photoUrl:"PHOTO_URL"},Ck={endpoint:"setAccountInfo",G:zk,Ta:"email",I:!0},Bk={endpoint:"resetPassword",G:zk,O:function(a){var b=a.requestType;if(!b||!a.email&&b!="EMAIL_SIGNIN"&&b!="VERIFY_AND_CHANGE_EMAIL")throw new P("internal-error");},I:!0},Dk={endpoint:"signupNewUser",G:function(a){Pj(a);if(!a.password)throw new P("weak-password");},O:ck,Ja:!0,I:!0},Tj={endpoint:"createAuthUri",I:!0},Ek={endpoint:"deleteAccount",
ba:["idToken"]},qk={endpoint:"setAccountInfo",ba:["idToken","deleteProvider"],G:function(a){if(!Array.isArray(a.deleteProvider))throw new P("internal-error");}},dj={endpoint:"emailLinkSignin",ba:["email","oobCode"],G:Pj,O:ck,Ja:!0,I:!0},fj={endpoint:"emailLinkSignin",ba:["idToken","email","oobCode"],G:Pj,O:ck,Ja:!0},Fk={endpoint:"accounts/mfaEnrollment:finalize",ba:["idToken","phoneVerificationInfo"],G:ok,O:ck,I:!0,Bd:!0},Gk={endpoint:"accounts/mfaSignIn:finalize",ba:["mfaPendingCredential","phoneVerificationInfo"],
G:ok,O:ck,I:!0,Bd:!0},Hk={endpoint:"getAccountInfo"},Rj={endpoint:"createAuthUri",G:function(a){if(!a.continueUri)throw new P("missing-continue-uri");if(!a.providerId)throw new P("internal-error","A provider ID must be provided in the request.");},O:function(a){if(!a.authUri)throw new P("internal-error","Unable to determine the authorization endpoint for the specified provider. This may be an issue in the provider configuration.");if(!a.sessionId)throw new P("internal-error");},I:!0},ik={endpoint:"getOobConfirmationCode",
ba:["requestType"],G:function(a){if(a.requestType!="EMAIL_SIGNIN")throw new P("internal-error");Pj(a)},Ta:"email",I:!0},jk={endpoint:"getOobConfirmationCode",ba:["idToken","requestType"],G:function(a){if(a.requestType!="VERIFY_EMAIL")throw new P("internal-error");},Ta:"email",I:!0},kk={endpoint:"getOobConfirmationCode",ba:["idToken","newEmail","requestType"],G:function(a){if(a.requestType!="VERIFY_AND_CHANGE_EMAIL")throw new P("internal-error");},Ta:"email",I:!0},hk={endpoint:"getOobConfirmationCode",
ba:["requestType"],G:function(a){if(a.requestType!="PASSWORD_RESET")throw new P("internal-error");Pj(a)},Ta:"email",I:!0},Vj={Ld:!0,endpoint:"getProjectConfig",httpMethod:"GET"},Ik={Ld:!0,endpoint:"getRecaptchaParam",httpMethod:"GET",O:function(a){if(!a.recaptchaSiteKey)throw new P("internal-error");}},Ak={endpoint:"resetPassword",G:zk,Ta:"email",I:!0},Jk={Ld:!0,endpoint:"getProjectConfig",httpMethod:"GET",Ta:"dynamicLinksDomain"},lk={endpoint:"sendVerificationCode",ba:["phoneNumber","recaptchaToken"],
Ta:"sessionInfo",I:!0},fk={endpoint:"setAccountInfo",ba:["idToken"],G:Qj,Ja:!0},gj={endpoint:"setAccountInfo",ba:["idToken"],G:function(a){Qj(a);if(!a.password)throw new P("weak-password");},O:ck,Ja:!0},ek={endpoint:"signupNewUser",O:ck,Ja:!0,I:!0},nk={endpoint:"accounts/mfaEnrollment:start",ba:["idToken","phoneEnrollmentInfo"],G:function(a){if(!a.phoneEnrollmentInfo)throw new P("internal-error");if(!a.phoneEnrollmentInfo.phoneNumber)throw new P("missing-phone-number");if(!a.phoneEnrollmentInfo.recaptchaToken)throw new P("missing-app-credential");
},O:function(a){if(!a.phoneSessionInfo||!a.phoneSessionInfo.sessionInfo)throw new P("internal-error");},I:!0,Bd:!0},pk={endpoint:"accounts/mfaSignIn:start",ba:["mfaPendingCredential","mfaEnrollmentId","phoneSignInInfo"],G:function(a){if(!a.phoneSignInInfo||!a.phoneSignInInfo.recaptchaToken)throw new P("missing-app-credential");},O:function(a){if(!a.phoneResponseInfo||!a.phoneResponseInfo.sessionInfo)throw new P("internal-error");},I:!0,Bd:!0},wk={endpoint:"verifyAssertion",G:sk,Be:tk,O:vk,Ja:!0,I:!0},
yk={endpoint:"verifyAssertion",G:sk,Be:tk,O:function(a){if(a.errorMessage&&a.errorMessage=="USER_NOT_FOUND")throw new P("user-not-found");if(a.errorMessage)throw uk(a.errorMessage);ck(a)},Ja:!0,I:!0},xk={endpoint:"verifyAssertion",G:function(a){sk(a);if(!a.idToken)throw new P("internal-error");},Be:tk,O:vk,Ja:!0},Kk={endpoint:"verifyCustomToken",G:function(a){if(!a.token)throw new P("invalid-custom-token");},O:ck,Ja:!0,I:!0},ej={endpoint:"verifyPassword",G:function(a){Pj(a);if(!a.password)throw new P("wrong-password");
},O:ck,Ja:!0,I:!0},mk={endpoint:"verifyPhoneNumber",G:dk,O:ck,I:!0},mj={endpoint:"verifyPhoneNumber",G:function(a){if(!a.idToken)throw new P("internal-error");dk(a)},O:function(a){if(a.temporaryProof)throw a.code="credential-already-in-use",xj(a);ck(a)}},nj={Ng:{USER_NOT_FOUND:"user-not-found"},endpoint:"verifyPhoneNumber",G:dk,O:ck,I:!0},Lk={endpoint:"accounts/mfaEnrollment:withdraw",ba:["idToken","mfaEnrollmentId"],O:function(a){if(!!a.idToken^!!a.refreshToken)throw new P("internal-error");},I:!0,
Bd:!0};var Mk=ra(["https://apis.google.com/js/api.js?onload=",""]),Ok=function(a){this.Vb=a;this.he=null;this.Qf=Nk(this)},Nk=function(a){return Pk().then(function(){return new I(function(b,c){N("gapi.iframes.getContext")().open({where:document.body,url:a.Vb,messageHandlersFilter:N("gapi.iframes.CROSS_ORIGIN_IFRAMES_FILTER"),attributes:{style:{position:"absolute",top:"-100px",width:"1px",height:"1px"}},dontclear:!0},function(d){a.he=d;a.he.restyle({setHideOnLeave:!1});var e=setTimeout(function(){c(Error("Network Error"))},
Qk.get()),f=function(){clearTimeout(e);b()};d.ping(f).then(f,function(){c(Error("Network Error"))})})})})};Ok.prototype.sendMessage=function(a){var b=this;return this.Qf.then(function(){return new I(function(c){b.he.send(a.type,a,c,N("gapi.iframes.CROSS_ORIGIN_IFRAMES_FILTER"))})})};
var Rk=function(a,b){a.Qf.then(function(){a.he.register("authEvent",b,N("gapi.iframes.CROSS_ORIGIN_IFRAMES_FILTER"))})},Pk=function(){return Sk?Sk:Sk=(new I(function(a,b){var c=function(){Mh();N("gapi.load")("gapi.iframes",{callback:a,ontimeout:function(){Mh();b(Error("Network Error"))},timeout:Tk.get()})};if(N("gapi.iframes.Iframe"))a();else if(N("gapi.load"))c();else{var d="__iframefcb"+Math.floor(Math.random()*1E6).toString();u[d]=function(){N("gapi.load")?c():b(Error("Network Error"))};d=bd(Mk,
d);J(Hg(d)).h(function(){b(Error("Network Error"))})}})).h(function(a){Sk=null;throw a;})},Tk=new Nh(3E4,6E4),Qk=new Nh(5E3,15E3),Sk=null;var Uk=function(a,b,c,d){this.J=a;this.A=b;this.B=c;this.s=d;this.Xb=null;this.s?(a=F(this.s.url),a=Dd(a.ua,a.ga,a.Sa,"/emulator/auth/iframe",null,null)):a=Dd("https",this.J,null,"/__/auth/iframe",null,null);this.hb=a;D(this.hb,"apiKey",this.A);D(this.hb,"appName",this.B);this.pa=null;this.U=[]};Uk.prototype.lg=function(a){this.Xb=a;return this};Uk.prototype.ig=function(a){this.pa=a;return this};
Uk.prototype.toString=function(){this.Xb?D(this.hb,"v",this.Xb):this.hb.removeParameter("v");this.pa?D(this.hb,"eid",this.pa):this.hb.removeParameter("eid");this.U.length?D(this.hb,"fw",this.U.join(",")):this.hb.removeParameter("fw");return this.hb.toString()};var Vk=function(a,b,c,d,e,f){this.J=a;this.A=b;this.B=c;this.Ii=d;this.s=f;this.Xb=this.T=this.zc=null;this.xc=e;this.C=this.pa=null};Vk.prototype.kg=function(a){this.C=a;return this};Vk.prototype.lg=function(a){this.Xb=a;return this};
Vk.prototype.ig=function(a){this.pa=a;return this};
Vk.prototype.toString=function(){if(this.s){var a=F(this.s.url);a=Dd(a.ua,a.ga,a.Sa,"/emulator/auth/handler",null,null)}else a=Dd("https",this.J,null,"/__/auth/handler",null,null);D(a,"apiKey",this.A);D(a,"appName",this.B);D(a,"authType",this.Ii);if(this.xc.isOAuthProvider){var b=this.xc;try{var c=firebase.app(this.B).auth().Fa}catch(f){c=null}b.mf=c;D(a,"providerId",this.xc.providerId);c=this.xc;b=Ih(c.Og);for(var d in b)b[d]=b[d].toString();d=Jh(b,c.Tj);c.If&&c.mf&&!d[c.If]&&(d[c.If]=c.mf);ed(d)||
D(a,"customParameters",Hh(d))}typeof this.xc.dh==="function"&&(d=this.xc.dh(),d.length&&D(a,"scopes",d.join(",")));this.zc?D(a,"redirectUrl",this.zc):a.removeParameter("redirectUrl");this.T?D(a,"eventId",this.T):a.removeParameter("eventId");this.Xb?D(a,"v",this.Xb):a.removeParameter("v");if(this.Ed)for(var e in this.Ed)this.Ed.hasOwnProperty(e)&&!E(a,e)&&D(a,e,this.Ed[e]);this.C?D(a,"tid",this.C):a.removeParameter("tid");this.pa?D(a,"eid",this.pa):a.removeParameter("eid");e=Wk(this.B);e.length&&D(a,
"fw",e.join(","));return a.toString()};var Wk=function(a){try{return mb(firebase.app(a).auth().U)}catch(b){return[]}},Xk=function(a,b,c,d,e,f){this.J=a;this.A=b;this.B=c;this.s=f;this.Pa=d||null;this.pa=e||null;this.i=this.Df=this.ah=null;this.Xa=[];this.je=this.cb=null},Yk=function(a){var b=b||ah();return Wj(a).then(function(c){if(!mh(c,b))throw new Ci(ah());})};l=Xk.prototype;
l.initialize=function(){if(this.je)return this.je;var a=this;return this.je=oh().then(function(){if(!a.Df){var b=a.J,c=a.A,d=a.B,e=a.Pa,f=a.pa,g=Wk(a.B);b=(new Uk(b,c,d,a.s)).lg(e).ig(f);b.U=mb(g||[]);a.Df=b.toString()}a.ge=new Ok(a.Df);Zk(a)})};l.wd=function(a,b,c){var d=new P("popup-closed-by-user"),e=new P("web-storage-unsupported"),f=this,g=!1;return this.Lb().then(function(){$k(f).then(function(h){h||(a&&hh(a),b(e),g=!0)})}).h(function(){}).then(function(){if(!g)return kh(a)}).then(function(){if(!g)return Tg(c).then(function(){b(d)})})};
l.di=function(){var a=M();return!Gh(a)&&!Lh(a)};l.fh=function(){return!1};
l.ld=function(a,b,c,d,e,f,g,h){if(!a)return K(new P("popup-blocked"));if(g&&!Gh())return this.Lb().h(function(m){hh(a);e(m)}),d(),J();this.cb||(this.cb=Yk(al(this)));var k=this;return this.cb.then(function(){var m=k.Lb().h(function(n){hh(a);e(n);throw n;});d();return m}).then(function(){vj(c);if(!g){var m=bl(k.J,k.A,k.B,b,c,null,f,k.Pa,void 0,k.pa,h,k.s);bh(m,a)}}).h(function(m){m.code=="auth/network-request-failed"&&(k.cb=null);throw m;})};
var al=function(a){a.i||(a.ah=a.Pa?Bh("JsCore",a.Pa,Wk(a.B)):null,a.i=new Ej(a.A,Yg(a.pa),a.ah),a.s&&Ij(a.i,a.s));return a.i};Xk.prototype.md=function(a,b,c,d){this.cb||(this.cb=Yk(al(this)));var e=this;return this.cb.then(function(){vj(b);var f=bl(e.J,e.A,e.B,a,b,ah(),c,e.Pa,void 0,e.pa,d,e.s);bh(f)}).h(function(f){f.code=="auth/network-request-failed"&&(e.cb=null);throw f;})};
Xk.prototype.Lb=function(){var a=this;return this.initialize().then(function(){return a.ge.Qf}).h(function(){a.cb=null;throw new P("network-request-failed");})};Xk.prototype.li=function(){return!0};
var bl=function(a,b,c,d,e,f,g,h,k,m,n,r){a=new Vk(a,b,c,d,e,r);a.zc=f;a.T=g;f=a.lg(h);f.Ed=fd(k||null);return f.ig(m).kg(n).toString()},Zk=function(a){if(!a.ge)throw Error("IfcHandler must be initialized!");Rk(a.ge,function(b){var c={};if(b&&b.authEvent){var d=!1;b=ni(b.authEvent);for(c=0;c<a.Xa.length;c++)d=a.Xa[c](b)||d;c={};c.status=d?"ACK":"ERROR";return J(c)}c.status="ERROR";return J(c)})},$k=function(a){var b={type:"webStorageSupport"};return a.initialize().then(function(){return a.ge.sendMessage(b)}).then(function(c){if(c&&
c.length&&typeof c[0].webStorageSupport!=="undefined")return c[0].webStorageSupport;throw Error();})};Xk.prototype.Zb=function(a){this.Xa.push(a)};Xk.prototype.rd=function(a){lb(this.Xa,function(b){return b==a})};function cl(){}cl.prototype.render=function(){};cl.prototype.reset=function(){};cl.prototype.getResponse=function(){};cl.prototype.execute=function(){};var dl=ra(["https://www.google.com/recaptcha/api.js?trustedtypes=true&onload=","&render=explicit&hl=",""]),el=function(){this.ec=u.grecaptcha?Infinity:0;this.mc=null;this.gf="__rcb"+Math.floor(Math.random()*1E6).toString()};
el.prototype.uh=function(a){var b=this;return new I(function(c,d){var e=setTimeout(function(){d(new P("network-request-failed"))},fl.get());if(!u.grecaptcha||a!==b.mc&&!b.ec){u[b.gf]=function(){if(u.grecaptcha){b.mc=a;var g=u.grecaptcha.render;u.grecaptcha.render=function(h,k){h=g(h,k);b.ec++;return h};clearTimeout(e);c(u.grecaptcha)}else clearTimeout(e),d(new P("internal-error"));delete u[b.gf]};var f=bd(dl,b.gf,a||"");J(Hg(f)).h(function(){clearTimeout(e);d(new P("internal-error","Unable to load external reCAPTCHA dependencies!"))})}else clearTimeout(e),
c(u.grecaptcha)})};el.prototype.Eg=function(){this.ec--};var fl=new Nh(3E4,6E4),gl=null;var hl=function(){this.Lf={};this.ec=1E12};hl.prototype.render=function(a,b){this.Lf[this.ec.toString()]=new il(a,b);return this.ec++};hl.prototype.reset=function(a){var b=jl(this,a);a=kl(a);b&&a&&(b.delete(),delete this.Lf[a])};hl.prototype.getResponse=function(a){return(a=jl(this,a))?a.getResponse():null};hl.prototype.execute=function(a){(a=jl(this,a))&&a.execute()};
var jl=function(a,b){return(b=kl(b))?a.Lf[b]||null:null},kl=function(a){return(a=typeof a==="undefined"?1E12:a)?a.toString():null},ll=null,il=function(a,b){this.Aa=!1;this.V=b;this.Fc=this.Ce=null;this.ph=this.V.size!=="invisible";this.S=ge(a);var c=this;this.Bh=function(){c.execute()};this.ph?this.execute():df(this.S,"click",this.Bh)};il.prototype.getResponse=function(){ml(this);return this.Ce};
il.prototype.execute=function(){ml(this);var a=this;this.Fc||(this.Fc=setTimeout(function(){a.Ce=zh();var b=a.V.callback,c=a.V["expired-callback"];if(b)try{b(a.Ce)}catch(d){}a.Fc=setTimeout(function(){a.Fc=null;a.Ce=null;if(c)try{c()}catch(d){}a.ph&&a.execute()},6E4)},500))};il.prototype.delete=function(){ml(this);this.Aa=!0;clearTimeout(this.Fc);this.Fc=null;mf(this.S,"click",this.Bh)};var ml=function(a){if(a.Aa)throw Error("reCAPTCHA mock was already deleted!");};var nl=function(){};nl.prototype.uh=function(){ll||(ll=new hl);return J(ll)};nl.prototype.Eg=function(){};var ol=null;var pl=function(a,b,c,d,e,f,g){O(this,"type","recaptcha");this.Jc=this.Lc=null;this.Qc=!1;this.Mc=b;this.Yc=null;g?(ol||(ol=new nl),g=ol):(gl||(gl=new el),g=gl);this.Qh=g;this.Ra=c||{theme:"light",type:"image"};this.Z=[];if(this.Ra.sitekey)throw new P("argument-error","sitekey should not be provided for reCAPTCHA as one is automatically provisioned for the current project.");this.ke=this.Ra.size==="invisible";if(!u.document)throw new P("operation-not-supported-in-this-environment","RecaptchaVerifier is only supported in a browser HTTP/HTTPS environment with DOM support.");
if(!ge(b)||!this.ke&&ge(b).hasChildNodes())throw new P("argument-error","reCAPTCHA container is either not found or already contains inner elements!");this.i=new Ej(a,f||null,e||null);this.Zi=d||function(){return null};var h=this;this.Pe=[];var k=this.Ra.callback;this.Ra.callback=function(n){h.Rc(n);if(typeof k==="function")k(n);else if(typeof k==="string"){var r=N(k,u);typeof r==="function"&&r(n)}};var m=this.Ra["expired-callback"];this.Ra["expired-callback"]=function(){h.Rc(null);if(typeof m===
"function")m();else if(typeof m==="string"){var n=N(m,u);typeof n==="function"&&n()}}};pl.prototype.Rc=function(a){for(var b=0;b<this.Pe.length;b++)try{this.Pe[b](a)}catch(c){}};var ql=function(a,b){lb(a.Pe,function(c){return c==b})};l=pl.prototype;l.j=function(a){var b=this;this.Z.push(a);a.yb(function(){ib(b.Z,a)});return a};
l.cd=function(){var a=this;return this.Lc?this.Lc:this.Lc=this.j(J().then(function(){if(Eh()&&!uh())return oh();throw new P("operation-not-supported-in-this-environment","RecaptchaVerifier is only supported in a browser HTTP/HTTPS environment.");}).then(function(){return a.Qh.uh(a.Zi())}).then(function(b){a.Yc=b;return Q(a.i,Ik,{})}).then(function(b){a.Ra.sitekey=b.recaptchaSiteKey}).h(function(b){a.Lc=null;throw b;}))};
l.render=function(){rl(this);var a=this;return this.j(this.cd().then(function(){if(a.Jc===null){var b=a.Mc;if(!a.ke){var c=ge(b);b=le(document,"DIV");c.appendChild(b)}a.Jc=a.Yc.render(b,a.Ra)}return a.Jc}))};l.verify=function(){rl(this);var a=this;return this.j(this.render().then(function(b){return new I(function(c){var d=a.Yc.getResponse(b);if(d)c(d);else{var e=function(f){f&&(ql(a,e),c(f))};a.Pe.push(e);a.ke&&a.Yc.execute(a.Jc)}})}))};l.reset=function(){rl(this);this.Jc!==null&&this.Yc.reset(this.Jc)};
var rl=function(a){if(a.Qc)throw new P("internal-error","RecaptchaVerifier instance has been destroyed.");};pl.prototype.clear=function(){rl(this);this.Qc=!0;this.Qh.Eg();for(var a=0;a<this.Z.length;a++)this.Z[a].cancel("RecaptchaVerifier instance has been destroyed.");this.ke||oe(ge(this.Mc))};
var sl=function(a,b,c){var d=!1;try{this.u=c||firebase.app()}catch(g){throw new P("argument-error","No firebase.app.App instance is currently initialized.");}if(this.u.options&&this.u.options.apiKey)c=this.u.options.apiKey;else throw new P("invalid-api-key");var e=this,f=null;try{f=mb(this.u.auth().U)}catch(g){}try{d=this.u.auth().settings.appVerificationDisabledForTesting}catch(g){}f=firebase.SDK_VERSION?Bh("JsCore",firebase.SDK_VERSION,f):null;pl.call(this,c,a,b,function(){try{var g=e.u.auth().Fa}catch(h){g=
null}return g},f,Yg(Zg),d)};x(sl,pl);var tl=function(a,b){this.Bk=a;this.pk=b||"*"};tl.prototype.postMessage=function(a,b){this.Bk.postMessage(a,this.pk,b)};var ul=function(a){this.Dd=a};ul.prototype.postMessage=function(a,b){this.Dd.postMessage(a,b)};var vl=function(a){this.Nj=a;this.Fg=!1;this.pe=[]},wl=function(a,b,c,d){var e=Date.now();return a.send(b,c).h(function(f){if(f&&f.message==="connection_unavailable")throw f;var g=Date.now()-e;if(g>d)throw f;return wl(a,b,c,d-g)})};
vl.prototype.send=function(a,b,c){b=b===void 0?null:b;c=c===void 0?!1:c;var d=this,e;b=b||{};var f,g,h,k=null;if(this.Fg)return K(Error("connection_unavailable"));var m=c?800:50,n=typeof MessageChannel!=="undefined"?new MessageChannel:null;return(new I(function(r,t){n?(e=""+Math.floor(Math.random()*1E20).toString(),n.port1.start(),g=setTimeout(function(){t(Error("unsupported_event"))},m),f=function(y){y.data.eventId===e&&(y.data.status==="ack"?(clearTimeout(g),h=setTimeout(function(){t(Error("timeout"))},
3E3)):y.data.status==="done"?(clearTimeout(h),typeof y.data.response!=="undefined"?r(y.data.response):t(Error("unknown_error"))):(clearTimeout(g),clearTimeout(h),t(Error("invalid_response"))))},k={messageChannel:n,onMessage:f},d.pe.push(k),n.port1.addEventListener("message",f),d.Nj.postMessage({eventType:a,eventId:e,data:b},[n.port2])):t(Error("connection_unavailable"))})).then(function(r){xl(d,k);return r}).h(function(r){xl(d,k);throw r;})};
var xl=function(a,b){if(b){var c=b.messageChannel,d=b.onMessage;c&&(c.port1.removeEventListener("message",d),c.port1.close());lb(a.pe,function(e){return e==b})}};vl.prototype.close=function(){for(;this.pe.length>0;)xl(this,this.pe[0]);this.Fg=!0};var yl=function(a){this.sf=a;this.Ca={};this.wh=w(this.cj,this)},Al=function(){var a=uh()?self:null;C(zl,function(c){c.sf==a&&(b=c)});if(!b){var b=new yl(a);zl.push(b)}return b};
yl.prototype.cj=function(a){var b=a.data.eventType,c=a.data.eventId,d=this.Ca[b];if(d&&d.length>0){a.ports[0].postMessage({status:"ack",eventId:c,eventType:b,response:null});var e=[];C(d,function(f){e.push(J().then(function(){return f(a.origin,a.data.data)}))});cg(e).then(function(f){var g=[];C(f,function(h){g.push({fulfilled:h.Zg,value:h.value,reason:h.reason?h.reason.message:void 0})});C(g,function(h){for(var k in h)typeof h[k]==="undefined"&&delete h[k]});a.ports[0].postMessage({status:"done",
eventId:c,eventType:b,response:g})})}};yl.prototype.subscribe=function(a,b){ed(this.Ca)&&this.sf.addEventListener("message",this.wh);typeof this.Ca[a]==="undefined"&&(this.Ca[a]=[]);this.Ca[a].push(b)};yl.prototype.unsubscribe=function(a,b){typeof this.Ca[a]!=="undefined"&&b?(lb(this.Ca[a],function(c){return c==b}),this.Ca[a].length==0&&delete this.Ca[a]):b||delete this.Ca[a];ed(this.Ca)&&this.sf.removeEventListener("message",this.wh)};var zl=[];var Bl=function(a){this.za=a||firebase.INTERNAL.reactNative&&firebase.INTERNAL.reactNative.AsyncStorage;if(!this.za)throw new P("internal-error","The React Native compatibility library was not found.");this.type="asyncStorage"};l=Bl.prototype;l.get=function(a){return J(this.za.getItem(a)).then(function(b){return b&&Kh(b)})};l.set=function(a,b){return J(this.za.setItem(a,Hh(b)))};l.remove=function(a){return J(this.za.removeItem(a))};l.kb=function(){};l.wb=function(){};function Cl(){this.storage={};this.type="inMemory"}l=Cl.prototype;l.get=function(a){return J(this.storage[a])};l.set=function(a,b){this.storage[a]=b;return J()};l.remove=function(a){delete this.storage[a];return J()};l.kb=function(){};l.wb=function(){};var Fl=function(){if(!Dl()){if(vh()=="Node")throw new P("internal-error","The LocalStorage compatibility library was not found.");throw new P("web-storage-unsupported");}this.za=El()||firebase.INTERNAL.node.localStorage;this.type="localStorage"},El=function(){try{var a=u.localStorage,b=Ch();a&&(a.setItem(b,"1"),a.removeItem(b));return a}catch(c){return null}},Dl=function(){var a=vh()=="Node";a=El()||a&&firebase.INTERNAL.node&&firebase.INTERNAL.node.localStorage;if(!a)return!1;try{return a.setItem("__sak",
"1"),a.removeItem("__sak"),!0}catch(b){return!1}};l=Fl.prototype;l.get=function(a){var b=this;return J().then(function(){var c=b.za.getItem(a);return Kh(c)})};l.set=function(a,b){var c=this;return J().then(function(){var d=Hh(b);d===null?c.remove(a):c.za.setItem(a,d)})};l.remove=function(a){var b=this;return J().then(function(){b.za.removeItem(a)})};l.kb=function(a){u.window&&df(u.window,"storage",a)};l.wb=function(a){u.window&&mf(u.window,"storage",a)};var Gl=function(){this.za={};this.type="nullStorage"};l=Gl.prototype;l.get=function(){return J(null)};l.set=function(){return J()};l.remove=function(){return J()};l.kb=function(){};l.wb=function(){};var Jl=function(){if(!Hl()){if(vh()=="Node")throw new P("internal-error","The SessionStorage compatibility library was not found.");throw new P("web-storage-unsupported");}this.za=Il()||firebase.INTERNAL.node.sessionStorage;this.type="sessionStorage"},Il=function(){try{var a=u.sessionStorage,b=Ch();a&&(a.setItem(b,"1"),a.removeItem(b));return a}catch(c){return null}},Hl=function(){var a=vh()=="Node";a=Il()||a&&firebase.INTERNAL.node&&firebase.INTERNAL.node.sessionStorage;if(!a)return!1;try{return a.setItem("__sak",
"1"),a.removeItem("__sak"),!0}catch(b){return!1}};l=Jl.prototype;l.get=function(a){var b=this;return J().then(function(){var c=b.za.getItem(a);return Kh(c)})};l.set=function(a,b){var c=this;return J().then(function(){var d=Hh(b);d===null?c.remove(a):c.za.setItem(a,d)})};l.remove=function(a){var b=this;return J().then(function(){b.za.removeItem(a)})};l.kb=function(){};l.wb=function(){};var Ml=function(){if(!Kl())throw new P("web-storage-unsupported");this.Pg="firebaseLocalStorageDb";this.re="firebaseLocalStorage";this.lf="fbase_key";this.wi="value";this.zk=1;this.ka={};this.Va=[];this.hd=0;this.jh=u.indexedDB;this.type="indexedDB";this.Ie=this.ag=this.ye=this.Uf=null;this.Wh=!1;this.Ve=null;var a=this;uh()&&self?(this.ag=Al(),this.ag.subscribe("keyChanged",function(b,c){return Ll(a).then(function(d){d.length>0&&C(a.Va,function(e){e(d)});return{keyProcessed:hb(d,c.key)}})}),this.ag.subscribe("ping",
function(){return J(["keyChanged"])})):Vh().then(function(b){if(a.Ve=b)a.Ie=new vl(new ul(b)),a.Ie.send("ping",null,!0).then(function(c){c[0].fulfilled&&hb(c[0].value,"keyChanged")&&(a.Wh=!0)}).h(function(){})})},Nl,Ol=function(a){return new I(function(b,c){var d=a.jh.deleteDatabase(a.Pg);d.onsuccess=function(){b()};d.onerror=function(e){c(Error(e.target.error))}})},Pl=function(a){return new I(function(b,c){var d=a.jh.open(a.Pg,a.zk);d.onerror=function(e){try{e.preventDefault()}catch(f){}c(Error(e.target.error))};
d.onupgradeneeded=function(e){e=e.target.result;try{e.createObjectStore(a.re,{keyPath:a.lf})}catch(f){c(f)}};d.onsuccess=function(e){e=e.target.result;e.objectStoreNames.contains(a.re)?b(e):Ol(a).then(function(){return Pl(a)}).then(function(f){b(f)}).h(function(f){c(f)})}})},Ql=function(a){a.Ff||(a.Ff=Pl(a));return a.Ff},Rl=function(a,b){var c=0,d=function(e,f){Ql(a).then(b).then(e).h(function(g){if(++c>3)f(g);else return Ql(a).then(function(h){h.close();a.Ff=void 0;return d(e,f)}).h(function(h){f(h)})})};
return new I(d)},Kl=function(){try{return!!u.indexedDB}catch(a){return!1}},Sl=function(a,b){return b.objectStore(a.re)},Tl=function(a,b,c){return b.transaction([a.re],c?"readwrite":"readonly")},Ul=function(a){return new I(function(b,c){a.onsuccess=function(d){d&&d.target?b(d.target.result):b()};a.onerror=function(d){c(d.target.error)}})};
Ml.prototype.set=function(a,b){var c=this,d=!1;return Rl(this,function(e){e=Sl(c,Tl(c,e,!0));return Ul(e.get(a))}).then(function(e){return Rl(c,function(f){f=Sl(c,Tl(c,f,!0));if(e)return e.value=b,Ul(f.put(e));c.hd++;d=!0;var g={};g[c.lf]=a;g[c.wi]=b;return Ul(f.add(g))})}).then(function(){c.ka[a]=b;return Vl(c,a)}).yb(function(){d&&c.hd--})};var Vl=function(a,b){return a.Ie&&a.Ve&&Uh()===a.Ve?a.Ie.send("keyChanged",{key:b},a.Wh).then(function(){}).h(function(){}):J()};
Ml.prototype.get=function(a){var b=this;return Rl(this,function(c){return Ul(Sl(b,Tl(b,c,!1)).get(a))}).then(function(c){return c&&c.value})};Ml.prototype.remove=function(a){var b=!1,c=this;return Rl(this,function(d){b=!0;c.hd++;return Ul(Sl(c,Tl(c,d,!0))["delete"](a))}).then(function(){delete c.ka[a];return Vl(c,a)}).yb(function(){b&&c.hd--})};
var Ll=function(a){return Ql(a).then(function(b){var c=Sl(a,Tl(a,b,!1));return c.getAll?Ul(c.getAll()):new I(function(d,e){var f=[],g=c.openCursor();g.onsuccess=function(h){(h=h.target.result)?(f.push(h.value),h["continue"]()):d(f)};g.onerror=function(h){e(h.target.error)}})}).then(function(b){var c={},d=[];if(a.hd==0){for(d=0;d<b.length;d++)c[b[d][a.lf]]=b[d][a.wi];d=dh(a.ka,c);a.ka=c}return d})};Ml.prototype.kb=function(a){this.Va.length==0&&this.ng();this.Va.push(a)};
Ml.prototype.wb=function(a){lb(this.Va,function(b){return b==a});this.Va.length==0&&this.Le()};Ml.prototype.ng=function(){var a=this;this.Le();var b=function(){a.ye=setTimeout(function(){a.Uf=Ll(a).then(function(c){c.length>0&&C(a.Va,function(d){d(c)})}).then(function(){b()}).h(function(c){c.message!="STOP_EVENT"&&b()})},800)};b()};Ml.prototype.Le=function(){this.Uf&&this.Uf.cancel("STOP_EVENT");this.ye&&(clearTimeout(this.ye),this.ye=null)};function Wl(a){var b=this,c=null;this.Va=[];this.type="indexedDB";this.Tg=a;this.rg=J().then(function(){if(Kl()){var d=Ch(),e="__sak"+d;Nl||(Nl=new Ml);c=Nl;return c.set(e,d).then(function(){return c.get(e)}).then(function(f){if(f!==d)throw Error("indexedDB not supported!");return c.remove(e)}).then(function(){return c}).h(function(){return b.Tg})}return b.Tg}).then(function(d){b.type=d.type;d.kb(function(e){C(b.Va,function(f){f(e)})});return d})}l=Wl.prototype;l.get=function(a){return this.rg.then(function(b){return b.get(a)})};
l.set=function(a,b){return this.rg.then(function(c){return c.set(a,b)})};l.remove=function(a){return this.rg.then(function(b){return b.remove(a)})};l.kb=function(a){this.Va.push(a)};l.wb=function(a){lb(this.Va,function(b){return b==a})};var am=function(){this.qf={Browser:Xl,Node:Yl,ReactNative:Zl,Worker:$l}[vh()]},bm,Xl={N:Fl,Me:Jl},Yl={N:Fl,Me:Jl},Zl={N:Bl,Me:Gl},$l={N:Fl,Me:Gl};var cm=function(){this.Xe=!1;Object.defineProperty(this,"appVerificationDisabled",{get:function(){return this.Xe},set:function(a){this.Xe=a},enumerable:!1})};var dm=function(a){this.bb(a)};
dm.prototype.bb=function(a){var b=a.url;if(typeof b==="undefined")throw new P("missing-continue-uri");if(typeof b!=="string"||typeof b==="string"&&!b.length)throw new P("invalid-continue-uri");this.Li=b;this.ug=this.ac=null;this.lh=!1;var c=a.android;if(c&&typeof c==="object"){b=c.packageName;var d=c.installApp;c=c.minimumVersion;if(typeof b==="string"&&b.length){this.ac=b;if(typeof d!=="undefined"&&typeof d!=="boolean")throw new P("argument-error","installApp property must be a boolean when specified.");this.lh=
!!d;if(typeof c!=="undefined"&&(typeof c!=="string"||typeof c==="string"&&!c.length))throw new P("argument-error","minimumVersion property must be a non empty string when specified.");this.ug=c||null}else{if(typeof b!=="undefined")throw new P("argument-error","packageName property must be a non empty string when specified.");if(typeof d!=="undefined"||typeof c!=="undefined")throw new P("missing-android-pkg-name");}}else if(typeof c!=="undefined")throw new P("argument-error","android property must be a non null object when specified.");
this.ad=null;if((b=a.iOS)&&typeof b==="object")if(b=b.bundleId,typeof b==="string"&&b.length)this.ad=b;else{if(typeof b!=="undefined")throw new P("argument-error","bundleId property must be a non empty string when specified.");}else if(typeof b!=="undefined")throw new P("argument-error","iOS property must be a non null object when specified.");b=a.handleCodeInApp;if(typeof b!=="undefined"&&typeof b!=="boolean")throw new P("argument-error","handleCodeInApp property must be a boolean when specified.");
this.Dg=!!b;a=a.dynamicLinkDomain;if(typeof a!=="undefined"&&(typeof a!=="string"||typeof a==="string"&&!a.length))throw new P("argument-error","dynamicLinkDomain property must be a non empty string when specified.");this.Pi=a||null};var em=function(a){var b={};b.continueUrl=a.Li;b.canHandleCodeInApp=a.Dg;if(b.androidPackageName=a.ac)b.androidMinimumVersion=a.ug,b.androidInstallApp=a.lh;b.iOSBundleId=a.ad;b.dynamicLinkDomain=a.Pi;for(var c in b)b[c]===null&&delete b[c];return b};var fm=function(a,b){this.Oi=b;O(this,"verificationId",a)};fm.prototype.confirm=function(a){a=tj(this.verificationId,a);return this.Oi(a)};var gm=function(a,b,c,d){return(new pj(a)).verifyPhoneNumber(b,c).then(function(e){return new fm(e,d)})};var hm=function(a,b,c){this.Lj=a;this.Yj=b;this.aj=c;this.oe=3E4;this.tg=96E4;this.Zj=!1;this.sc=null;this.Nb=this.oe;if(this.tg<this.oe)throw Error("Proactive refresh lower bound greater than upper bound!");};hm.prototype.start=function(){this.Nb=this.oe;im(this,!0)};
var jm=function(a,b){if(b)return a.Nb=a.oe,a.aj();b=a.Nb;a.Nb*=2;a.Nb>a.tg&&(a.Nb=a.tg);return b},im=function(a,b){a.stop();a.sc=Tg(jm(a,b)).then(function(){return a.Zj?J():Ph()}).then(function(){return a.Lj()}).then(function(){im(a,!0)}).h(function(c){a.Yj(c)&&im(a,!1)})};hm.prototype.stop=function(){this.sc&&(this.sc.cancel(),this.sc=null)};var qm=function(a){var b={};b["facebook.com"]=km;b["google.com"]=lm;b["github.com"]=mm;b["twitter.com"]=nm;var c=a&&a.providerId;try{if(c)return b[c]?new b[c](a):new om(a);if(typeof a.idToken!=="undefined")return new pm(a)}catch(d){}return null},pm=function(a){var b=a.providerId;if(!b&&a.idToken){var c=Fi(a.idToken);c&&c.wc&&(b=c.wc)}if(!b)throw Error("Invalid additional user info!");if(b=="anonymous"||b=="custom")b=null;c=!1;typeof a.isNewUser!=="undefined"?c=!!a.isNewUser:a.kind==="identitytoolkit#SignupNewUserResponse"&&
(c=!0);O(this,"providerId",b);O(this,"isNewUser",c)},om=function(a){pm.call(this,a);a=Kh(a.rawUserInfo||"{}");O(this,"profile",di(a||{}))};q(om,pm);var km=function(a){om.call(this,a);if(this.providerId!="facebook.com")throw Error("Invalid provider ID!");};q(km,om);var mm=function(a){om.call(this,a);if(this.providerId!="github.com")throw Error("Invalid provider ID!");O(this,"username",this.profile&&this.profile.login||null)};q(mm,om);
var lm=function(a){om.call(this,a);if(this.providerId!="google.com")throw Error("Invalid provider ID!");};q(lm,om);var nm=function(a){om.call(this,a);if(this.providerId!="twitter.com")throw Error("Invalid provider ID!");O(this,"username",a.screenName||null)};q(nm,om);var rm={LOCAL:"local",NONE:"none",SESSION:"session"};function sm(a){var b=new P("invalid-persistence-type"),c=new P("unsupported-persistence-type");a:{for(d in rm)if(rm[d]==a){var d=!0;break a}d=!1}if(!d||typeof a!=="string")throw b;switch(vh()){case "ReactNative":if(a==="session")throw c;break;case "Node":if(a!=="none")throw c;break;case "Worker":if(a==="session"||!Kl()&&a!=="none")throw c;break;default:if(!Dh()&&a!=="none")throw c;}}
var tm=function(){var a=!Lh(M())&&sh()?!0:!1,b=Gh(),c=Dh();this.zh="firebase";this.fg=":";this.ak=a;this.Sh=b;this.xi=c;this.ra={};bm||(bm=new am);a=bm;try{this.Ih=!$g()&&Sh()||!u.indexedDB?new a.qf.N:new Wl(uh()?new Cl:new a.qf.N)}catch(d){this.Ih=new Cl,this.Sh=!0}try{this.ji=new a.qf.Me}catch(d){this.ji=new Cl}this.oj=new Cl;this.og=w(this.ei,this);this.ka={}},um,vm=function(){um||(um=new tm);return um},wm=function(a,b){switch(b){case "session":return a.ji;case "none":return a.oj;default:return a.Ih}};
tm.prototype.wa=function(a,b){return this.zh+this.fg+a.name+(b?this.fg+b:"")};var xm=function(a,b,c){var d=a.wa(b,c),e=wm(a,b.N);return a.get(b,c).then(function(f){var g=null;try{g=Kh(u.localStorage.getItem(d))}catch(h){}if(g&&!f)return u.localStorage.removeItem(d),a.set(b,g,c);g&&f&&e.type!="localStorage"&&u.localStorage.removeItem(d)})};l=tm.prototype;l.get=function(a,b){return wm(this,a.N).get(this.wa(a,b))};l.remove=function(a,b){b=this.wa(a,b);a.N=="local"&&(this.ka[b]=null);return wm(this,a.N).remove(b)};
l.set=function(a,b,c){var d=this.wa(a,c),e=this,f=wm(this,a.N);return f.set(d,b).then(function(){return f.get(d)}).then(function(g){a.N=="local"&&(e.ka[d]=g)})};l.addListener=function(a,b,c){a=this.wa(a,b);this.xi&&(this.ka[a]=u.localStorage.getItem(a));ed(this.ra)&&this.ng();this.ra[a]||(this.ra[a]=[]);this.ra[a].push(c)};l.removeListener=function(a,b,c){a=this.wa(a,b);this.ra[a]&&(lb(this.ra[a],function(d){return d==c}),this.ra[a].length==0&&delete this.ra[a]);ed(this.ra)&&this.Le()};
l.ng=function(){wm(this,"local").kb(this.og);this.Sh||($g()||!Sh())&&u.indexedDB||!this.xi||ym(this)};var ym=function(a){zm(a);a.Kf=setInterval(function(){for(var b in a.ra){var c=u.localStorage.getItem(b),d=a.ka[b];c!=d&&(a.ka[b]=c,c=new Se({type:"storage",key:b,target:window,oldValue:d,newValue:c,Tf:!0}),a.ei(c))}},1E3)},zm=function(a){a.Kf&&(clearInterval(a.Kf),a.Kf=null)};tm.prototype.Le=function(){wm(this,"local").wb(this.og);zm(this)};
tm.prototype.ei=function(a){if(a&&a.Xi){var b=a.qa.key;if(b==null)for(var c in this.ra){var d=this.ka[c];typeof d==="undefined"&&(d=null);var e=u.localStorage.getItem(c);e!==d&&(this.ka[c]=e,this.ef(c))}else if(b.indexOf(this.zh+this.fg)==0&&this.ra[b]){typeof a.qa.Tf!=="undefined"?wm(this,"local").wb(this.og):zm(this);if(this.ak)if(c=u.localStorage.getItem(b),d=a.qa.newValue,d!==c)d!==null?u.localStorage.setItem(b,d):u.localStorage.removeItem(b);else if(this.ka[b]===d&&typeof a.qa.Tf==="undefined")return;
var f=this;c=function(){if(typeof a.qa.Tf!=="undefined"||f.ka[b]!==u.localStorage.getItem(b))f.ka[b]=u.localStorage.getItem(b),f.ef(b)};ob&&Ab&&Ab==10&&u.localStorage.getItem(b)!==a.qa.newValue&&a.qa.newValue!==a.qa.oldValue?setTimeout(c,10):c()}}else C(a,w(this.ef,this))};tm.prototype.ef=function(a){this.ra[a]&&C(this.ra[a],function(b){b()})};var Am=function(a){this.D=a;this.o=vm()},Cm=function(a){return a.o.get(Bm,a.D).then(function(b){return ni(b)})};Am.prototype.Zb=function(a){this.o.addListener(Bm,this.D,a)};Am.prototype.rd=function(a){this.o.removeListener(Bm,this.D,a)};var Bm={name:"authEvent",N:"local"},Dm={name:"redirectEvent",N:"session"};var Em=function(){this.o=vm()};Em.prototype.jc=function(a){return this.o.get(Fm,a)};var Hm=function(a){return a.o.get(Gm).then(function(b){b=b||{};return b.type&&b.apiKey?new oi(b.apiKey,b.appName||"",b.type,b.eventId,b.redirectUrl,b.clientVersion,b.displayName,b.apn,b.ibi,b.eid,b.fw,b.clientId,b.sha1Cert,b.tenantId,b.providerId,b.appId,b.publicKey):null})},Im=function(a,b,c){return a.o.set(Bm,c.m(),b)},Gm={name:"oauthHelperState",N:"session"},Fm={name:"sessionId",N:"session"};var Jm=function(){this.Mf=null;this.Pd=[]};Jm.prototype.subscribe=function(a){var b=this;this.Pd.push(a);this.Mf||(this.Mf=function(c){for(var d=0;d<b.Pd.length;d++)b.Pd[d](c)},a=N("universalLinks.subscribe",u),typeof a==="function"&&a(null,this.Mf))};Jm.prototype.unsubscribe=function(a){lb(this.Pd,function(b){return b==a})};var Km=null;var Lm=function(a,b,c,d,e,f){this.J=a;this.A=b;this.B=c;this.s=f;this.Pa=d||null;this.pa=e||null;this.gi=b+":"+c;this.bk=new Em;this.bh=new Am(this.gi);this.Gf=null;this.Xa=[];this.rj=500;this.Qj=2E3;this.bd=this.we=null},Mm=function(a){return new P("invalid-cordova-configuration",a)};
Lm.prototype.Lb=function(){return this.cd?this.cd:this.cd=qh().then(function(){if(typeof N("universalLinks.subscribe",u)!=="function")throw Mm("cordova-universal-links-plugin-fix is not installed");if(typeof N("BuildInfo.packageName",u)==="undefined")throw Mm("cordova-plugin-buildinfo is not installed");if(typeof N("cordova.plugins.browsertab.openUrl",u)!=="function")throw Mm("cordova-plugin-browsertab is not installed");if(typeof N("cordova.InAppBrowser.open",u)!=="function")throw Mm("cordova-plugin-inappbrowser is not installed");
},function(){throw new P("cordova-not-ready");})};var Nm=function(){for(var a=20,b=[];a>0;)b.push("1234567890abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ".charAt(Math.floor(Math.random()*62))),a--;return b.join("")},Om=function(a){var b=new Oe;b.update(a);return La(b.digest())};l=Lm.prototype;l.wd=function(a,b){b(new P("operation-not-supported-in-this-environment"));return J()};l.ld=function(){return K(new P("operation-not-supported-in-this-environment"))};l.li=function(){return!1};l.di=function(){return!0};
l.fh=function(){return!0};
l.md=function(a,b,c,d){if(this.we)return K(new P("redirect-operation-pending"));var e=this,f=u.document,g=null,h=null,k=null,m=null;return this.we=J().then(function(){vj(b);return Pm(e)}).then(function(){return Qm(e,a,b,c,d)}).then(function(){return(new I(function(n,r){h=function(){var t=N("cordova.plugins.browsertab.close",u);n();typeof t==="function"&&t();e.bd&&typeof e.bd.close==="function"&&(e.bd.close(),e.bd=null);return!1};e.Zb(h);k=function(){g||(g=Tg(e.Qj).then(function(){r(new P("redirect-cancelled-by-user"))}))};m=
function(){Oh()&&k()};f.addEventListener("resume",k,!1);M().toLowerCase().match(/android/)||f.addEventListener("visibilitychange",m,!1)})).h(function(n){return Rm(e).then(function(){throw n;})})}).yb(function(){k&&f.removeEventListener("resume",k,!1);m&&f.removeEventListener("visibilitychange",m,!1);g&&g.cancel();h&&e.rd(h);e.we=null})};
var Qm=function(a,b,c,d,e){var f=Nm(),g=new mi(b,d,null,f,new P("no-auth-event"),null,e),h=N("BuildInfo.packageName",u);if(typeof h!=="string")throw new P("invalid-cordova-configuration");var k=N("BuildInfo.displayName",u),m={};if(M().toLowerCase().match(/iphone|ipad|ipod/))m.ibi=h;else if(M().toLowerCase().match(/android/))m.apn=h;else return K(new P("operation-not-supported-in-this-environment"));k&&(m.appDisplayName=k);f=Om(f);m.sessionId=f;var n=bl(a.J,a.A,a.B,b,c,null,d,a.Pa,m,a.pa,e,a.s);return a.Lb().then(function(){return Im(a.bk,
a.gi,g)}).then(function(){var r=N("cordova.plugins.browsertab.isAvailable",u);if(typeof r!=="function")throw new P("invalid-cordova-configuration");var t=null;r(function(y){if(y){t=N("cordova.plugins.browsertab.openUrl",u);if(typeof t!=="function")throw new P("invalid-cordova-configuration");t(n)}else{t=N("cordova.InAppBrowser.open",u);if(typeof t!=="function")throw new P("invalid-cordova-configuration");y=t;var ba=M();ba=!(!ba.match(/(iPad|iPhone|iPod).*OS 7_\d/i)&&!ba.match(/(iPad|iPhone|iPod).*OS 8_\d/i));
a.bd=y(n,ba?"_blank":"_system","location=yes")}})})};Lm.prototype.Rc=function(a){for(var b=0;b<this.Xa.length;b++)try{this.Xa[b](a)}catch(c){}};
var Pm=function(a){a.Gf||(a.Gf=a.Lb().then(function(){return new I(function(b){var c=function(d){b(d);a.rd(c);return!1};a.Zb(c);Sm(a)})}));return a.Gf},Rm=function(a){var b=null;return Cm(a.bh).then(function(c){b=c;c=a.bh;return c.o.remove(Bm,c.D)}).then(function(){return b})},Sm=function(a){var b=new mi("unknown",null,null,null,new P("no-auth-event")),c=!1,d=Tg(a.rj).then(function(){return Rm(a).then(function(){c||a.Rc(b)})}),e=function(g){c=!0;d&&d.cancel();Rm(a).then(function(h){var k=b;if(h&&
g&&g.url){var m=null;k=Ai(g.url);k.indexOf("/__/auth/callback")!=-1&&(m=F(k),m=Kh(E(m,"firebaseError")||null),m=(m=typeof m==="object"?li(m):null)?new mi(h.getType(),h.T,null,null,m,null,h.C):new mi(h.getType(),h.T,k,h.jc(),null,null,h.C));k=m||b}a.Rc(k)})},f=u.handleOpenURL;u.handleOpenURL=function(g){g.toLowerCase().indexOf(N("BuildInfo.packageName",u).toLowerCase()+"://")==0&&e({url:g});if(typeof f==="function")try{f(g)}catch(h){console.error(h)}};Km||(Km=new Jm);Km.subscribe(e)};
Lm.prototype.Zb=function(a){this.Xa.push(a);Pm(this).h(function(b){b.code==="auth/invalid-cordova-configuration"&&(b=new mi("unknown",null,null,null,new P("no-auth-event")),a(b))})};Lm.prototype.rd=function(a){lb(this.Xa,function(b){return b==a})};var Tm=function(a){this.D=a;this.o=vm()},Vm=function(a){return a.o.set(Um,"pending",a.D)},Wm=function(a){return a.o.remove(Um,a.D)},Xm=function(a){return a.o.get(Um,a.D).then(function(b){return b=="pending"})},Um={name:"pendingRedirect",N:"session"};var bn=function(a,b,c,d){this.Ae={};this.Jf=0;this.J=a;this.A=b;this.B=c;this.s=d;this.yd=[];this.oc=!1;this.af=w(this.Af,this);this.sb=new Ym(this);this.Vf=new Zm(this);this.jd=new Tm($m(this.A,this.B));this.zb={};this.zb.unknown=this.sb;this.zb.signInViaRedirect=this.sb;this.zb.linkViaRedirect=this.sb;this.zb.reauthViaRedirect=this.sb;this.zb.signInViaPopup=this.Vf;this.zb.linkViaPopup=this.Vf;this.zb.reauthViaPopup=this.Vf;this.xa=an(this.J,this.A,this.B,Zg,this.s)},an=function(a,b,c,d,e){var f=
firebase.SDK_VERSION||null;return ph()?new Lm(a,b,c,f,d,e):new Xk(a,b,c,f,d,e)};bn.prototype.reset=function(){this.oc=!1;this.xa.rd(this.af);this.xa=an(this.J,this.A,this.B,null,this.s);this.Ae={}};bn.prototype.dc=function(){this.sb.dc()};bn.prototype.initialize=function(){var a=this;this.oc||(this.oc=!0,this.xa.Zb(this.af));var b=this.xa;return this.xa.Lb().h(function(c){a.xa==b&&a.reset();throw c;})};
var en=function(a){a.xa.di()&&a.initialize().h(function(b){var c=new mi("unknown",null,null,null,new P("operation-not-supported-in-this-environment"));cn(b)&&a.Af(c)});a.xa.fh()||dn(a.sb)};l=bn.prototype;l.subscribe=function(a){hb(this.yd,a)||this.yd.push(a);if(!this.oc){var b=this;Xm(this.jd).then(function(c){c?Wm(b.jd).then(function(){b.initialize().h(function(d){var e=new mi("unknown",null,null,null,new P("operation-not-supported-in-this-environment"));cn(d)&&b.Af(e)})}):en(b)}).h(function(){en(b)})}};
l.unsubscribe=function(a){lb(this.yd,function(b){return b==a})};l.Af=function(a){if(!a)throw new P("invalid-auth-event");Date.now()-this.Jf>=6E5&&(this.Ae={},this.Jf=0);if(a&&a.getUid()&&this.Ae.hasOwnProperty(a.getUid()))return!1;for(var b=!1,c=0;c<this.yd.length;c++){var d=this.yd[c];if(d.Cg(a.getType(),a.T)){if(b=this.zb[a.getType()])b.Nh(a,d),a&&(a.jc()||a.T)&&(this.Ae[a.getUid()]=!0,this.Jf=Date.now());b=!0;break}}dn(this.sb);return b};l.getRedirectResult=function(){return this.sb.getRedirectResult()};
l.ld=function(a,b,c,d,e,f){var g=this;return this.xa.ld(a,b,c,function(){g.oc||(g.oc=!0,g.xa.Zb(g.af))},function(){g.reset()},d,e,f)};var cn=function(a){return a&&a.code=="auth/cordova-not-ready"?!0:!1};bn.prototype.md=function(a,b,c,d){var e=this,f;return Vm(this.jd).then(function(){return e.xa.md(a,b,c,d).h(function(g){if(cn(g))throw new P("operation-not-supported-in-this-environment");f=g;return Wm(e.jd).then(function(){throw f;})}).then(function(){return e.xa.li()?new I(function(){}):Wm(e.jd).then(function(){return e.getRedirectResult()}).then(function(){}).h(function(){})})})};
bn.prototype.wd=function(a,b,c,d){return this.xa.wd(c,function(e){a.Sb(b,null,e,d)},fn.get())};var $m=function(a,b,c){a=a+":"+b;c&&(a=a+":"+c.url);return a},hn=function(a,b,c,d){var e=$m(b,c,d);gn[e]||(gn[e]=new bn(a,b,c,d));return gn[e]},fn=new Nh(2E3,1E4),jn=new Nh(3E4,6E4),gn={},Ym=function(a){this.o=a;this.Ac=null;this.pd=[];this.od=[];this.yc=null;this.mi=this.qd=!1};Ym.prototype.reset=function(){this.Ac=null;this.yc&&(this.yc.cancel(),this.yc=null)};
Ym.prototype.Nh=function(a,b){if(a){this.reset();this.qd=!0;var c=a.getType(),d=a.T,e=a.getError()&&a.getError().code=="auth/web-storage-unsupported",f=a.getError()&&a.getError().code=="auth/operation-not-supported-in-this-environment";this.mi=!(!e&&!f);c!="unknown"||e||f?a.Y?this.Xf(a,b):b.Vc(c,d)?this.Yf(a,b):K(new P("invalid-auth-event")):(kn(this,!1,null,null),J())}else K(new P("invalid-auth-event"))};var dn=function(a){a.qd||(a.qd=!0,kn(a,!1,null,null))};
Ym.prototype.dc=function(){this.qd&&!this.mi&&kn(this,!1,null,null)};Ym.prototype.Xf=function(a){kn(this,!0,null,a.getError());J()};Ym.prototype.Yf=function(a,b){var c=this,d=a.T,e=a.getType();b=b.Vc(e,d);d=a.Wa;e=a.jc();var f=a.Wf,g=a.C,h=!!a.getType().match(/Redirect$/);b(d,e,g,f).then(function(k){kn(c,h,k,null)}).h(function(k){kn(c,h,null,k)})};
var ln=function(a,b){a.Ac=function(){return K(b)};if(a.od.length)for(var c=0;c<a.od.length;c++)a.od[c](b)},mn=function(a,b){a.Ac=function(){return J(b)};if(a.pd.length)for(var c=0;c<a.pd.length;c++)a.pd[c](b)},kn=function(a,b,c,d){b?d?ln(a,d):mn(a,c):mn(a,{user:null});a.pd=[];a.od=[]};Ym.prototype.getRedirectResult=function(){var a=this;return new I(function(b,c){a.Ac?a.Ac().then(b,c):(a.pd.push(b),a.od.push(c),nn(a))})};
var nn=function(a){var b=new P("timeout");a.yc&&a.yc.cancel();a.yc=Tg(jn.get()).then(function(){a.Ac||(a.qd=!0,kn(a,!0,null,b))})},Zm=function(a){this.o=a};Zm.prototype.Nh=function(a,b){if(a){var c=a.getType(),d=a.T;a.Y?this.Xf(a,b):b.Vc(c,d)?this.Yf(a,b):K(new P("invalid-auth-event"))}else K(new P("invalid-auth-event"))};Zm.prototype.Xf=function(a,b){var c=a.T,d=a.getType();b.Sb(d,null,a.getError(),c);J()};
Zm.prototype.Yf=function(a,b){var c=a.T,d=a.getType(),e=b.Vc(d,c),f=a.Wa,g=a.jc();e(f,g,a.C,a.Wf).then(function(h){b.Sb(d,h,null,c)}).h(function(h){b.Sb(d,null,h,c)})};var on=function(a,b,c){var d=b&&b.mfaPendingCredential;if(!d)throw new P("argument-error","Internal assert: Invalid MultiFactorResolver");this.Jd=a;this.Qi=fd(b);this.Ij=c;this.Xh=new Hi(null,d);this.gh=[];var e=this;C(b.mfaInfo||[],function(f){(f=si(f))&&e.gh.push(f)});O(this,"auth",this.Jd);O(this,"session",this.Xh);O(this,"hints",this.gh)};
on.prototype.resolveSignIn=function(a){var b=this;return a.process(this.Jd.i,this.Xh).then(function(c){var d=fd(b.Qi);delete d.mfaInfo;delete d.mfaPendingCredential;hd(d,c);return b.Ij(d)})};var pn=function(a,b,c,d){P.call(this,"multi-factor-auth-required",d,b);this.Xj=new on(a,b,c);O(this,"resolver",this.Xj)};q(pn,P);var qn=function(a,b,c){if(a&&v(a.serverResponse)&&a.code==="auth/multi-factor-auth-required")try{return new pn(b,a.serverResponse,c,a.message)}catch(d){}return null};var rn=function(){};rn.prototype.process=function(a,b,c){return b.type=="enroll"?sn(this,a,b,c):tn(this,a,b)};var sn=function(a,b,c,d){return c.Xc().then(function(e){e={idToken:e};typeof d!=="undefined"&&(e.displayName=d);hd(e,{phoneVerificationInfo:lj(a.Of)});return Q(b,Fk,e)})},tn=function(a,b,c){return c.Xc().then(function(d){d={mfaPendingCredential:d};hd(d,{phoneVerificationInfo:lj(a.Of)});return Q(b,Gk,d)})},un=function(a){O(this,"factorId",a.providerId);this.Of=a};x(un,rn);
var vn=function(a){un.call(this,a);if(this.Of.providerId!=pj.PROVIDER_ID)throw new P("argument-error","firebase.auth.PhoneMultiFactorAssertion requires a valid firebase.auth.PhoneAuthCredential");};x(vn,un);var wn=function(a,b){H.call(this,a);for(var c in b)this[c]=b[c]};q(wn,H);var yn=function(a,b){this.ib=a;this.Td=[];this.xk=w(this.lj,this);df(this.ib,"userReloaded",this.xk);var c=[];b&&b.multiFactor&&b.multiFactor.enrolledFactors&&C(b.multiFactor.enrolledFactors,function(d){var e=null,f={};if(d){d.uid&&(f.mfaEnrollmentId=d.uid);d.displayName&&(f.displayName=d.displayName);d.enrollmentTime&&(f.enrolledAt=(new Date(d.enrollmentTime)).toISOString());if(d.phoneNumber){f.phoneInfo=d.phoneNumber;try{e=new qi(f)}catch(g){}}else if(d.totpInfo){f.totpInfo=d.totpInfo;try{e=new ri(f)}catch(g){}}else e=
null;d=e}else d=null;d&&c.push(d)});xn(this,c)},zn=function(a){var b=[];C(a.mfaInfo||[],function(c){(c=si(c))&&b.push(c)});return b};yn.prototype.lj=function(a){xn(this,zn(a.yk))};var xn=function(a,b){a.Td=b;O(a,"enrolledFactors",b)};l=yn.prototype;l.copy=function(a){xn(this,a.Td)};l.getSession=function(){return this.ib.getIdToken().then(function(a){return new Hi(a,null)})};
l.enroll=function(a,b){var c=this,d=this.ib.i;return this.getSession().then(function(e){return a.process(d,e,b)}).then(function(e){An(c.ib,e);return c.ib.reload()})};l.unenroll=function(a){var b=this,c=typeof a==="string"?a:a.uid,d=this.ib.i;return this.ib.getIdToken().then(function(e){return Q(d,Lk,{idToken:e,mfaEnrollmentId:c})}).then(function(e){var f=eb(b.Td,function(g){return g.uid!=c});xn(b,f);An(b.ib,e);return b.ib.reload().h(function(g){if(g.code!="auth/user-token-expired")throw g;})})};
l.m=function(){return{multiFactor:{enrolledFactors:fb(this.Td,function(a){return a.m()})}}};var Bn=function(a){this.i=a;this.na=this.la=null;this.fc=Date.now()};Bn.prototype.m=function(){return{apiKey:this.i.A,refreshToken:this.la,accessToken:this.na&&this.na.toString(),expirationTime:this.fc}};var Cn=function(a,b){typeof b==="undefined"&&(a.na?(b=a.na,b=b.uf-b.nj):b=0);a.fc=Date.now()+b*1E3},Dn=function(a,b){a.na=Fi(b.idToken||"");a.la=b.refreshToken;b=b.expiresIn;Cn(a,typeof b!=="undefined"?Number(b):void 0)};Bn.prototype.copy=function(a){this.na=a.na;this.la=a.la;this.fc=a.fc};
var En=function(a,b){return Nj(a.i,b).then(function(c){a.na=Fi(c.access_token);a.la=c.refresh_token;Cn(a,c.expires_in);return{accessToken:a.na.toString(),refreshToken:a.la}}).h(function(c){c.code=="auth/user-token-expired"&&(a.la=null);throw c;})};Bn.prototype.getToken=function(a){a=!!a;return this.na&&!this.la?K(new P("user-token-expired")):a||!this.na||Date.now()>this.fc-3E4?this.la?En(this,{grant_type:"refresh_token",refresh_token:this.la}):J(null):J({accessToken:this.na.toString(),refreshToken:this.la})};var Fn=function(a,b){this.Lg=a||null;this.rh=b||null;ai(this,{lastSignInTime:Rh(b||null),creationTime:Rh(a||null)})};Fn.prototype.clone=function(){return new Fn(this.Lg,this.rh)};Fn.prototype.m=function(){return{lastLoginAt:this.rh,createdAt:this.Lg}};
var Gn=function(a,b,c,d,e,f){ai(this,{uid:a,displayName:d||null,photoURL:e||null,email:c||null,phoneNumber:f||null,providerId:b})},R=function(a,b,c){pf.call(this);this.Z=[];this.A=a.apiKey;this.B=a.appName;this.J=a.authDomain||null;var d=firebase.SDK_VERSION?Bh("JsCore",firebase.SDK_VERSION):null;this.i=new Ej(this.A,Yg(Zg),d);(this.s=a.emulatorConfig||null)&&Ij(this.i,this.s);this.Ka=new Bn(this.i);Hn(this,b.idToken);Dn(this.Ka,b);O(this,"refreshToken",this.Ka.la);In(this,c||{});this.kd=!1;this.J&&
Fh()&&(this.v=hn(this.J,this.A,this.B,this.s));this.Ke=[];this.La=null;this.vc=Jn(this);this.Ic=w(this.Cf,this);var e=this;this.Fa=null;this.Eh=function(f){e.Cc(f.languageCode)};this.Hf=null;this.Ch=function(f){Kn(e,f.emulatorConfig)};this.pf=null;this.U=[];this.Dh=function(f){Ln(e,f.Uc)};this.xf=null;this.qe=new yn(this,c);O(this,"multiFactor",this.qe)};q(R,pf);R.prototype.Cc=function(a){this.Fa=a;Gj(this.i,a)};
var Kn=function(a,b){a.s=b;Ij(a.i,b);a.v&&(b=a.v,a.v=hn(a.J,a.A,a.B,a.s),a.kd&&(b.unsubscribe(a),a.v.subscribe(a)))},Mn=function(a,b){a.Hf&&mf(a.Hf,"languageCodeChanged",a.Eh);(a.Hf=b)&&df(b,"languageCodeChanged",a.Eh)},Nn=function(a,b){a.pf&&mf(a.pf,"emulatorConfigChanged",a.Ch);(a.pf=b)&&df(b,"emulatorConfigChanged",a.Ch)},Ln=function(a,b){a.U=b;Jj(a.i,firebase.SDK_VERSION?Bh("JsCore",firebase.SDK_VERSION,a.U):null)},On=function(a,b){a.xf&&mf(a.xf,"frameworkChanged",a.Dh);(a.xf=b)&&df(b,"frameworkChanged",
a.Dh)};R.prototype.Cf=function(){this.vc.sc&&(this.vc.stop(),this.vc.start())};
var Pn=function(a){try{return firebase.app(a.B).auth()}catch(b){throw new P("internal-error","No firebase.auth.Auth instance is available for the Firebase App '"+a.B+"'!");}},Jn=function(a){return new hm(function(){return a.getIdToken(!0)},function(b){return b&&b.code=="auth/network-request-failed"?!0:!1},function(){var b=a.Ka.fc-Date.now()-3E5;return b>0?b:0})},Qn=function(a){a.Qc||a.vc.sc||(a.vc.start(),mf(a,"tokenChanged",a.Ic),df(a,"tokenChanged",a.Ic))},Rn=function(a){mf(a,"tokenChanged",a.Ic);
a.vc.stop()},Hn=function(a,b){a.qh=b;O(a,"_lat",b)},Sn=function(a,b){lb(a.Ke,function(c){return c==b})},Tn=function(a){for(var b=[],c=0;c<a.Ke.length;c++)b.push(a.Ke[c](a));return cg(b).then(function(){return a})},Un=function(a){a.v&&!a.kd&&(a.kd=!0,a.v.subscribe(a))},In=function(a,b){ai(a,{uid:b.uid,displayName:b.displayName||null,photoURL:b.photoURL||null,email:b.email||null,emailVerified:b.emailVerified||!1,phoneNumber:b.phoneNumber||null,isAnonymous:b.isAnonymous||!1,tenantId:b.tenantId||null,
metadata:new Fn(b.createdAt,b.lastLoginAt),providerData:[]});a.i.C=a.tenantId},Vn=function(){},Wn=function(a){return J().then(function(){if(a.Qc)throw new P("app-deleted");})},Xn=function(a){return fb(a.providerData,function(b){return b.providerId})},Zn=function(a,b){b&&(Yn(a,b.providerId),a.providerData.push(b))},Yn=function(a,b){lb(a.providerData,function(c){return c.providerId==b})},$n=function(a,b,c){(b!="uid"||c)&&a.hasOwnProperty(b)&&O(a,b,c)};
R.prototype.copy=function(a){var b=this;b!=a&&(ai(this,{uid:a.uid,displayName:a.displayName,photoURL:a.photoURL,email:a.email,emailVerified:a.emailVerified,phoneNumber:a.phoneNumber,isAnonymous:a.isAnonymous,tenantId:a.tenantId,providerData:[]}),a.metadata?O(this,"metadata",a.metadata.clone()):O(this,"metadata",new Fn),C(a.providerData,function(c){Zn(b,c)}),this.Ka.copy(a.Ka),O(this,"refreshToken",this.Ka.la),this.qe.copy(a.qe))};R.prototype.reload=function(){var a=this;return this.j(Wn(this).then(function(){return ao(a).then(function(){return Tn(a)}).then(Vn)}))};
var ao=function(a){return a.getIdToken().then(function(b){var c=a.isAnonymous;return Q(a.i,Hk,{idToken:b}).then(w(a.Mj,a)).then(function(){c||$n(a,"isAnonymous",!1);return b})})};R.prototype.getIdTokenResult=function(a){return this.getIdToken(a).then(function(b){return new Gi(b)})};
R.prototype.getIdToken=function(a){var b=this;return this.j(Wn(this).then(function(){return b.Ka.getToken(a)}).then(function(c){if(!c)throw new P("internal-error");c.accessToken!=b.qh&&(Hn(b,c.accessToken),b.rb());$n(b,"refreshToken",c.refreshToken);return c.accessToken}))};var An=function(a,b){b.idToken&&a.qh!=b.idToken&&(Dn(a.Ka,b),a.rb(),Hn(a,b.idToken),$n(a,"refreshToken",a.Ka.la))};R.prototype.rb=function(){this.dispatchEvent(new wn("tokenChanged"))};
R.prototype.Mj=function(a){a=a.users;if(!a||!a.length)throw new P("internal-error");a=a[0];In(this,{uid:a.localId,displayName:a.displayName,photoURL:a.photoUrl,email:a.email,emailVerified:!!a.emailVerified,phoneNumber:a.phoneNumber,lastLoginAt:a.lastLoginAt,createdAt:a.createdAt,tenantId:a.tenantId});for(var b=bo(a),c=0;c<b.length;c++)Zn(this,b[c]);$n(this,"isAnonymous",!(this.email&&a.passwordHash)&&!(this.providerData&&this.providerData.length));this.dispatchEvent(new wn("userReloaded",{yk:a}))};
var bo=function(a){return(a=a.providerUserInfo)&&a.length?fb(a,function(b){return new Gn(b.rawId,b.providerId,b.email,b.displayName,b.photoUrl,b.phoneNumber)}):[]};R.prototype.reauthenticateAndRetrieveDataWithCredential=function(a){Yh("firebase.User.prototype.reauthenticateAndRetrieveDataWithCredential is deprecated. Please use firebase.User.prototype.reauthenticateWithCredential instead.");return this.reauthenticateWithCredential(a)};
R.prototype.reauthenticateWithCredential=function(a){var b=this,c=null;return this.j(a.fd(this.i,this.uid).then(function(d){An(b,d);c=co(b,d,"reauthenticate");b.La=null;return b.reload()}).then(function(){return c}),!0)};var eo=function(a,b){return ao(a).then(function(){if(hb(Xn(a),b))return Tn(a).then(function(){throw new P("provider-already-linked");})})};
R.prototype.linkAndRetrieveDataWithCredential=function(a){Yh("firebase.User.prototype.linkAndRetrieveDataWithCredential is deprecated. Please use firebase.User.prototype.linkWithCredential instead.");return this.linkWithCredential(a)};R.prototype.linkWithCredential=function(a){var b=this,c=null;return this.j(eo(this,a.providerId).then(function(){return b.getIdToken()}).then(function(d){return a.pc(b.i,d)}).then(function(d){c=co(b,d,"link");return fo(b,d)}).then(function(){return c}))};
R.prototype.linkWithPhoneNumber=function(a,b){var c=this;return this.j(eo(this,"phone").then(function(){return gm(Pn(c),a,b,w(c.linkWithCredential,c))}))};R.prototype.reauthenticateWithPhoneNumber=function(a,b){var c=this;return this.j(J().then(function(){return gm(Pn(c),a,b,w(c.reauthenticateWithCredential,c))}),!0)};var co=function(a,b,c){var d=uj(b);b=qm(b);return bi({user:a,credential:d,additionalUserInfo:b,operationType:c})},fo=function(a,b){An(a,b);return a.reload().then(function(){return a})};
l=R.prototype;l.updateEmail=function(a){var b=this;return this.j(this.getIdToken().then(function(c){return b.i.updateEmail(c,a)}).then(function(c){An(b,c);return b.reload()}))};l.updatePhoneNumber=function(a){var b=this;return this.j(this.getIdToken().then(function(c){return a.pc(b.i,c)}).then(function(c){An(b,c);return b.reload()}))};l.updatePassword=function(a){var b=this;return this.j(this.getIdToken().then(function(c){return b.i.updatePassword(c,a)}).then(function(c){An(b,c);return b.reload()}))};
l.updateProfile=function(a){if(a.displayName===void 0&&a.photoURL===void 0)return Wn(this);var b=this;return this.j(this.getIdToken().then(function(c){return b.i.updateProfile(c,{displayName:a.displayName,photoUrl:a.photoURL})}).then(function(c){An(b,c);$n(b,"displayName",c.displayName||null);$n(b,"photoURL",c.photoUrl||null);C(b.providerData,function(d){d.providerId==="password"&&(O(d,"displayName",b.displayName),O(d,"photoURL",b.photoURL))});return Tn(b)}).then(Vn))};
l.unlink=function(a){var b=this;return this.j(ao(this).then(function(c){return hb(Xn(b),a)?rk(b.i,c,[a]).then(function(d){var e={};C(d.providerUserInfo||[],function(f){e[f.providerId]=!0});C(Xn(b),function(f){e[f]||Yn(b,f)});e[pj.PROVIDER_ID]||O(b,"phoneNumber",null);return Tn(b)}):Tn(b).then(function(){throw new P("no-such-provider");})}))};
l.delete=function(){var a=this;return this.j(this.getIdToken().then(function(b){return Q(a.i,Ek,{idToken:b})}).then(function(){a.dispatchEvent(new wn("userDeleted"))})).then(function(){for(var b=0;b<a.Z.length;b++)a.Z[b].cancel("app-deleted");Mn(a,null);Nn(a,null);On(a,null);a.Z=[];a.Qc=!0;Rn(a);O(a,"refreshToken",null);a.v&&a.v.unsubscribe(a)})};
l.Cg=function(a,b){return a=="linkViaPopup"&&(this.Ha||null)==b&&this.Ga||a=="reauthViaPopup"&&(this.Ha||null)==b&&this.Ga||a=="linkViaRedirect"&&(this.tb||null)==b||a=="reauthViaRedirect"&&(this.tb||null)==b?!0:!1};l.Sb=function(a,b,c,d){a!="linkViaPopup"&&a!="reauthViaPopup"||d!=(this.Ha||null)||(c&&this.Pb?this.Pb(c):b&&!c&&this.Ga&&this.Ga(b),this.aa&&(this.aa.cancel(),this.aa=null),delete this.Ga,delete this.Pb)};
l.Vc=function(a,b){return a=="linkViaPopup"&&b==(this.Ha||null)?w(this.Vg,this):a=="reauthViaPopup"&&b==(this.Ha||null)?w(this.Wg,this):a=="linkViaRedirect"&&(this.tb||null)==b?w(this.Vg,this):a=="reauthViaRedirect"&&(this.tb||null)==b?w(this.Wg,this):null};l.Xd=function(){return Ch(this.uid+":::")};l.linkWithPopup=function(a){var b=this;return go(this,"linkViaPopup",a,function(){return eo(b,a.providerId).then(function(){return Tn(b)})},!1)};
l.reauthenticateWithPopup=function(a){return go(this,"reauthViaPopup",a,function(){return J()},!0)};
var go=function(a,b,c,d,e){if(!Fh())return K(new P("operation-not-supported-in-this-environment"));if(a.La&&!e)return K(a.La);var f=hi(c.providerId),g=a.Xd(),h=null;(!Gh()||sh())&&a.J&&c.isOAuthProvider&&(h=bl(a.J,a.A,a.B,b,c,null,g,firebase.SDK_VERSION||null,null,null,a.tenantId,a.s));var k=ih(h,f&&f.uc,f&&f.tc);d=d().then(function(){ho(a);if(!e)return a.getIdToken().then(function(){})}).then(function(){return a.v.ld(k,b,c,g,!!h,a.tenantId)}).then(function(){return new I(function(m,n){a.Sb(b,null,
new P("cancelled-popup-request"),a.Ha||null);a.Ga=m;a.Pb=n;a.Ha=g;a.aa=a.v.wd(a,b,k,g)})}).then(function(m){k&&hh(k);return m?bi(m):null}).h(function(m){k&&hh(k);throw m;});return a.j(d,e)};R.prototype.linkWithRedirect=function(a){var b=this;return io(this,"linkViaRedirect",a,function(){return eo(b,a.providerId)},!1)};R.prototype.reauthenticateWithRedirect=function(a){return io(this,"reauthViaRedirect",a,function(){return J()},!0)};
var io=function(a,b,c,d,e){if(!Fh())return K(new P("operation-not-supported-in-this-environment"));if(a.La&&!e)return K(a.La);var f=null,g=a.Xd();d=d().then(function(){ho(a);if(!e)return a.getIdToken().then(function(){})}).then(function(){a.tb=g;return Tn(a)}).then(function(h){a.ub&&(h=a.ub,h=h.o.set(jo,a.m(),h.D));return h}).then(function(){return a.v.md(b,c,g,a.tenantId)}).h(function(h){f=h;if(a.ub)return ko(a.ub);throw f;}).then(function(){if(f)throw f;});return a.j(d,e)},ho=function(a){if(!a.v||
!a.kd){if(a.v&&!a.kd)throw new P("internal-error");throw new P("auth-domain-config-required");}};l=R.prototype;l.Vg=function(a,b,c,d){var e=this;this.aa&&(this.aa.cancel(),this.aa=null);var f=null;c=this.getIdToken().then(function(g){return Mi(e.i,{requestUri:a,postBody:d,sessionId:b,idToken:g})}).then(function(g){f=co(e,g,"link");return fo(e,g)}).then(function(){return f});return this.j(c)};
l.Wg=function(a,b,c,d){var e=this;this.aa&&(this.aa.cancel(),this.aa=null);var f=null,g=J().then(function(){return Ji(Ni(e.i,{requestUri:a,sessionId:b,postBody:d,tenantId:c}),e.uid)}).then(function(h){f=co(e,h,"reauthenticate");An(e,h);e.La=null;return e.reload()}).then(function(){return f});return this.j(g,!0)};
l.sendEmailVerification=function(a){var b=this,c=null;return this.j(this.getIdToken().then(function(d){c=d;return typeof a==="undefined"||ed(a)?{}:em(new dm(a))}).then(function(d){return b.i.sendEmailVerification(c,d)}).then(function(d){if(b.email!=d)return b.reload()}).then(function(){}))};
l.verifyBeforeUpdateEmail=function(a,b){var c=this,d=null;return this.j(this.getIdToken().then(function(e){d=e;return typeof b==="undefined"||ed(b)?{}:em(new dm(b))}).then(function(e){return c.i.verifyBeforeUpdateEmail(d,a,e)}).then(function(e){if(c.email!=e)return c.reload()}).then(function(){}))};
l.j=function(a,b){var c=this,d=lo(this,a,b);this.Z.push(d);d.yb(function(){ib(c.Z,d)});return d.h(function(e){var f=null;e&&e.code==="auth/multi-factor-auth-required"&&(f=qn(e.m(),Pn(c),w(c.Bf,c)));throw f||e;})};l.Bf=function(a){var b=null,c=this;a=Ji(J(a),c.uid).then(function(d){b=co(c,d,"reauthenticate");An(c,d);c.La=null;return c.reload()}).then(function(){return b});return this.j(a,!0)};
var lo=function(a,b,c){return a.La&&!c?(b.cancel(),K(a.La)):b.h(function(d){!d||d.code!="auth/user-disabled"&&d.code!="auth/user-token-expired"||(a.La||a.dispatchEvent(new wn("userInvalidated")),a.La=d);throw d;})};R.prototype.toJSON=function(){return this.m()};
R.prototype.m=function(){var a={uid:this.uid,displayName:this.displayName,photoURL:this.photoURL,email:this.email,emailVerified:this.emailVerified,phoneNumber:this.phoneNumber,isAnonymous:this.isAnonymous,tenantId:this.tenantId,providerData:[],apiKey:this.A,appName:this.B,authDomain:this.J,stsTokenManager:this.Ka.m(),redirectEventId:this.tb||null};this.metadata&&hd(a,this.metadata.m());C(this.providerData,function(b){var c=a.providerData,d=c.push,e={},f;for(f in b)b.hasOwnProperty(f)&&(e[f]=b[f]);
d.call(c,e)});hd(a,this.qe.m());return a};
var mo=function(a){if(!a.apiKey)return null;var b={apiKey:a.apiKey,authDomain:a.authDomain,appName:a.appName,emulatorConfig:a.emulatorConfig},c={};if(a.stsTokenManager&&a.stsTokenManager.accessToken){c.idToken=a.stsTokenManager.accessToken;c.refreshToken=a.stsTokenManager.refreshToken||null;var d=a.stsTokenManager.expirationTime;d&&(c.expiresIn=(d-Date.now())/1E3)}else return null;var e=new R(b,c,a);a.providerData&&C(a.providerData,function(f){f&&Zn(e,bi(f))});a.redirectEventId&&(e.tb=a.redirectEventId);
return e},no=function(a,b,c,d){var e=new R(a,b);c&&(e.ub=c);d&&Ln(e,d);return e.reload().then(function(){return e})},oo=function(a,b,c,d){b=b||{apiKey:a.A,authDomain:a.J,appName:a.B};var e=a.Ka,f={};f.idToken=e.na&&e.na.toString();f.refreshToken=e.la;b=new R(b,f);c&&(b.ub=c);d&&Ln(b,d);b.copy(a);return b};O(R.prototype,"providerId","firebase");var po=function(a){this.D=a;this.o=vm()},ko=function(a){return a.o.remove(jo,a.D)},qo=function(a,b){return a.o.get(jo,a.D).then(function(c){c&&b&&(c.authDomain=b);return mo(c||{})})},jo={name:"redirectUser",N:"session"};var so=function(a){this.D=a;this.o=vm();this.oa=null;this.Rf=this.bb();this.o.addListener(ro("local"),this.D,w(this.mk,this))};so.prototype.mk=function(){var a=this,b=ro("local");to(this,function(){return J().then(function(){return a.oa&&a.oa.N!="local"?a.o.get(b,a.D):null}).then(function(c){if(c)return uo(a,"local").then(function(){a.oa=b})})})};var uo=function(a,b){var c=[],d;for(d in rm)rm[d]!==b&&c.push(a.o.remove(ro(rm[d]),a.D));c.push(a.o.remove(vo,a.D));return bg(c)};
so.prototype.bb=function(){var a=this,b=ro("local"),c=ro("session"),d=ro("none");return xm(this.o,b,this.D).then(function(){return a.o.get(c,a.D)}).then(function(e){return e?c:a.o.get(d,a.D).then(function(f){return f?d:a.o.get(b,a.D).then(function(g){return g?b:a.o.get(vo,a.D).then(function(h){return h?ro(h):b})})})}).then(function(e){a.oa=e;return uo(a,e.N)}).h(function(){a.oa||(a.oa=b)})};var ro=function(a){return{name:"authUser",N:a}};
so.prototype.setPersistence=function(a){var b=null,c=this;sm(a);return to(this,function(){return a!=c.oa.N?c.o.get(c.oa,c.D).then(function(d){b=d;return uo(c,a)}).then(function(){c.oa=ro(a);if(b)return c.o.set(c.oa,b,c.D)}):J()})};
var wo=function(a){return to(a,function(){return a.o.set(vo,a.oa.N,a.D)})},xo=function(a,b){return to(a,function(){return a.o.set(a.oa,b.m(),a.D)})},yo=function(a){return to(a,function(){return a.o.remove(a.oa,a.D)})},zo=function(a,b,c){return to(a,function(){return a.o.get(a.oa,a.D).then(function(d){d&&b&&(d.authDomain=b);d&&c&&(d.emulatorConfig=c);return mo(d||{})})})},to=function(a,b){a.Rf=a.Rf.then(b,b);return a.Rf},vo={name:"persistence",N:"session"};var S=function(a){pf.call(this);this.Aa=!1;this.Zh=new cm;O(this,"settings",this.Zh);O(this,"app",a);if(this.u().options&&this.u().options.apiKey)a=firebase.SDK_VERSION?Bh("JsCore",firebase.SDK_VERSION):null,this.i=new Ej(this.u().options&&this.u().options.apiKey,Yg(Zg),a);else throw new P("invalid-api-key");this.Z=[];this.Bb=[];this.Hc=[];this.Hj=firebase.INTERNAL.createSubscribe(w(this.pj,this));this.Cd=void 0;this.Kj=firebase.INTERNAL.createSubscribe(w(this.qj,this));Ao(this,null);this.Ma=new so(this.kc());
this.Rb=new po(this.kc());this.Id=this.j(Bo(this));this.Ia=this.j(Co(this));this.le=!1;this.zf=w(this.nk,this);this.ui=w(this.pb,this);this.Ic=w(this.Cf,this);this.ri=w(this.jj,this);this.si=w(this.kj,this);this.v=null;Do(this);this.INTERNAL={};this.INTERNAL["delete"]=w(this.delete,this);this.INTERNAL.logFramework=w(this.Dj,this);this.Ib=0;Eo(this);this.U=[];this.s=null};q(S,pf);S.prototype.setPersistence=function(a){a=this.Ma.setPersistence(a);return this.j(a)};
S.prototype.Cc=function(a){this.Fa===a||this.Aa||(this.Fa=a,Gj(this.i,this.Fa),this.dispatchEvent(new Fo(this.Fa)))};S.prototype.useDeviceLanguage=function(){var a=u.navigator;this.Cc(a?a.languages&&a.languages[0]||a.language||a.userLanguage||null:null)};
S.prototype.useEmulator=function(a,b){if(!this.s){if(this.v)throw new P("argument-error","useEmulator() must be called immediately following firebase.auth() initialization.");b=b?!!b.disableWarnings:!1;Go(b);this.s={url:a,disableWarnings:b};this.Zh.Xe=!0;Ij(this.i,this.s);this.dispatchEvent(new Ho(this.s))}};
var Go=function(a){typeof console!=="undefined"&&typeof console.info==="function"&&console.info("WARNING: You are using the Auth Emulator, which is intended for local testing only.  Do not use with production credentials.");u.document&&!a&&oh().then(function(){var b=u.document.createElement("p");b.innerText="Running in emulator mode. Do not use with production credentials.";b.style.position="fixed";b.style.width="100%";b.style.backgroundColor="#ffffff";b.style.border=".1em solid #000000";b.style.color=
"#b50000";b.style.bottom="0px";b.style.left="0px";b.style.margin="0px";b.style.zIndex=1E4;b.style.textAlign="center";b.classList.add("firebase-emulator-warning");u.document.body.appendChild(b)})};S.prototype.Dj=function(a){this.U.push(a);Jj(this.i,firebase.SDK_VERSION?Bh("JsCore",firebase.SDK_VERSION,this.U):null);this.dispatchEvent(new Io(this.U))};S.prototype.kg=function(a){this.C===a||this.Aa||(this.C=a,this.i.C=this.C)};
var Eo=function(a){Object.defineProperty(a,"lc",{get:function(){return this.Fa},set:function(b){this.Cc(b)},enumerable:!1});a.Fa=null;Object.defineProperty(a,"ti",{get:function(){return this.C},set:function(b){this.kg(b)},enumerable:!1});a.C=null;Object.defineProperty(a,"emulatorConfig",{get:function(){if(this.s){var b=F(this.s.url);b=bi({protocol:b.ua,host:b.ga,port:b.Sa,options:bi({disableWarnings:this.s.disableWarnings})})}else b=null;return b},enumerable:!1})};
S.prototype.toJSON=function(){return{apiKey:this.u().options.apiKey,authDomain:this.u().options.authDomain,appName:this.u().name,currentUser:T(this)&&T(this).m()}};
var Jo=function(a){return a.Ri||K(new P("auth-domain-config-required"))},Do=function(a){var b=a.u().options.authDomain,c=a.u().options.apiKey;b&&Fh()&&(a.Ri=a.Id.then(function(){if(!a.Aa){a.v=hn(b,c,a.u().name,a.s);a.v.subscribe(a);T(a)&&Un(T(a));if(a.vb){Un(a.vb);var d=a.vb;d.Cc(a.Fa);Mn(d,a);d=a.vb;Ln(d,a.U);On(d,a);d=a.vb;Kn(d,a.s);Nn(d,a);a.vb=null}return a.v}}))};l=S.prototype;
l.Cg=function(a,b){switch(a){case "unknown":case "signInViaRedirect":return!0;case "signInViaPopup":return this.Ha==b&&!!this.Ga;default:return!1}};l.Sb=function(a,b,c,d){a=="signInViaPopup"&&this.Ha==d&&(c&&this.Pb?this.Pb(c):b&&!c&&this.Ga&&this.Ga(b),this.aa&&(this.aa.cancel(),this.aa=null),delete this.Ga,delete this.Pb)};l.Vc=function(a,b){return a=="signInViaRedirect"||a=="signInViaPopup"&&this.Ha==b&&this.Ga?w(this.Vi,this):null};
l.Vi=function(a,b,c,d){var e=this,f={requestUri:a,postBody:d,sessionId:b,tenantId:c};this.aa&&(this.aa.cancel(),this.aa=null);return e.Id.then(function(){return Ko(e,Li(e.i,f))})};l.Xd=function(){return Ch()};
l.signInWithPopup=function(a){if(!Fh())return K(new P("operation-not-supported-in-this-environment"));var b=this,c=hi(a.providerId),d=this.Xd(),e=null;(!Gh()||sh())&&this.u().options.authDomain&&a.isOAuthProvider&&(e=bl(this.u().options.authDomain,this.u().options.apiKey,this.u().name,"signInViaPopup",a,null,d,firebase.SDK_VERSION||null,null,null,this.C,this.s));var f=ih(e,c&&c.uc,c&&c.tc);c=Jo(this).then(function(g){return g.ld(f,"signInViaPopup",a,d,!!e,b.C)}).then(function(){return new I(function(g,
h){b.Sb("signInViaPopup",null,new P("cancelled-popup-request"),b.Ha);b.Ga=g;b.Pb=h;b.Ha=d;b.aa=b.v.wd(b,"signInViaPopup",f,d)})}).then(function(g){f&&hh(f);return g?bi(g):null}).h(function(g){f&&hh(f);throw g;});return this.j(c)};l.signInWithRedirect=function(a){if(!Fh())return K(new P("operation-not-supported-in-this-environment"));var b=this,c=Jo(this).then(function(){return wo(b.Ma)}).then(function(){return b.v.md("signInViaRedirect",a,void 0,b.C)});return this.j(c)};
var Lo=function(a){if(!Fh())return K(new P("operation-not-supported-in-this-environment"));var b=Jo(a).then(function(){return a.v.getRedirectResult()}).then(function(c){return c?bi(c):null});return a.j(b)};S.prototype.getRedirectResult=function(){var a=this;return Lo(this).then(function(b){a.v&&a.v.dc();return b}).h(function(b){a.v&&a.v.dc();throw b;})};
S.prototype.updateCurrentUser=function(a){if(!a)return K(new P("null-user"));if(this.C!=a.tenantId)return K(new P("tenant-id-mismatch"));var b=this,c={};c.apiKey=this.u().options.apiKey;c.authDomain=this.u().options.authDomain;c.appName=this.u().name;var d=oo(a,c,b.Rb,mb(b.U));return this.j(this.Ia.then(function(){if(b.u().options.apiKey!=a.A)return d.reload()}).then(function(){if(T(b)&&a.uid==T(b).uid)return T(b).copy(a),b.pb(a);Ao(b,d);Un(d);return b.pb(d)}).then(function(){b.rb()}))};
var Mo=function(a,b){var c={};c.apiKey=a.u().options.apiKey;c.authDomain=a.u().options.authDomain;c.appName=a.u().name;a.s&&(c.emulatorConfig=a.s);return a.Id.then(function(){return no(c,b,a.Rb,mb(a.U))}).then(function(d){if(T(a)&&d.uid==T(a).uid)return T(a).copy(d),a.pb(d);Ao(a,d);Un(d);return a.pb(d)}).then(function(){a.rb()})},Ao=function(a,b){T(a)&&(Sn(T(a),a.ui),mf(T(a),"tokenChanged",a.Ic),mf(T(a),"userDeleted",a.ri),mf(T(a),"userInvalidated",a.si),Rn(T(a)));b&&(b.Ke.push(a.ui),df(b,"tokenChanged",
a.Ic),df(b,"userDeleted",a.ri),df(b,"userInvalidated",a.si),a.Ib>0&&Qn(b));O(a,"currentUser",b);b&&(b.Cc(a.Fa),Mn(b,a),Ln(b,a.U),On(b,a),Kn(b,a.s),Nn(b,a))};S.prototype.signOut=function(){var a=this,b=this.Ia.then(function(){a.v&&a.v.dc();if(!T(a))return J();Ao(a,null);return yo(a.Ma).then(function(){a.rb()})});return this.j(b)};
var No=function(a){var b=a.u().options.authDomain;b=qo(a.Rb,b).then(function(c){if(a.vb=c)c.ub=a.Rb;return ko(a.Rb)});return a.j(b)},Bo=function(a){var b=a.u().options.authDomain,c=No(a).then(function(){return zo(a.Ma,b,a.s)}).then(function(d){return d?(d.ub=a.Rb,a.vb&&(a.vb.tb||null)==(d.tb||null)?d:d.reload().then(function(){return xo(a.Ma,d).then(function(){return d})}).h(function(e){return e.code=="auth/network-request-failed"?d:yo(a.Ma)})):null}).then(function(d){Ao(a,d||null)});return a.j(c)},
Co=function(a){return a.Id.then(function(){return Lo(a)}).h(function(){}).then(function(){if(!a.Aa)return a.zf()}).h(function(){}).then(function(){if(!a.Aa){a.le=!0;var b=a.Ma;b.o.addListener(ro("local"),b.D,a.zf)}})};l=S.prototype;
l.nk=function(){var a=this,b=this.u().options.authDomain;return zo(this.Ma,b).then(function(c){if(!a.Aa){var d;if(d=T(a)&&c){d=T(a).uid;var e=c.uid;d=d===void 0||d===null||d===""||e===void 0||e===null||e===""?!1:d==e}if(d)return T(a).copy(c),T(a).getIdToken();if(T(a)||c)Ao(a,c),c&&(Un(c),c.ub=a.Rb),a.v&&a.v.subscribe(a),a.rb()}})};l.pb=function(a){return xo(this.Ma,a)};l.Cf=function(){this.rb();this.pb(T(this))};l.jj=function(){this.signOut()};l.kj=function(){this.signOut()};
var Ko=function(a,b){var c=null,d=null;return a.j(b.then(function(e){c=uj(e);d=qm(e);return Mo(a,e)},function(e){var f=null;e&&e.code==="auth/multi-factor-auth-required"&&(f=qn(e.m(),a,w(a.Bf,a)));throw f||e;}).then(function(){return bi({user:T(a),credential:c,additionalUserInfo:d,operationType:"signIn"})}))};l=S.prototype;l.Bf=function(a){var b=this;return this.Ia.then(function(){return Ko(b,J(a))})};l.pj=function(a){var b=this;this.addAuthTokenListener(function(){a.next(T(b))})};
l.qj=function(a){var b=this;Oo(this,function(){a.next(T(b))})};l.onIdTokenChanged=function(a,b,c){var d=this;this.le&&firebase.Promise.resolve().then(function(){typeof a==="function"?a(T(d)):typeof a.next==="function"&&a.next(T(d))});return this.Hj(a,b,c)};l.onAuthStateChanged=function(a,b,c){var d=this;this.le&&firebase.Promise.resolve().then(function(){d.Cd=d.getUid();typeof a==="function"?a(T(d)):typeof a.next==="function"&&a.next(T(d))});return this.Kj(a,b,c)};
l.Yi=function(a){var b=this,c=this.Ia.then(function(){return T(b)?T(b).getIdToken(a).then(function(d){return{accessToken:d}}):null});return this.j(c)};l.signInWithCustomToken=function(a){var b=this;return this.Ia.then(function(){return Ko(b,Q(b.i,Kk,{token:a}))}).then(function(c){var d=c.user;$n(d,"isAnonymous",!1);b.pb(d);return c})};l.signInWithEmailAndPassword=function(a,b){var c=this;return this.Ia.then(function(){return Ko(c,Q(c.i,ej,{email:a,password:b}))})};
l.createUserWithEmailAndPassword=function(a,b){var c=this;return this.Ia.then(function(){return Ko(c,Q(c.i,Dk,{email:a,password:b}))})};l.signInWithCredential=function(a){var b=this;return this.Ia.then(function(){return Ko(b,a.Jb(b.i))})};l.signInAndRetrieveDataWithCredential=function(a){Yh("firebase.auth.Auth.prototype.signInAndRetrieveDataWithCredential is deprecated. Please use firebase.auth.Auth.prototype.signInWithCredential instead.");return this.signInWithCredential(a)};
l.signInAnonymously=function(){var a=this;return this.Ia.then(function(){var b=T(a);if(b&&b.isAnonymous){var c=bi({providerId:null,isNewUser:!1});return bi({user:b,credential:null,additionalUserInfo:c,operationType:"signIn"})}return Ko(a,a.i.signInAnonymously()).then(function(d){var e=d.user;$n(e,"isAnonymous",!0);a.pb(e);return d})})};l.kc=function(){var a=this.u().options.apiKey,b=this.u().name;return a+":"+b};l.u=function(){return this.app};var T=function(a){return a.currentUser};
S.prototype.getUid=function(){return T(this)&&T(this).uid||null};var Po=function(a){return T(a)&&T(a)._lat||null};l=S.prototype;l.rb=function(){if(this.le){for(var a=0;a<this.Bb.length;a++)if(this.Bb[a])this.Bb[a](Po(this));if(this.Cd!==this.getUid()&&this.Hc.length)for(this.Cd=this.getUid(),a=0;a<this.Hc.length;a++)if(this.Hc[a])this.Hc[a](Po(this))}};l.Fi=function(a){this.addAuthTokenListener(a);this.Ib++;this.Ib>0&&T(this)&&Qn(T(this))};
l.Rj=function(a){var b=this;C(this.Bb,function(c){c==a&&b.Ib--});this.Ib<0&&(this.Ib=0);this.Ib==0&&T(this)&&Rn(T(this));this.removeAuthTokenListener(a)};l.addAuthTokenListener=function(a){var b=this;this.Bb.push(a);this.j(this.Ia.then(function(){b.Aa||hb(b.Bb,a)&&a(Po(b))}))};l.removeAuthTokenListener=function(a){lb(this.Bb,function(b){return b==a})};var Oo=function(a,b){a.Hc.push(b);a.j(a.Ia.then(function(){!a.Aa&&hb(a.Hc,b)&&a.Cd!==a.getUid()&&(a.Cd=a.getUid(),b(Po(a)))}))};l=S.prototype;
l.delete=function(){this.Aa=!0;for(var a=0;a<this.Z.length;a++)this.Z[a].cancel("app-deleted");this.Z=[];this.Ma&&(a=this.Ma,a.o.removeListener(ro("local"),a.D,this.zf));this.v&&(this.v.unsubscribe(this),this.v.dc());return firebase.Promise.resolve()};l.j=function(a){var b=this;this.Z.push(a);a.yb(function(){ib(b.Z,a)});return a};l.fetchSignInMethodsForEmail=function(a){return this.j(Uj(this.i,a))};l.isSignInWithEmailLink=function(a){return!!ij(a)};
l.sendSignInLinkToEmail=function(a,b){var c=this;return this.j(J().then(function(){var d=new dm(b);if(!d.Dg)throw new P("argument-error","handleCodeInApp must be true when sending sign in link to email");return em(d)}).then(function(d){return c.i.sendSignInLinkToEmail(a,d)}).then(function(){}))};l.verifyPasswordResetCode=function(a){return this.checkActionCode(a).then(function(b){return b.data.email})};l.confirmPasswordReset=function(a,b){return this.j(this.i.confirmPasswordReset(a,b).then(function(){}))};
l.checkActionCode=function(a){return this.j(this.i.checkActionCode(a).then(function(b){return new ti(b)}))};l.applyActionCode=function(a){return this.j(this.i.applyActionCode(a).then(function(){}))};l.sendPasswordResetEmail=function(a,b){var c=this;return this.j(J().then(function(){return typeof b==="undefined"||ed(b)?{}:em(new dm(b))}).then(function(d){return c.i.sendPasswordResetEmail(a,d)}).then(function(){}))};
l.signInWithPhoneNumber=function(a,b){return this.j(gm(this,a,b,w(this.signInWithCredential,this)))};l.signInWithEmailLink=function(a,b){var c=this;return this.j(J().then(function(){b=b||ah();var d=jj(a,b),e=ij(b);if(!e)throw new P("argument-error","Invalid email link!");if(e.tenantId!==c.C)throw new P("tenant-id-mismatch");return c.signInWithCredential(d)}))};var Fo=function(a){H.call(this,"languageCodeChanged");this.languageCode=a};q(Fo,H);
var Ho=function(a){H.call(this,"emulatorConfigChanged");this.emulatorConfig=a};q(Ho,H);var Io=function(a){H.call(this,"frameworkChanged");this.Uc=a};q(Io,H);var Ro=function(a,b,c,d){a:{c=Array.prototype.slice.call(c);var e=0;for(var f=!1,g=0;g<b.length;g++)if(b[g].optional)f=!0;else{if(f)throw new P("internal-error","Argument validator encountered a required argument after an optional argument.");e++}f=b.length;if(c.length<e||f<c.length)d="Expected "+(e==f?e==1?"1 argument":e+" arguments":e+"-"+f+" arguments")+" but got "+c.length+".";else{for(e=0;e<c.length;e++)if(f=b[e].optional&&c[e]===void 0,!b[e].X(c[e])&&!f){c=e;b=b[e];if(c<0||c>=Qo.length)throw new P("internal-error",
"Argument validator received an unsupported number of arguments.");c=Qo[c];d=(d?"":c+" argument ")+(b.name?'"'+b.name+'" ':"")+"must be "+b.W+".";break a}d=null}}if(d)throw new P("argument-error",a+" failed: "+d);},Qo="First Second Third Fourth Fifth Sixth Seventh Eighth Ninth".split(" "),U=function(a,b){return{name:a||"",W:"a valid string",optional:!!b,X:function(c){return typeof c==="string"}}},So=function(a,b){return{name:a||"",W:"a boolean",optional:!!b,X:function(c){return typeof c==="boolean"}}},
V=function(a,b){return{name:a||"",W:"a valid object",optional:!!b,X:v}},To=function(a,b){return{name:a||"",W:"a function",optional:!!b,X:zf}},Uo=function(a,b){return{name:a||"",W:"null",optional:!!b,X:function(c){return c===null}}},Vo=function(){return{name:"",W:"an HTML element",optional:!1,X:function(a){return!!(a&&a instanceof Element)}}},Wo=function(){return{name:"auth",W:"an instance of Firebase Auth",optional:!0,X:function(a){return!!(a&&a instanceof S)}}},Xo=function(){return{name:"app",W:"an instance of Firebase App",
optional:!0,X:function(a){return!!(a&&a instanceof firebase.app.App)}}},Yo=function(a){return{name:a?a+"Credential":"credential",W:a?"a valid "+a+" credential":"a valid credential",optional:!1,X:function(b){if(!b)return!1;var c=!a||b.providerId===a;return!(!b.Jb||!c)}}},Zo=function(){return{name:"multiFactorAssertion",W:"a valid multiFactorAssertion",optional:!1,X:function(a){return a?!!a.process:!1}}},$o=function(){return{name:"authProvider",W:"a valid Auth provider",optional:!1,X:function(a){return!!(a&&
a.providerId&&a.hasOwnProperty&&a.hasOwnProperty("isOAuthProvider"))}}},ap=function(a,b){return v(a)&&typeof a.type==="string"&&a.type===b&&typeof a.Xc==="function"},bp=function(a){return v(a)&&typeof a.uid==="string"},cp=function(){return{name:"applicationVerifier",W:"an implementation of firebase.auth.ApplicationVerifier",optional:!1,X:function(a){return!(!a||typeof a.type!=="string"||typeof a.verify!=="function")}}},W=function(a,b,c,d){return{name:c||"",W:a.W+" or "+b.W,optional:!!d,X:function(e){return a.X(e)||
b.X(e)}}};var X=function(a,b){for(var c in b){var d=b[c].name;a[d]=dp(d,a[c],b[c].g)}},ep=function(a,b){for(var c in b){var d=b[c].name;d!==c&&Object.defineProperty(a,d,{get:Aa(function(e){return this[e]},c),set:Aa(function(e,f,g,h){Ro(e,[g],[h],!0);this[f]=h},d,c,b[c].Ye),enumerable:!0})}},Y=function(a,b,c,d){a[b]=dp(b,c,d)},dp=function(a,b,c){if(!c)return b;var d=fp(a);a=function(){var g=Array.prototype.slice.call(arguments);Ro(d,c,g);return b.apply(this,g)};for(var e in b)a[e]=b[e];for(var f in b.prototype)a.prototype[f]=
b.prototype[f];return a},fp=function(a){a=a.split(".");return a[a.length-1]};function gp(){}O(gp,"FACTOR_ID","phone");X(S.prototype,{applyActionCode:{name:"applyActionCode",g:[U("code")]},checkActionCode:{name:"checkActionCode",g:[U("code")]},confirmPasswordReset:{name:"confirmPasswordReset",g:[U("code"),U("newPassword")]},createUserWithEmailAndPassword:{name:"createUserWithEmailAndPassword",g:[U("email"),U("password")]},fetchSignInMethodsForEmail:{name:"fetchSignInMethodsForEmail",g:[U("email")]},getRedirectResult:{name:"getRedirectResult",g:[]},isSignInWithEmailLink:{name:"isSignInWithEmailLink",g:[U("emailLink")]},
onAuthStateChanged:{name:"onAuthStateChanged",g:[W(V(),To(),"nextOrObserver"),To("opt_error",!0),To("opt_completed",!0)]},onIdTokenChanged:{name:"onIdTokenChanged",g:[W(V(),To(),"nextOrObserver"),To("opt_error",!0),To("opt_completed",!0)]},sendPasswordResetEmail:{name:"sendPasswordResetEmail",g:[U("email"),W(V("opt_actionCodeSettings",!0),Uo(null,!0),"opt_actionCodeSettings",!0)]},sendSignInLinkToEmail:{name:"sendSignInLinkToEmail",g:[U("email"),V("actionCodeSettings")]},setPersistence:{name:"setPersistence",
g:[U("persistence")]},signInAndRetrieveDataWithCredential:{name:"signInAndRetrieveDataWithCredential",g:[Yo()]},signInAnonymously:{name:"signInAnonymously",g:[]},signInWithCredential:{name:"signInWithCredential",g:[Yo()]},signInWithCustomToken:{name:"signInWithCustomToken",g:[U("token")]},signInWithEmailAndPassword:{name:"signInWithEmailAndPassword",g:[U("email"),U("password")]},signInWithEmailLink:{name:"signInWithEmailLink",g:[U("email"),U("emailLink",!0)]},signInWithPhoneNumber:{name:"signInWithPhoneNumber",
g:[U("phoneNumber"),cp()]},signInWithPopup:{name:"signInWithPopup",g:[$o()]},signInWithRedirect:{name:"signInWithRedirect",g:[$o()]},updateCurrentUser:{name:"updateCurrentUser",g:[W(function(a){return{name:"user",W:"an instance of Firebase User",optional:!!a,X:function(b){return!!(b&&b instanceof R)}}}(),Uo(),"user")]},signOut:{name:"signOut",g:[]},toJSON:{name:"toJSON",g:[U(null,!0)]},useDeviceLanguage:{name:"useDeviceLanguage",g:[]},useEmulator:{name:"useEmulator",g:[U("url"),V("options",!0)]},
verifyPasswordResetCode:{name:"verifyPasswordResetCode",g:[U("code")]}});ep(S.prototype,{lc:{name:"languageCode",Ye:W(U(),Uo(),"languageCode")},ti:{name:"tenantId",Ye:W(U(),Uo(),"tenantId")}});S.Persistence=rm;S.Persistence.LOCAL="local";S.Persistence.SESSION="session";S.Persistence.NONE="none";
X(R.prototype,{"delete":{name:"delete",g:[]},getIdTokenResult:{name:"getIdTokenResult",g:[So("opt_forceRefresh",!0)]},getIdToken:{name:"getIdToken",g:[So("opt_forceRefresh",!0)]},linkAndRetrieveDataWithCredential:{name:"linkAndRetrieveDataWithCredential",g:[Yo()]},linkWithCredential:{name:"linkWithCredential",g:[Yo()]},linkWithPhoneNumber:{name:"linkWithPhoneNumber",g:[U("phoneNumber"),cp()]},linkWithPopup:{name:"linkWithPopup",g:[$o()]},linkWithRedirect:{name:"linkWithRedirect",g:[$o()]},reauthenticateAndRetrieveDataWithCredential:{name:"reauthenticateAndRetrieveDataWithCredential",
g:[Yo()]},reauthenticateWithCredential:{name:"reauthenticateWithCredential",g:[Yo()]},reauthenticateWithPhoneNumber:{name:"reauthenticateWithPhoneNumber",g:[U("phoneNumber"),cp()]},reauthenticateWithPopup:{name:"reauthenticateWithPopup",g:[$o()]},reauthenticateWithRedirect:{name:"reauthenticateWithRedirect",g:[$o()]},reload:{name:"reload",g:[]},sendEmailVerification:{name:"sendEmailVerification",g:[W(V("opt_actionCodeSettings",!0),Uo(null,!0),"opt_actionCodeSettings",!0)]},toJSON:{name:"toJSON",g:[U(null,
!0)]},unlink:{name:"unlink",g:[U("provider")]},updateEmail:{name:"updateEmail",g:[U("email")]},updatePassword:{name:"updatePassword",g:[U("password")]},updatePhoneNumber:{name:"updatePhoneNumber",g:[Yo("phone")]},updateProfile:{name:"updateProfile",g:[V("profile")]},verifyBeforeUpdateEmail:{name:"verifyBeforeUpdateEmail",g:[U("email"),W(V("opt_actionCodeSettings",!0),Uo(null,!0),"opt_actionCodeSettings",!0)]}});X(hl.prototype,{execute:{name:"execute"},render:{name:"render"},reset:{name:"reset"},getResponse:{name:"getResponse"}});
X(cl.prototype,{execute:{name:"execute"},render:{name:"render"},reset:{name:"reset"},getResponse:{name:"getResponse"}});X(I.prototype,{yb:{name:"finally"},h:{name:"catch"},then:{name:"then"}});ep(cm.prototype,{appVerificationDisabled:{name:"appVerificationDisabledForTesting",Ye:So("appVerificationDisabledForTesting")}});X(fm.prototype,{confirm:{name:"confirm",g:[U("verificationCode")]}});
Y(Ii,"fromJSON",function(a){a=typeof a==="string"?JSON.parse(a):a;for(var b,c=[Qi,hj,oj,Oi],d=0;d<c.length;d++)if(b=c[d](a))return b;return null},[W(U(),V(),"json")]);Y(bj,"credential",function(a,b){return new cj(a,b)},[U("email"),U("password")]);X(cj.prototype,{m:{name:"toJSON",g:[U(null,!0)]}});X(Ui.prototype,{addScope:{name:"addScope",g:[U("scope")]},setCustomParameters:{name:"setCustomParameters",g:[V("customOAuthParameters")]}});Y(Ui,"credential",Vi,[W(U(),V(),"token")]);
Y(bj,"credentialWithLink",jj,[U("email"),U("emailLink")]);X(Wi.prototype,{addScope:{name:"addScope",g:[U("scope")]},setCustomParameters:{name:"setCustomParameters",g:[V("customOAuthParameters")]}});Y(Wi,"credential",Xi,[W(U(),V(),"token")]);X(Yi.prototype,{addScope:{name:"addScope",g:[U("scope")]},setCustomParameters:{name:"setCustomParameters",g:[V("customOAuthParameters")]}});Y(Yi,"credential",Zi,[W(U(),W(V(),Uo()),"idToken"),W(U(),Uo(),"accessToken",!0)]);
X($i.prototype,{setCustomParameters:{name:"setCustomParameters",g:[V("customOAuthParameters")]}});Y($i,"credential",aj,[W(U(),V(),"token"),U("secret",!0)]);X(Ti.prototype,{addScope:{name:"addScope",g:[U("scope")]},credential:{name:"credential",g:[W(U(),W(V(),Uo()),"optionsOrIdToken"),W(U(),Uo(),"accessToken",!0)]},setCustomParameters:{name:"setCustomParameters",g:[V("customOAuthParameters")]}});X(Pi.prototype,{m:{name:"toJSON",g:[U(null,!0)]}});X(Ki.prototype,{m:{name:"toJSON",g:[U(null,!0)]}});
Y(pj,"credential",tj,[U("verificationId"),U("verificationCode")]);
X(pj.prototype,{verifyPhoneNumber:{name:"verifyPhoneNumber",g:[W(U(),function(a,b){return{name:a||"phoneInfoOptions",W:"valid phone info options",optional:!!b,X:function(c){return c?c.session&&c.phoneNumber?ap(c.session,"enroll")&&typeof c.phoneNumber==="string":c.session&&c.multiFactorHint?ap(c.session,"signin")&&bp(c.multiFactorHint):c.session&&c.multiFactorUid?ap(c.session,"signin")&&typeof c.multiFactorUid==="string":c.phoneNumber?typeof c.phoneNumber==="string":!1:!1}}}(),"phoneInfoOptions"),
cp()]}});X(kj.prototype,{m:{name:"toJSON",g:[U(null,!0)]}});X(P.prototype,{toJSON:{name:"toJSON",g:[U(null,!0)]}});X(wj.prototype,{toJSON:{name:"toJSON",g:[U(null,!0)]}});X(Ci.prototype,{toJSON:{name:"toJSON",g:[U(null,!0)]}});X(pn.prototype,{toJSON:{name:"toJSON",g:[U(null,!0)]}});X(on.prototype,{resolveSignIn:{name:"resolveSignIn",g:[Zo()]}});
X(yn.prototype,{getSession:{name:"getSession",g:[]},enroll:{name:"enroll",g:[Zo(),U("displayName",!0)]},unenroll:{name:"unenroll",g:[W({name:"multiFactorInfo",W:"a valid multiFactorInfo",optional:!1,X:bp},U(),"multiFactorInfoIdentifier")]}});X(sl.prototype,{clear:{name:"clear",g:[]},render:{name:"render",g:[]},verify:{name:"verify",g:[]}});Y(vi,"parseLink",wi,[U("link")]);Y(gp,"assertion",function(a){return new vn(a)},[Yo("phone")]);
(function(){if(typeof firebase!=="undefined"&&firebase.INTERNAL&&firebase.INTERNAL.registerService){var a={ActionCodeInfo:{Operation:{EMAIL_SIGNIN:"EMAIL_SIGNIN",PASSWORD_RESET:"PASSWORD_RESET",RECOVER_EMAIL:"RECOVER_EMAIL",REVERT_SECOND_FACTOR_ADDITION:"REVERT_SECOND_FACTOR_ADDITION",VERIFY_AND_CHANGE_EMAIL:"VERIFY_AND_CHANGE_EMAIL",VERIFY_EMAIL:"VERIFY_EMAIL"}},Auth:S,AuthCredential:Ii,Error:P};Y(a,"EmailAuthProvider",bj,[]);Y(a,"FacebookAuthProvider",Ui,[]);Y(a,"GithubAuthProvider",Wi,[]);Y(a,
"GoogleAuthProvider",Yi,[]);Y(a,"TwitterAuthProvider",$i,[]);Y(a,"OAuthProvider",Ti,[U("providerId")]);Y(a,"SAMLAuthProvider",Si,[U("providerId")]);Y(a,"PhoneAuthProvider",pj,[Wo()]);Y(a,"RecaptchaVerifier",sl,[W(U(),Vo(),"recaptchaContainer"),V("recaptchaParameters",!0),Xo()]);Y(a,"ActionCodeURL",vi,[]);Y(a,"PhoneMultiFactorGenerator",gp,[]);firebase.INTERNAL.registerService("auth",function(b,c){b=new S(b);c({INTERNAL:{getUid:w(b.getUid,b),getToken:w(b.Yi,b),addAuthTokenListener:w(b.Fi,b),removeAuthTokenListener:w(b.Rj,
b)}});return b},a,function(b,c){if(b==="create")try{c.auth()}catch(d){}});firebase.INTERNAL.extendNamespace({User:R})}else throw Error("Cannot find the firebase namespace; be sure to include firebase-app.js before this library.");})();var hp=function(){this.ab=(typeof document=="undefined"?null:document)||{cookie:""}};l=hp.prototype;l.isEnabled=function(){if(!u.navigator.cookieEnabled)return!1;if(!this.mh())return!0;this.set("TESTCOOKIESENABLED","1",{Nf:60});if(this.get("TESTCOOKIESENABLED")!=="1")return!1;this.remove("TESTCOOKIESENABLED");return!0};
l.set=function(a,b,c){var d=!1;if(typeof c==="object"){var e=c.jl;d=c.ek||!1;var f=c.domain||void 0;var g=c.path||void 0;var h=c.Nf}if(/[;=\s]/.test(a))throw Error('Invalid cookie name "'+a+'"');if(/[;\r\n]/.test(b))throw Error('Invalid cookie value "'+b+'"');h===void 0&&(h=-1);this.gg(a+"="+b+(f?";domain="+f:"")+(g?";path="+g:"")+(h<0?"":h==0?";expires="+(new Date(1970,1,1)).toUTCString():";expires="+(new Date(Date.now()+h*1E3)).toUTCString())+(d?";secure":"")+(e!=null?";samesite="+e:""))};
l.get=function(a,b){for(var c=a+"=",d=(this.Wc()||"").split(";"),e=0,f;e<d.length;e++){f=Ma(d[e]);if(f.lastIndexOf(c,0)==0)return f.slice(c.length);if(f==a)return""}return b};l.remove=function(a,b,c){var d=this.Nc(a);this.set(a,"",{Nf:0,path:b,domain:c});return d};l.Yd=function(){return ip(this).keys};l.ob=function(){return ip(this).values};l.mh=function(){return!this.Wc()};l.Nc=function(a){return this.get(a)!==void 0};l.clear=function(){for(var a=ip(this).keys,b=a.length-1;b>=0;b--)this.remove(a[b])};
l.gg=function(a){this.ab.cookie=a};l.Wc=function(){return this.ab.cookie};var ip=function(a){a=(a.Wc()||"").split(";");for(var b=[],c=[],d,e,f=0;f<a.length;f++)e=Ma(a[f]),d=e.indexOf("="),d==-1?(b.push(""),c.push(e)):(b.push(e.substring(0,d)),c.push(e.substring(d+1)));return{keys:b,values:c}},jp=new hp;var kp=/\.(firebaseapp\-staging\.com|staging\-web\.app)$/;var lp=function(){var a=u.EXPERIMENTS||{};this.K={};var b;for(b in a){var c=""+a[b].id;this.K[c]=a[b];typeof this.K[c].stagingRollout!=="undefined"&&(this.K[c].stagingRollout<0&&(this.K[c].stagingRollout=0),this.K[c].stagingRollout>1&&(this.K[c].stagingRollout=1));typeof this.K[c].rollout!=="undefined"&&(this.K[c].rollout<0&&(this.K[c].rollout=0),this.K[c].rollout>1&&(this.K[c].rollout=1))}};
lp.prototype.isEnabled=function(a){var b=a.id;a=a.id.toString();if(typeof this.K[a]!=="undefined"){var c=c===void 0?u.window:c;if(!(c&&c.navigator&&c.navigator.cookieEnabled)||this.K[a].expiration&&this.K[a].expiration.getTime()<=Date.now())return!!this.K[a].defaultValue;var d;c=this.Wc("e_gcip_"+b);c===null&&(c=parseInt(Math.random()*1E4,10)/1E4,this.K[b.toString()].expiration&&(d=parseInt((this.K[b.toString()].expiration.getTime()-Date.now())/1E3,10)),this.gg("e_gcip_"+b,c.toString(),d));b=parseFloat(c);
var e;return(e=e===void 0?u.window:e)&&e.location&&e.location.hostname&&kp.test(e.location.hostname)&&typeof this.K[a].stagingRollout!=="undefined"?(console.log("Evaluating experiment for staging domain"),this.K[a].stagingRollout===1?!0:b===0?!1:b<=this.K[a].stagingRollout):typeof this.K[a].rollout!=="undefined"?b===0?!1:b<=this.K[a].rollout:!!this.K[a].defaultValue}return!1};lp.prototype.gg=function(a,b,c){jp.set(a,b,{Nf:c?c:2592E3,path:"/__/auth/",domain:u.window.location.hostname,ek:!0})};
lp.prototype.Wc=function(a){return jp.get(a)||null};var mp=function(){this.Ud=new lp};mp.prototype.tj=function(){var a=(u.EXPERIMENTS||{}).DISPLAY_CONTINUE_BUTTON_IF_NOT_REDIRECT;return typeof a==="undefined"?!1:this.Ud.isEnabled(a)};mp.prototype.vj=function(){var a=(u.EXPERIMENTS||{}).POPUP_POST_MESSAGE_TO_IFRAME;return typeof a==="undefined"?!1:this.Ud.isEnabled(a)};mp.prototype.sj=function(){var a=(u.EXPERIMENTS||{}).CHECK_OAUTH_STATE_STORED_BEFORE_REDIRECT;return typeof a==="undefined"?!1:this.Ud.isEnabled(a)};
mp.prototype.xj=function(){var a=(u.EXPERIMENTS||{}).CHECK_REDIRECT_URL_IS_AUTHORIZED;return typeof a==="undefined"?!1:this.Ud.isEnabled(a)};var np=new mp,op=np.tj.bind(np),pp=np.vj.bind(np),qp=np.sj.bind(np),rp=np.xj.bind(np);var sp=function(a){return typeof a.className=="string"?a.className:a.getAttribute&&a.getAttribute("class")||""},tp=function(a,b){if(a.classList)a.classList.add(b);else if(a.classList?!a.classList.contains(b):!hb(a.classList?a.classList:sp(a).match(/\S+/g)||[],b)){var c=sp(a);b=c+(c.length>0?" "+b:b);typeof a.className=="string"?a.className=b:a.setAttribute&&a.setAttribute("class",b)}};/*

 Copyright 2015 Google Inc. All Rights Reserved.

 Licensed under the Apache License, Version 2.0 (the "License");
 you may not use this file except in compliance with the License.
 You may obtain a copy of the License at

      http://www.apache.org/licenses/LICENSE-2.0

 Unless required by applicable law or agreed to in writing, software
 distributed under the License is distributed on an "AS IS" BASIS,
 WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 See the License for the specific language governing permissions and
 limitations under the License.
*/
var Z={ni:function(){},oi:function(){},pi:function(){},sg:function(){},Rh:function(){},register:function(){},Rg:function(){}};
Z=function(){function a(n,r){for(var t=0;t<k.length;t++)if(k[t].className===n)return typeof r!=="undefined"&&(k[t]=r),k[t];return!1}function b(n){n=n.getAttribute("data-upgraded");return n===null?[""]:n.split(",")}function c(n,r){return b(n).indexOf(r)!==-1}function d(n,r,t){if("CustomEvent"in window&&typeof window.CustomEvent==="function")return new CustomEvent(n,{bubbles:r,cancelable:t});var y=document.createEvent("Events");y.initEvent(n,r,t);return y}function e(n,r){if(typeof n==="undefined"&&
typeof r==="undefined")for(n=0;n<k.length;n++)e(k[n].className,k[n].mb);else{if(typeof r==="undefined"){var t=a(n);t&&(r=t.mb)}r=document.querySelectorAll("."+r);for(t=0;t<r.length;t++)f(r[t],n)}}function f(n,r){if(!(typeof n==="object"&&n instanceof Element))throw Error("Invalid argument provided to upgrade MDL element.");var t=d("mdl-componentupgrading",!0,!0);n.dispatchEvent(t);if(!t.defaultPrevented){t=b(n);var y=[];if(r)c(n,r)||y.push(a(r));else{var ba=n.classList;k.forEach(function(se){ba.contains(se.mb)&&
y.indexOf(se)===-1&&!c(n,se.className)&&y.push(se)})}r=0;for(var jb=y.length,qa;r<jb;r++){if(qa=y[r]){t.push(qa.className);n.setAttribute("data-upgraded",t.join(","));var xh=new qa.Ji(n);xh.mdlComponentConfigInternal_=qa;m.push(xh);for(var yh=0,Tp=qa.ff.length;yh<Tp;yh++)qa.ff[yh](n);qa.Te&&(n[qa.className]=xh)}else throw Error("Unable to find a registered component for the given class.");qa=d("mdl-componentupgraded",!0,!1);n.dispatchEvent(qa)}}}function g(n){Array.isArray(n)||(n=n instanceof Element?
[n]:Array.prototype.slice.call(n));for(var r=0,t=n.length,y;r<t;r++)y=n[r],y instanceof HTMLElement&&(f(y),y.children.length>0&&g(y.children))}function h(n){if(n){m.splice(m.indexOf(n),1);var r=n.S.getAttribute("data-upgraded").split(",");r.splice(r.indexOf(n.mdlComponentConfigInternal_.jf),1);n.S.setAttribute("data-upgraded",r.join(","));r=d("mdl-componentdowngraded",!0,!1);n.S.dispatchEvent(r)}}var k=[],m=[];return{ni:e,oi:f,pi:g,sg:function(){for(var n=0;n<k.length;n++)e(k[n].className)},Rh:function(n,
r){(n=a(n))&&n.ff.push(r)},register:function(n){var r=!0;if(typeof n.Te!=="undefined"||typeof n.widget!=="undefined")r=n.Te||n.widget;var t={Ji:n.constructor||n.constructor,className:n.jf||n.classAsString,mb:n.mb||n.cssClass,Te:r,ff:[]};k.forEach(function(y){if(y.mb===t.mb)throw Error("The provided cssClass has already been registered: "+y.mb);if(y.className===t.className)throw Error("The provided className has already been registered");});if(n.constructor.prototype.hasOwnProperty("mdlComponentConfigInternal_"))throw Error("MDL component classes must not have mdlComponentConfigInternal_ defined as a property.");
a(n.jf,t)||k.push(t)},Rg:function(n){var r=function(y){m.filter(function(ba){return ba.S===y}).forEach(h)};if(n instanceof Array||n instanceof NodeList)for(var t=0;t<n.length;t++)r(n[t]);else if(n instanceof Node)r(n);else throw Error("Invalid argument provided to downgrade MDL nodes.");}}}();Z.upgradeDom=Z.ni;Z.upgradeElement=Z.oi;Z.upgradeElements=Z.pi;Z.upgradeAllRegistered=Z.sg;Z.registerUpgradedCallback=Z.Rh;Z.register=Z.register;Z.downgradeElements=Z.Rg;window.componentHandler=Z;
window.addEventListener("load",function(){"classList"in document.createElement("div")&&"querySelector"in document&&"addEventListener"in window&&Array.prototype.forEach&&(document.documentElement.classList.add("mdl-js"),Z.sg())});(function(){var a=function(b){this.S=b;this.init()};window.MaterialProgress=a;a.prototype.Bi={Ci:"mdl-progress__indeterminate"};a.prototype.jk=function(b){this.S.classList.contains(this.Bi.Ci)||(this.Oh.style.width=b+"%")};a.prototype.setProgress=a.prototype.jk;a.prototype.ik=function(b){this.Bg.style.width=b+"%";this.yg.style.width=100-b+"%"};a.prototype.setBuffer=a.prototype.ik;a.prototype.init=function(){if(this.S){var b=document.createElement("div");b.className="progressbar bar bar1";this.S.appendChild(b);
this.Oh=b;b=document.createElement("div");b.className="bufferbar bar bar2";this.S.appendChild(b);this.Bg=b;b=document.createElement("div");b.className="auxbar bar bar3";this.S.appendChild(b);this.yg=b;this.Oh.style.width="0%";this.Bg.style.width="100%";this.yg.style.width="0%";this.S.classList.add("is-upgraded")}};Z.register({constructor:a,jf:"MaterialProgress",mb:"mdl-js-progress",Te:!0})})();var up={"244437093285883777":{ar:"\u062c\u0627\u0631\u064d \u0627\u0644\u062a\u0623\u0643\u0651\u062f \u0645\u0646 \u0623\u0646\u0643 \u0644\u0633\u062a \u0628\u0631\u0646\u0627\u0645\u062c \u0631\u0648\u0628\u0648\u062a...",ar_xb:"\u200f\u202eVerifying\u202c\u200f \u200f\u202eyou\u202c\u200f'\u200f\u202ere\u202c\u200f \u200f\u202enot\u202c\u200f \u200f\u202ea\u202c\u200f \u200f\u202erobot\u202c\u200f...",bg:"\u041f\u043e\u0442\u0432\u044a\u0440\u0436\u0434\u0430\u0432\u0430 \u0441\u0435, \u0447\u0435 \u043d\u0435 \u0441\u0442\u0435 \u0440\u043e\u0431\u043e\u0442\u2026",
ca:"S'est\u00e0 comprovant que no siguis un robot...",cs:"Ov\u011b\u0159ujeme, zda nejste robot\u2026",da:"Bekr\u00e6fter, at du ikke er en robot\u2026",de:"Best\u00e4tigen Sie bitte, dass Sie kein Roboter sind.",el:"\u0395\u03c0\u03b1\u03bb\u03ae\u03b8\u03b5\u03c5\u03c3\u03b7 \u03cc\u03c4\u03b9 \u03b4\u03b5\u03bd \u03b5\u03af\u03c3\u03c4\u03b5 \u03c1\u03bf\u03bc\u03c0\u03cc\u03c4\u2026",en:"Verifying you're not a robot...",en_gb:"Verifying you're not a robot...",en_xa:"[V\u00e9\u0155\u00ee\u0192\u00fd\u00ee\u00f1\u011d \u00fd\u00f6\u00fb'\u0155\u00e9 \u00f1\u00f6\u0163 \u00e5 \u0155\u00f6\u0431\u00f6\u0163... one two three four five six seven]",
es:"Estamos comprobando que no eres un robot...",es_419:"Estamos verificando que no eres un robot\u2026",fa:"\u062f\u0631\u062d\u0627\u0644 \u062a\u0623\u06cc\u06cc\u062f \u0627\u06cc\u0646\u06a9\u0647 \u0634\u0645\u0627 \u0631\u0628\u0627\u062a \u0646\u06cc\u0633\u062a\u06cc\u062f\u2026",fi:"Tarkistamme, ettet ole robotti\u2026",fil:"Vine-verify na hindi ka robot...",fr:"Nous v\u00e9rifions que vous n'\u00eates pas un robot\u2026",hi:"\u0906\u092a \u0930\u094b\u092c\u094b\u091f \u0928\u0939\u0940\u0902 \u0939\u0948\u0902 \u0907\u0938\u0915\u0940 \u092a\u0941\u0937\u094d\u091f\u093f \u0915\u0940 \u091c\u093e \u0930\u0939\u0940 \u0939\u0948...",
hr:"Potvr\u0111ujemo da niste robot...",hu:"Annak ellen\u0151rz\u00e9se, hogy \u00d6n nem robot...",id:"Memverifikasi bahwa Anda bukan robot...",it:"Stiamo verificando che non sei un robot\u2026",iw:"\u05de\u05d5\u05d5\u05d3\u05d0 \u05e9\u05d0\u05d9\u05e0\u05da \u05e8\u05d5\u05d1\u05d5\u05d8...",ja:"\u30ed\u30dc\u30c3\u30c8\u306b\u3088\u308b\u64cd\u4f5c\u3067\u306a\u3044\u3053\u3068\u3092\u78ba\u8a8d\u3057\u3066\u3044\u307e\u3059...",ko:"\ub85c\ubd07\uc774 \uc544\ub2cc \uc2e4\uc81c \uc0ac\uc6a9\uc790\uc784\uc744 \ud655\uc778 \uc911...",
lt:"Tikrinama, ar nesate robotas...",lv:"Notiek verifik\u0101cija, lai p\u0101rliecin\u0101tos, ka neesat robots...",nl:"Verifi\u00ebren of u geen robot bent...",no:"Bekrefter at du ikke er en robot ...",pl:"Potwierd\u017a, \u017ce nie jeste\u015b robotem.",pt:"Verificando se voc\u00ea n\u00e3o \u00e9 um rob\u00f4...",pt_pt:"A verificar se \u00e9 um rob\u00f4...",ro:"Se verific\u0103 dac\u0103 sunte\u021bi un robot...",ru:"\u041d\u0430\u043c \u043d\u0443\u0436\u043d\u043e \u0443\u0431\u0435\u0434\u0438\u0442\u044c\u0441\u044f, \u0447\u0442\u043e \u0432\u044b \u043d\u0435 \u0440\u043e\u0431\u043e\u0442...",
sk:"Overuje sa, \u017ee nie ste robot...",sl:"Preverjamo, da niste robot ...",sr:"\u041f\u043e\u0442\u0432\u0440\u0452\u0443\u0458\u0435\u043c\u043e \u0434\u0430 \u043d\u0438\u0441\u0442\u0435 \u0440\u043e\u0431\u043e\u0442\u2026",sv:"Verifierar att du inte \u00e4r en robot \u2026",th:"\u0e01\u0e33\u0e25\u0e31\u0e07\u0e22\u0e37\u0e19\u0e22\u0e31\u0e19\u0e27\u0e48\u0e32\u0e04\u0e38\u0e13\u0e44\u0e21\u0e48\u0e43\u0e0a\u0e48\u0e2b\u0e38\u0e48\u0e19\u0e22\u0e19\u0e15\u0e4c...",tr:"Robot olmad\u0131\u011f\u0131n\u0131z do\u011frulan\u0131yor...",
uk:"\u041f\u0435\u0440\u0435\u0432\u0456\u0440\u044f\u0454\u043c\u043e, \u0447\u0438 \u0432\u0438 \u043d\u0435 \u0440\u043e\u0431\u043e\u0442\u2026",vi:"\u0110ang x\u00e1c minh b\u1ea1n kh\u00f4ng ph\u1ea3i l\u00e0 r\u00f4 b\u1ed1t...",zh_cn:"\u6b63\u5728\u9a8c\u8bc1\u60a8\u662f\u5426\u4e3a\u673a\u5668\u4eba\u2026",zh_tw:"\u6b63\u5728\u9a57\u8b49\u60a8\u662f\u5426\u70ba\u81ea\u52d5\u7a0b\u5f0f..."}},vp=null,wp="ar ar_xb iw fa ps sd so tk ug ur he yi syc ks ku".split(" "),xp=function(a,b){if(!vp){vp=
{};for(var c in up)vp[up[c].en]=c}b=b.replace("-","_").toLowerCase();return typeof vp[a]!=="undefined"&&(c=vp[a],typeof up[c][b]!=="undefined")?up[c][b]:a};var yp=function(a,b){this.rk=a;this.qk=b;this.S=null};
yp.prototype.render=function(a){var b=(0,this.rk)(this.qk||Be,void 0);var c=Ca||(Ca=new ye);if(b&&b.Sj)c=b.Sj();else{c=c.createElement("DIV");b:if(v(b)){if(b.ki){var d=b.ki();if(d instanceof yc){b=d;break b}}Ga("Soy template output is unsafe for use as HTML: "+b);b=ad("zSoyz")}else b=ad(String(b));d=b.toString();var e=d.match(Ae);z(!e,"This template starts with a %s, which cannot be a child of a <div>, as required by soy internals. Consider using goog.soy.renderElement instead.\nTemplate output: %s",e&&
e[0],d);c.innerHTML=Ac(b)}c.childNodes.length==1&&(b=c.firstChild,b.nodeType==1&&(c=b));this.S=c;ne(a,this.S);this.Fd()};yp.prototype.Fd=function(){};yp.prototype.Kd=function(){};yp.prototype.dispose=function(){this.S&&(this.Kd(),pe(this.S),this.S=null)};var zp=function(){yp.call(this,Ce)};q(zp,yp);zp.prototype.Fd=function(){var a=ge("progressBar");window.componentHandler&&window.componentHandler.upgradeElement&&window.componentHandler.upgradeElement(a)};
zp.prototype.Kd=function(){var a=ge("progressBar");window.componentHandler&&window.componentHandler.downgradeElements&&window.componentHandler.downgradeElements(a)};var Ap=function(a,b){yp.call(this,De,{appName:a});this.te=b;this.Za=null};q(Ap,yp);Ap.prototype.Fd=function(){var a=ge("continue"),b=this;this.Za=df(a,"click",function(){b.te()})};Ap.prototype.Kd=function(){this.Za&&(nf(this.Za),this.Za=null)};var Bp=function(a){yp.call(this,Ee,{errorMessage:a})};q(Bp,yp);
var Cp=function(a,b){yp.call(this,Fe,{});this.te=a||null;this.mc=b||null;this.Za=null};q(Cp,yp);Cp.prototype.Fd=function(){var a=ge("verify"),b=this;this.te&&(this.Za=df(a,"click",function(){b.te()}));a=ge("app-verification-progress-bar");window.componentHandler&&window.componentHandler.upgradeElement&&window.componentHandler.upgradeElement(a);if((a=ge("status-container-label"))&&this.mc){var c=xp(xe(a),this.mc);te(a,c);hb(wp,this.mc.replace("-","_").toLowerCase())&&tp(a,"firebase-rtl")}};
var Dp=function(){var a=ge("status-container");tp(a,"firebase-hidden")};Cp.prototype.Kd=function(){this.Za&&(nf(this.Za),this.Za=null);var a=ge("app-verification-progress-bar");window.componentHandler&&window.componentHandler.downgradeElements&&window.componentHandler.downgradeElements(a)};var Ep=function(a){this.Zf=ke("DIV",{id:"progressBarContainer"});var b=this;this.xb=new Em;this.uri=F(a);this.apiKey=E(this.uri,"apiKey")||null;this.appName=E(this.uri,"appName")||"";this.authType=E(this.uri,"authType")||null;this.Fb=E(this.uri,"eventId")||null;this.ta=E(this.uri,"redirectUrl")||null;this.ve=E(this.uri,"v")||null;this.dk=(a=E(this.uri,"scopes"))?a.split(","):[];this.Rd={};this.sessionId=E(this.uri,"sessionId")||null;this.We=E(this.uri,"appDisplayName")||null;this.Oa=E(this.uri,"apn")||
null;this.qb=E(this.uri,"ibi")||null;this.Sd=E(this.uri,"eid")||null;this.clientId=E(this.uri,"clientId")||null;this.nb=E(this.uri,"appId")||null;(this.vg=(new wd(this.uri.ic)).get("fac")||null)&&console.log("App Check token found.");this.hh=E(this.uri,"hl")||null;this.Tb=E(this.uri,"sha1Cert")||null;this.publicKey=E(this.uri,"publicKey")||null;this.Ne=E(this.uri,"tid")||null;a=Kh(E(this.uri,"customParameters")||"{}");this.Rd=typeof a=="object"?a||{}:{};this.providerId=E(this.uri,"providerId")||null;
this.ze=typeof u.POST_BODY==="string"&&u.POST_BODY!="{{POST_BODY}}"&&u.POST_BODY.length!=0?u.POST_BODY:null;this.providerId&&(this.Rd=Jh(this.Rd,ii(this.providerId)));this.Uc=(a=E(this.uri,"fw"))?a.split(","):[];this.mode="oauth";this.Qb=null;this.Fh=this.Pf=oh().then(function(){document.body.appendChild(b.Zf);b.Qb=new zp;b.Qb.render(b.Zf)});this.Ua=null},Fp={},Gp={bf:["facebook.com"]},Hp={},Ip={bf:["facebook.com","apple.com"]},Jp={},Kp=function(a){if(a.ta)try{return td(ud(sd(F(a.ta),""),""),"").toString()}catch(b){}else{if(a.Oa)return"file://asset/www/index.html?apn="+
encodeURIComponent(a.Oa);if(a.qb)return"file://asset/www/index.html?ibi="+encodeURIComponent(a.qb)}return null},Lp=function(a,b){return E(a,b)},Mp=function(a){if(!a.apiKey)throw Qh("No API key available"),new P("bad-request");a.Ua=new Ej(a.apiKey,Yg(a.Sd),Bh("Handler","2.20.6",a.Uc),a.vg);a.Ua.C=a.Ne},Op=function(a){Np(a);a.Pf.then(function(){a.Qb=new zp;a.Qb.render(a.Zf)})},Np=function(a){a.Fh&&a.Fh.cancel();a.Qb&&(a.Qb.dispose(),a.Qb=null)};
Ep.prototype.kc=function(){return this.apiKey?this.apiKey+":"+(this.appName||""):null};Ep.prototype.handleError=function(a){var b=this;if(a instanceof P&&(a.code==="auth/unauthorized-domain"||a.code==="auth/bad-request"))return oh().then(function(){Np(b);(new Bp(a.message)).render(document.body)});var c=new mi(this.authType||"unknown",this.Fb,null,null,a);return Pp(this,c)};
var Qp=function(a,b,c,d){b=new mi(a.authType,a.Fb,b,c,null,d,a.Ne);return Pp(a,b)},Pp=function(a,b){var c=a.kc(),d=!1,e=J();jh()&&!a.ta&&(e=Tg(500));return e.then(function(){if((a.Oa||a.qb)&&a.Ua)return d=!0,Rp(a.Ua,b,a.Oa,a.qb,a.clientId,a.Tb,a.We,a.Fb,a.nb,a.publicKey);if(a.authType==="verifyApp"&&b.Y)return d=!0,Sp(b.getError());if(c){var f=a.xb;return b.getType().match(/Redirect$/)?f.o.set(Dm,b.m(),c):Up(f,c,b)}}).then(function(){return a.xb.o.remove(Gm)}).then(function(){if(c)return a.xb.o.remove(Fm,
c)}).yb(function(){d?Np(a):/redirect/i.test(a.authType||"")?(Np(a),Th(),ch(a.ta)):a.ve&&Gh()&&!th()?a.apiKey?setTimeout(function(){Np(a);hh()},15E3):(Np(a),hh()):(Np(a),hh())})},Rp=function(a,b,c,d,e,f,g,h,k,m){return J().then(function(){if(b.getType()==="verifyApp"&&d){if(!e&&!k)throw new P("invalid-app-id");Vp(null,b,c,d,e,f,g,h,k,m)}else return b.getType()==="verifyApp"&&c?Vp(null,b,c,d,e,f,g,h,k,m):c?Zj(a,c,f).then(function(){var n=null;n=f?J("playservices.app.goo.gl"):Q(a,Jk,{returnDynamicLink:!0});
return n.then(function(r){Vp(r,b,c,d,e,f,g,h,k,m)})}):(e?ak(a,e):k?bk(a,k):Yj(a,d)).then(function(){Vp(null,b,c,d,e,f,g,h,k,m)})}).h(function(n){return Sp(n)})},Sp=function(a){var b=!a||a.code!="auth/dynamic-link-not-activated"&&a.code!="auth/invalid-app-id"&&a.code!="auth/invalid-oauth-client-id"&&a.code!="auth/invalid-api-key"&&a.code!="auth/internal-error"&&a.code!="auth/invalid-cert-hash"?(Rd["fireauth.oauthhelper.ui.soy.temporaryErrorMessage"]?Rd["fireauth.oauthhelper.ui.soy.temporaryErrorMessage"](void 0,
void 0):"An error occurred. Please try again later.").toString():a.message;return oh().then(function(){(new Bp(b)).render(document.body)})},Vp=function(a,b,c,d,e,f,g,h,k,m){m=m?"android_non_gmscore":c?"android":"ios";var n=c?c:d,r=null;f?(r=Wp(b,c,h,m),n="com.google.android.gms"):(e||k)&&d&&b.getType()!=="verifyApp"&&!b.Y?(r=window.location.protocol+"//"+window.location.host+"/__/auth/callback?authType="+encodeURIComponent(b.getType())+"&link="+encodeURIComponent(b.Wa),h&&(r+="&eventId="+h)):b.Y?
(r=window.location.protocol+"//"+window.location.host+"/__/auth/callback?firebaseError="+encodeURIComponent(Hh(b.getError().m()))+"&authType="+encodeURIComponent(b.getType()),h&&(r+="&eventId="+h)):r=b.Wa.replace("/handler","/callback");a=new xi(a,m,n,window.location.host,r,e,k);m=="android"?(yi(a,g),ch(a.toString(!f))):ch(a.toString(),void 0,!0);setTimeout(function(){bh(null)},4E3)},Wp=function(a,b,c,d){if(d==="android_non_gmscore"){d=a.Wa;var e=window.location.protocol+"//"+window.location.host+
"/__/auth/handler";b="intent://firebase.auth/#Intent;scheme="+(a.getType()==="verifyApp"?"recaptcha":"genericidp")+";package="+b+";S.authType="+a.getType()+";";c&&(b+="S.eventId="+c+";");a.Y?b+="S.firebaseError="+encodeURIComponent(Hh(a.getError().m()))+";":(b+="S.link="+encodeURIComponent(d)+";",b+="B.encryptionEnabled=false;");b+="S.browser_fallback_url="+encodeURIComponent(e)+";";a=b+"end;"}else d=Dd("https","fir-auth-gms.firebaseapp.com",null,"/",null,null),D(d,"authType",a.getType()),D(d,"cpn",
b),c&&D(d,"eventId",c),a.Y?D(d,"firebaseError",Hh(a.getError().m())):D(d,"link",a.Wa),a=d.toString();return a},Up=function(a,b,c){var d=u.window&&u.window.opener||null;if(pp()&&d&&/popup/i.test(c.getType()||"")){for(var e=[],f=b.split(":"),g=0;g<d.frames.length;g++){var h=d.frames[g];try{var k=F(h.location.href);f[0]===E(k,"apiKey")&&f[1]===E(k,"appName")&&e.push(new vl(new tl(h,h.location.origin)))}catch(n){}}if(e.length===0)return Im(a,b,c);var m=[];e.forEach(function(n){var r=!1;m.push(wl(n,"sendAuthEvent",
{storageKey:b,authEvent:c.m()},2E4).then(function(t){for(var y=0;y<t.length;y++)t[y].fulfilled&&t[y].value&&(r=t[y].value);if(!r)throw Error("Unable to send the auth event");}))});return dg(m).h(function(){return Im(a,b,c)}).then(function(){e.forEach(function(n){n.close()})})}return Im(a,b,c)};var Xp=function(a){this.Gg=!1;this.Mc=le(document,"DIV");if(Lp(F(a),"authType")!=="verifyApp")throw Error("Invalid mode!");this.Ra={size:"invisible",type:"image",tabindex:0,theme:"light"};Ep.call(this,a);this.Hd=new Cp(null,this.hh);this.hf=this.Ab=null;this.mode="verifyApp"};x(Xp,Ep);Xp.prototype.start=function(){var a=this;return this.bb().then(function(){return Yp(a)}).h(function(b){a.Ab&&a.Ab.clear();Op(a);a.Hd&&a.Hd.dispose();return b instanceof P?a.handleError(b):a.handleError(new P("internal-error"))})};
Xp.prototype.bb=function(){var a=this;return J().then(function(){if(!(a.apiKey&&a.qb&&(a.clientId||a.nb)||a.apiKey&&a.Oa&&a.Tb&&a.publicKey)){if(!a.apiKey)throw new P("invalid-api-key");if(!a.clientId&&!a.nb)throw new P("invalid-app-id");throw new P("internal-error");}}).then(function(){Mp(a);if(a.clientId)return ak(a.Ua,a.clientId);if(a.nb)return bk(a.Ua,a.nb);if(a.Oa&&a.Tb)return Zj(a.Ua,a.Oa,a.Tb);throw new P("internal-error");})};
var Yp=function(a){var b,c;return a.Pf.then(function(){c=function(){var d=qe();d&&d.style.width&&(d.style.width="")};a.Gg||(a.Gg=!0,document.body.appendChild(a.Mc));Np(a);a.Hd.render(a.Mc);b=ge("verify");a.Ab=new pl(a.apiKey,b,a.Ra,function(){return a.hh},a.ve,Yg(a.Sd));return a.Ab.render()}).then(function(){b.click();return Tg(2500)}).then(function(){c();Dp();a.hf=setInterval(function(){qe().style.visibility&&qe().style.visibility==="hidden"&&b.click()},1E3);u.window.addEventListener("orientationchange",
c);u.window.addEventListener("resize",c);return a.Ab.verify()}).then(function(d){Op(a);clearInterval(a.hf);u.window.removeEventListener("orientationchange",c);u.window.removeEventListener("resize",c);a.Ab.clear();a.Ab=null;d=window.location.protocol+"//"+window.location.host+"/__/auth/callback?authType="+encodeURIComponent(a.mode)+"&recaptchaToken="+encodeURIComponent(d);a.Fb&&(d+="&eventId="+encodeURIComponent(a.Fb));a.Hd.dispose();return Qp(a,d,"blank")}).h(function(d){clearInterval(a.hf);u.window.removeEventListener("orientationchange",
c);u.window.removeEventListener("resize",c);throw d;})};var Zp=function(a){this.ud=[];Ep.call(this,a)};x(Zp,Ep);
var $p=function(a){var b=u.window&&u.window.opener||null;if(!a.ta&&b&&/popup/i.test(a.authType||"")){for(var c=0;c<b.frames.length;c++){var d=b.frames[c];try{var e=F(d.location.href);a.apiKey===E(e,"apiKey")&&a.appName===E(e,"appName")&&a.ud.push(new vl(new tl(d,d.location.origin)))}catch(f){}}b=[];for(c=0;c<a.ud.length;c++)b.push(wl(a.ud[c],"getParentOrigin",null,2E4).then(function(f){for(var g=0;g<f.length;g++)f[g].fulfilled&&f[g].value&&(a.ta=f[g].value);if(!a.ta)throw Error("Unable to determine origin");
}));return dg(b).h(function(){}).then(function(){for(var f=0;f<a.ud.length;f++)a.ud[f].close()})}return J()};Zp.prototype.start=function(){var a=this;return this.bb().then(function(){return aq(a,a.providerId,a.Rd,a.dk,a.sessionId)}).h(function(b){return b instanceof P?a.handleError(b):a.handleError(new P("internal-error"))})};
Zp.prototype.bb=function(){var a=this;return J().then(function(){Mp(a);if(a.apiKey&&a.authType&&a.providerId){var b=new oi(a.apiKey,a.appName,a.authType,a.Fb,a.ta,a.ve,a.We,a.Oa,a.qb,a.Sd,a.Uc,a.clientId,a.Tb,a.Ne,a.providerId,a.nb,a.publicKey),c=new Wg,d=a.providerId,e=function(h,k){var m=new Ej(h);return Wj(m).then(function(n){var r=mh(n,k);return r?J(r):Sj(m,d,k+"#webwidgetstarter",{},null,null).then(function(){return J(r)},function(){return J(r)})},function(n){return J(n)})},f=function(h,k){return Xj(k).then(function(m){return J(!h||
m===h)},function(){return J(!1)})},g=function(h,k,m){return c.He(new L(c.Mi),c.Ki,"GET",null,{"Content-type":"application/json"},1E4).then(function(n){return n.apiKey===h?J(!0):e(n.apiKey,k).then(function(r){return r instanceof Error?f(n.messagingSenderId,m).then(function(t){return t?J(t):Sj(m,d,k+"#webwidgetstarter_projectNumber",{},null,null).then(function(){return J(t)},function(){return J(t)})},function(){return J(!1)}):J(r)})},function(){return J(!0)})};return(a.ta?Wj(a.Ua).h(function(){Qh("Unable to verify that the app domain is authorized");
throw new P("bad-request");}).then(function(h){if(!mh(h,a.ta))throw Qh("App domain is unauthorized"),new P("bad-request");return g(a.apiKey,a.ta,a.Ua).then(function(k){if(k)return J(k);Qh("App domain is unauthorized in the Firebase Hosting project.");if(!rp())return J(!0);throw new Ci(a.ta);},function(k){if(!rp())return J(!0);throw k;})}).h(function(h){throw h;}):J()).then(function(){var h=a.Oa?a.Tb?Gp:Hp:a.qb?a.clientId||a.nb?Ip:Jp:Fp;if(h.bf&&h.bf.includes(a.providerId))throw new P("operation-not-supported-in-this-environment",
"This web-based operation for the "+a.providerId+" provider is not supported in this environment. Please use the identity provider's native SDK instead.");return a.xb.o.set(Gm,b.m())})}Qh("Request is missing required data");throw new P("bad-request");})};
var aq=function(a,b,c,d,e){var f,g=td(ud(F(a.uri.toString()),""),"").toString(),h=null;return Sj(a.Ua,b,g,c,d,e).then(function(k){f=k;return $p(a)}).then(function(){var k=F(f.authUri),m=Kp(a),n;(n=(n=u.window)&&n.innerWidth&&n.innerHeight?{width:parseFloat(n.innerWidth),height:parseFloat(n.innerHeight)}:null)&&n.width<800&&b=="facebook.com"&&!a.ta&&D(k,"display","popup");m&&D(k,"context_uri",m);h=k.toString();k=a.xb;m=a.kc();return k.o.set(Fm,f.sessionId,m)}).then(function(){return bq(a)}).then(function(){Np(a);
var k=ah();ch(h);op()&&eh(M())==="Safari"&&setTimeout(function(){k===ah()&&(new Ap(null,function(){a.handleError(new P("user-cancelled"))})).render(document.body)},1E3)})},bq=function(a){if(!qp())return J();var b=0;return new I(function(c,d){var e=function(){b++>=10?(Qh("Unable to save initial state."),d(new P("bad-request","Unable to save initial state. This may happen if browser sessionStorage is inaccessible."))):Hm(a.xb).then(function(f){f?c():setTimeout(e,1)})};e()})};var cq=function(a){Ep.call(this,a)};q(cq,Ep);cq.prototype.start=function(){var a=this;return this.bb().then(function(){return dq(a)}).h(function(b){return b instanceof P?a.handleError(b):a.handleError(new P("internal-error"))})};
cq.prototype.bb=function(){var a=this;return Hm(this.xb).then(function(b){if(!b)throw Qh("Unable to process request due to missing initial state."),new P("bad-request","Unable to process request due to missing initial state. This may happen if browser sessionStorage is inaccessible or accidentally cleared. Some specific scenarios are - 1) Using IDP-Initiated SAML SSO. 2) Using signInWithRedirect in a storage-partitioned browser environment.");var c=b&&b.A,d=b&&b.getType();if(!c)throw new P("invalid-api-key");
if(!d)throw new P("internal-error");a.apiKey=b.A;a.Sd=b.Sg;a.Uc=b.U;Mp(a);a.appName=b.B;a.authType=b.getType();a.Fb=b.T;a.ta=b.zc;a.ve=b.Pa;a.We=b.nf;a.Oa=b.ac;a.qb=b.ad;a.clientId=b.Cb;a.Tb=b.bi;a.Ne=b.C;a.providerId=b.wc;a.nb=b.Gb;a.publicKey=b.Ph})};
var eq=function(a,b){if(a.ze&&a.providerId==="apple.com"){b=F(b);var c=Wh(a.ze);a.ze=null;for(var d in c)c.hasOwnProperty(d)&&D(b,d,c[d]);return b.toString()}return b},dq=function(a){var b=eq(a,a.uri.toString()),c=a.kc();return a.xb.jc(c).then(function(d){if(!d)throw new P("internal-error");return Qp(a,b,d,a.ze)})};var fq=null;function gq(a){hq();oh().then(function(){var b=new Ap(a.appName,function(){b.dispose();ch(a.toString());setTimeout(function(){bh(null)},4E3)});b.render(document.body)})}function iq(a){var b=a;try{var c=li(Kh(a));c&&c.message&&(b=c.message)}catch(d){}hq();oh().then(function(){(new Bp(b)).render(document.body)})}
function hq(){var a=new fe(de,'.mdl-card{display:-webkit-box;display:-webkit-flex;display:-moz-box;display:-ms-flexbox;display:flex;-webkit-box-orient:vertical;-webkit-box-direction:normal;-webkit-flex-direction:column;-moz-box-orient:vertical;-moz-box-direction:normal;-ms-flex-direction:column;flex-direction:column;font-size:16px;font-weight:400;min-height:200px;overflow:hidden;width:330px;z-index:1;position:relative;background:#fff;border-radius:2px;-moz-box-sizing:border-box;box-sizing:border-box}.mdl-card__media{background-color:#ff4081;background-repeat:repeat;background-position:50% 50%;background-size:cover;background-origin:padding-box;background-attachment:scroll;-moz-box-sizing:border-box;box-sizing:border-box}.mdl-card__title{-webkit-box-align:center;-webkit-align-items:center;-moz-box-align:center;-ms-flex-align:center;align-items:center;color:#000;display:block;display:-webkit-box;display:-webkit-flex;display:-moz-box;display:-ms-flexbox;display:flex;-webkit-box-pack:stretch;-webkit-justify-content:stretch;-moz-box-pack:stretch;-ms-flex-pack:stretch;justify-content:stretch;line-height:normal;padding:16px 16px;-webkit-perspective-origin:165px 56px;perspective-origin:165px 56px;-webkit-transform-origin:165px 56px;transform-origin:165px 56px;-moz-box-sizing:border-box;box-sizing:border-box}.mdl-card__title.mdl-card--border{border-bottom:1px solid rgba(0,0,0,.1)}.mdl-card__title-text{-webkit-align-self:flex-end;-ms-flex-item-align:end;align-self:flex-end;color:inherit;display:block;display:-webkit-box;display:-webkit-flex;display:-moz-box;display:-ms-flexbox;display:flex;font-size:24px;font-weight:300;line-height:normal;overflow:hidden;-webkit-transform-origin:149px 48px;transform-origin:149px 48px;margin:0}.mdl-card__subtitle-text{font-size:14px;color:rgba(0,0,0,.54);margin:0}.mdl-card__supporting-text{color:rgba(0,0,0,.54);font-size:1rem;line-height:18px;overflow:hidden;padding:16px 16px;width:90%}.mdl-card__supporting-text.mdl-card--border{border-bottom:1px solid rgba(0,0,0,.1)}.mdl-card__actions{font-size:16px;line-height:normal;width:100%;background-color:transparent;padding:8px;-moz-box-sizing:border-box;box-sizing:border-box}.mdl-card__actions.mdl-card--border{border-top:1px solid rgba(0,0,0,.1)}.mdl-card--expand{-webkit-box-flex:1;-webkit-flex-grow:1;-moz-box-flex:1;-ms-flex-positive:1;flex-grow:1}.mdl-card__menu{position:absolute;right:16px;top:16px}.mdl-button{background:transparent;border:none;border-radius:2px;color:#000;position:relative;height:36px;margin:0;min-width:64px;padding:0 16px;display:inline-block;font-family:Roboto,Helvetica,Arial,sans-serif;font-size:14px;font-weight:500;text-transform:uppercase;line-height:1;letter-spacing:0;overflow:hidden;will-change:box-shadow;-webkit-transition:box-shadow .2s cubic-bezier(.4,0,1,1),background-color .2s cubic-bezier(.4,0,.2,1),color .2s cubic-bezier(.4,0,.2,1);transition:box-shadow .2s cubic-bezier(.4,0,1,1),background-color .2s cubic-bezier(.4,0,.2,1),color .2s cubic-bezier(.4,0,.2,1);outline:none;cursor:pointer;text-decoration:none;text-align:center;line-height:36px;vertical-align:middle}.mdl-button::-moz-focus-inner{border:0}.mdl-button:hover{background-color:hsla(0,0%,62%,.2)}.mdl-button:focus:not(:active){background-color:rgba(0,0,0,.12)}.mdl-button:active{background-color:hsla(0,0%,62%,.4)}.mdl-button.mdl-button--colored{color:#3f51b5}.mdl-button.mdl-button--colored:focus:not(:active){background-color:rgba(0,0,0,.12)}input.mdl-button[type=submit]{-webkit-appearance:none}.mdl-button--raised{background:hsla(0,0%,62%,.2);box-shadow:0 2px 2px 0 rgba(0,0,0,.14),0 3px 1px -2px rgba(0,0,0,.2),0 1px 5px 0 rgba(0,0,0,.12)}.mdl-button--raised:active{box-shadow:0 4px 5px 0 rgba(0,0,0,.14),0 1px 10px 0 rgba(0,0,0,.12),0 2px 4px -1px rgba(0,0,0,.2);background-color:hsla(0,0%,62%,.4)}.mdl-button--raised:focus:not(:active){box-shadow:0 0 8px rgba(0,0,0,.18),0 8px 16px rgba(0,0,0,.36);background-color:hsla(0,0%,62%,.4)}.mdl-button--raised.mdl-button--colored{background:#3f51b5;color:#fff}.mdl-button--raised.mdl-button--colored:hover{background-color:#3f51b5}.mdl-button--raised.mdl-button--colored:active{background-color:#3f51b5}.mdl-button--raised.mdl-button--colored:focus:not(:active){background-color:#3f51b5}.mdl-button--raised.mdl-button--colored .mdl-ripple{background:#fff}.mdl-button--fab{border-radius:50%;font-size:24px;height:56px;margin:auto;min-width:56px;width:56px;padding:0;overflow:hidden;background:hsla(0,0%,62%,.2);box-shadow:0 1px 1.5px 0 rgba(0,0,0,.12),0 1px 1px 0 rgba(0,0,0,.24);position:relative;line-height:normal}.mdl-button--fab .material-icons{position:absolute;top:50%;left:50%;-webkit-transform:translate(-12px,-12px);transform:translate(-12px,-12px);line-height:24px;width:24px}.mdl-button--fab.mdl-button--mini-fab{height:40px;min-width:40px;width:40px}.mdl-button--fab .mdl-button__ripple-container{border-radius:50%;-webkit-mask-image:-webkit-radial-gradient(circle,#fff,#000)}.mdl-button--fab:active{box-shadow:0 4px 5px 0 rgba(0,0,0,.14),0 1px 10px 0 rgba(0,0,0,.12),0 2px 4px -1px rgba(0,0,0,.2);background-color:hsla(0,0%,62%,.4)}.mdl-button--fab:focus:not(:active){box-shadow:0 0 8px rgba(0,0,0,.18),0 8px 16px rgba(0,0,0,.36);background-color:hsla(0,0%,62%,.4)}.mdl-button--fab.mdl-button--colored{background:#ff4081;color:#fff}.mdl-button--fab.mdl-button--colored:hover{background-color:#ff4081}.mdl-button--fab.mdl-button--colored:focus:not(:active){background-color:#ff4081}.mdl-button--fab.mdl-button--colored:active{background-color:#ff4081}.mdl-button--fab.mdl-button--colored .mdl-ripple{background:#fff}.mdl-button--icon{border-radius:50%;font-size:24px;height:32px;margin-left:0;margin-right:0;min-width:32px;width:32px;padding:0;overflow:hidden;color:inherit;line-height:normal}.mdl-button--icon .material-icons{position:absolute;top:50%;left:50%;-webkit-transform:translate(-12px,-12px);transform:translate(-12px,-12px);line-height:24px;width:24px}.mdl-button--icon.mdl-button--mini-icon{height:24px;min-width:24px;width:24px}.mdl-button--icon.mdl-button--mini-icon .material-icons{top:0;left:0}.mdl-button--icon .mdl-button__ripple-container{border-radius:50%;-webkit-mask-image:-webkit-radial-gradient(circle,#fff,#000)}.mdl-button__ripple-container{display:block;height:100%;left:0;position:absolute;top:0;width:100%;z-index:0;overflow:hidden}.mdl-button.mdl-button--disabled .mdl-button__ripple-container .mdl-ripple,.mdl-button[disabled] .mdl-button__ripple-container .mdl-ripple{background-color:transparent}.mdl-button--primary.mdl-button--primary{color:#3f51b5}.mdl-button--primary.mdl-button--primary .mdl-ripple{background:#fff}.mdl-button--primary.mdl-button--primary.mdl-button--fab,.mdl-button--primary.mdl-button--primary.mdl-button--raised{color:#fff;background-color:#3f51b5}.mdl-button--accent.mdl-button--accent{color:#ff4081}.mdl-button--accent.mdl-button--accent .mdl-ripple{background:#fff}.mdl-button--accent.mdl-button--accent.mdl-button--fab,.mdl-button--accent.mdl-button--accent.mdl-button--raised{color:#fff;background-color:#ff4081}.mdl-button.mdl-button--disabled.mdl-button--disabled,.mdl-button[disabled][disabled]{color:rgba(0,0,0,.26);cursor:default;background-color:transparent}.mdl-button--fab.mdl-button--disabled.mdl-button--disabled,.mdl-button--fab[disabled][disabled]{background-color:rgba(0,0,0,.12);color:rgba(0,0,0,.26)}.mdl-button--raised.mdl-button--disabled.mdl-button--disabled,.mdl-button--raised[disabled][disabled]{background-color:rgba(0,0,0,.12);color:rgba(0,0,0,.26);box-shadow:none}.mdl-button--colored.mdl-button--disabled.mdl-button--disabled,.mdl-button--colored[disabled][disabled]{color:rgba(0,0,0,.26)}.mdl-button .material-icons{vertical-align:middle}.mdl-progress{display:block;position:relative;height:4px;width:500px;max-width:100%}.mdl-progress>.bar{display:block;position:absolute;top:0;bottom:0;width:0;-webkit-transition:width .2s cubic-bezier(.4,0,.2,1);transition:width .2s cubic-bezier(.4,0,.2,1)}.mdl-progress>.progressbar{background-color:#3f51b5;z-index:1;left:0}.mdl-progress>.bufferbar{background-image:-webkit-gradient(linear,left top,right top,from(hsla(0,0%,100%,.7)),to(hsla(0,0%,100%,.7))),-webkit-gradient(linear,left top,right top,from(#3f51b5),to(#3f51b5));background-image:-webkit-linear-gradient(left,hsla(0,0%,100%,.7),hsla(0,0%,100%,.7)),-webkit-linear-gradient(left,#3f51b5,#3f51b5);background-image:linear-gradient(90deg,hsla(0,0%,100%,.7),hsla(0,0%,100%,.7)),linear-gradient(90deg,#3f51b5,#3f51b5);z-index:0;left:0}.mdl-progress>.auxbar{right:0}@supports (-webkit-appearance:none){.mdl-progress:not(.mdl-progress--indeterminate):not(.mdl-progress--indeterminate)>.auxbar,.mdl-progress:not(.mdl-progress__indeterminate):not(.mdl-progress__indeterminate)>.auxbar{background-image:-webkit-gradient(linear,left top,right top,from(hsla(0,0%,100%,.7)),to(hsla(0,0%,100%,.7))),-webkit-gradient(linear,left top,right top,from(#3f51b5),to(#3f51b5));background-image:-webkit-linear-gradient(left,hsla(0,0%,100%,.7),hsla(0,0%,100%,.7)),-webkit-linear-gradient(left,#3f51b5,#3f51b5);background-image:linear-gradient(90deg,hsla(0,0%,100%,.7),hsla(0,0%,100%,.7)),linear-gradient(90deg,#3f51b5,#3f51b5);-webkit-mask:url("data:image/svg+xml;base64,PD94bWwgdmVyc2lvbj0iMS4wIj8+Cjxzdmcgd2lkdGg9IjEyIiBoZWlnaHQ9IjQiIHZpZXdQb3J0PSIwIDAgMTIgNCIgdmVyc2lvbj0iMS4xIiB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciPgogIDxlbGxpcHNlIGN4PSIyIiBjeT0iMiIgcng9IjIiIHJ5PSIyIj4KICAgIDxhbmltYXRlIGF0dHJpYnV0ZU5hbWU9ImN4IiBmcm9tPSIyIiB0bz0iLTEwIiBkdXI9IjAuNnMiIHJlcGVhdENvdW50PSJpbmRlZmluaXRlIiAvPgogIDwvZWxsaXBzZT4KICA8ZWxsaXBzZSBjeD0iMTQiIGN5PSIyIiByeD0iMiIgcnk9IjIiIGNsYXNzPSJsb2FkZXIiPgogICAgPGFuaW1hdGUgYXR0cmlidXRlTmFtZT0iY3giIGZyb209IjE0IiB0bz0iMiIgZHVyPSIwLjZzIiByZXBlYXRDb3VudD0iaW5kZWZpbml0ZSIgLz4KICA8L2VsbGlwc2U+Cjwvc3ZnPgo=");mask:url("data:image/svg+xml;base64,PD94bWwgdmVyc2lvbj0iMS4wIj8+Cjxzdmcgd2lkdGg9IjEyIiBoZWlnaHQ9IjQiIHZpZXdQb3J0PSIwIDAgMTIgNCIgdmVyc2lvbj0iMS4xIiB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciPgogIDxlbGxpcHNlIGN4PSIyIiBjeT0iMiIgcng9IjIiIHJ5PSIyIj4KICAgIDxhbmltYXRlIGF0dHJpYnV0ZU5hbWU9ImN4IiBmcm9tPSIyIiB0bz0iLTEwIiBkdXI9IjAuNnMiIHJlcGVhdENvdW50PSJpbmRlZmluaXRlIiAvPgogIDwvZWxsaXBzZT4KICA8ZWxsaXBzZSBjeD0iMTQiIGN5PSIyIiByeD0iMiIgcnk9IjIiIGNsYXNzPSJsb2FkZXIiPgogICAgPGFuaW1hdGUgYXR0cmlidXRlTmFtZT0iY3giIGZyb209IjE0IiB0bz0iMiIgZHVyPSIwLjZzIiByZXBlYXRDb3VudD0iaW5kZWZpbml0ZSIgLz4KICA8L2VsbGlwc2U+Cjwvc3ZnPgo=")}}.mdl-progress:not(.mdl-progress--indeterminate)>.auxbar,.mdl-progress:not(.mdl-progress__indeterminate)>.auxbar{background-image:-webkit-gradient(linear,left top,right top,from(hsla(0,0%,100%,.9)),to(hsla(0,0%,100%,.9))),-webkit-gradient(linear,left top,right top,from(#3f51b5),to(#3f51b5));background-image:-webkit-linear-gradient(left,hsla(0,0%,100%,.9),hsla(0,0%,100%,.9)),-webkit-linear-gradient(left,#3f51b5,#3f51b5);background-image:linear-gradient(90deg,hsla(0,0%,100%,.9),hsla(0,0%,100%,.9)),linear-gradient(90deg,#3f51b5,#3f51b5)}.mdl-progress.mdl-progress--indeterminate>.bar1,.mdl-progress.mdl-progress__indeterminate>.bar1{background-color:#3f51b5;-webkit-animation-name:indeterminate1;animation-name:indeterminate1;-webkit-animation-duration:2s;animation-duration:2s;-webkit-animation-iteration-count:infinite;animation-iteration-count:infinite;-webkit-animation-timing-function:linear;animation-timing-function:linear}.mdl-progress.mdl-progress--indeterminate>.bar3,.mdl-progress.mdl-progress__indeterminate>.bar3{background-image:none;background-color:#3f51b5;-webkit-animation-name:indeterminate2;animation-name:indeterminate2;-webkit-animation-duration:2s;animation-duration:2s;-webkit-animation-iteration-count:infinite;animation-iteration-count:infinite;-webkit-animation-timing-function:linear;animation-timing-function:linear}@-webkit-keyframes indeterminate1{0%{left:0;width:0}50%{left:25%;width:75%}75%{left:100%;width:0}}@keyframes indeterminate1{0%{left:0;width:0}50%{left:25%;width:75%}75%{left:100%;width:0}}@-webkit-keyframes indeterminate2{0%{left:0;width:0}50%{left:0;width:0}75%{left:0;width:25%}to{left:100%;width:0}}@keyframes indeterminate2{0%{left:0;width:0}50%{left:0;width:0}75%{left:0;width:25%}to{left:100%;width:0}}body{margin:0}.firebase-container{background-color:#fff;box-sizing:border-box;-moz-box-sizing:border-box;-webkit-box-sizing:border-box;color:rgba(0,0,0,.87);direction:ltr;font:16px Roboto,arial,sans-serif;margin:0 auto;max-width:360px;overflow:hidden;padding-top:8px;position:relative;width:100%}.firebase-progress-bar{height:5px;left:0;position:absolute;top:0;width:100%}.firebase-hidden-button{height:1px;visibility:hidden;width:1px}.firebase-container#app-verification-screen{top:100px}.firebase-title{color:rgba(0,0,0,.87);direction:ltr;font-size:24px;font-weight:500;line-height:24px;margin:0;padding:0;text-align:center}.firebase-middle-progress-bar{height:5px;margin-left:auto;margin-right:auto;top:20px;width:250px}.firebase-hidden{display:none}.firebase-rtl{direction:rtl;text-align:right}@media (max-width:520px){.firebase-container{box-shadow:none;max-width:none;width:100%}}');a instanceof
fe&&a.constructor===fe&&a.Di===ee?a=a.ii:(Ga("expected object of type Const, got '"+a+"'"),a="type_error:Const");z(!A(a,"<"),"Forbidden '<' character in style sheet string: "+a);Yc("Deprecated, but safe closure/html builder");var b=new Fc(a);a=Ca||(Ca=new ye);var c=ze(a,"HEAD")[0];if(!c){var d=ze(a,"BODY")[0];c=a.Kg("HEAD");d.parentNode.insertBefore(c,d)}d=a.Kg("STYLE");var e=Cc("style",document);e&&d.setAttribute("nonce",e);if(b instanceof Fc)b=b.Lh;else throw Error("Unexpected type when unwrapping SafeStyleSheet, got '"+
b+"' of type '"+typeof b+"'");u.trustedTypes?te(d,b):d.innerHTML=b;a.appendChild(c,d)};for(var jq=function(){var a=ah();switch(E(F(a),"blank")?"blank":Lp(F(a),"authType")==="verifyApp"?"verifyApp":zi(a)?"dynamicLink":E(F(a),"firebaseError")?"error":Lp(F(a),"apiKey")?"starter":"finisher"){case "blank":bh(null);return;case "dynamicLink":a=zi(a);gq(a);return;case "error":a=E(F(a),"firebaseError")||null;iq(a);return;case "starter":fq=new Zp(a);break;case "finisher":fq=new cq(a);break;case "verifyApp":fq=new Xp(a)}hq();fq.start()},kq=["fireauth","oauthhelper","widget","initialize"],lq=u,
mq;kq.length&&(mq=kq.shift());)kq.length||jq===void 0?lq=lq[mq]&&lq[mq]!==Object.prototype[mq]?lq[mq]:lq[mq]={}:lq[mq]=jq;}).call(this);
